""" Cisco_IOS_XR_mpls_ldp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR mpls\-ldp package operational data.

This module contains definitions
for the following management objects\:
  mpls\-ldp\: MPLS LDP operational data

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class DhcbState(Enum):
    """
    DhcbState (Enum Class)

    DHCB State Type

    .. data:: none = 0

    	None

    .. data:: dhcb_active = 1

    	Active

    .. data:: dhcb_passive = 2

    	Passive

    .. data:: dhcb_active_passive = 3

    	Active and Passive

    """

    none = Enum.YLeaf(0, "none")

    dhcb_active = Enum.YLeaf(1, "dhcb-active")

    dhcb_passive = Enum.YLeaf(2, "dhcb-passive")

    dhcb_active_passive = Enum.YLeaf(3, "dhcb-active-passive")


class L2vpnLdpPwAgi(Enum):
    """
    L2vpnLdpPwAgi (Enum Class)

    L2vpn ldp pw agi

    .. data:: rd = 0

    	AGI type RD

    """

    rd = Enum.YLeaf(0, "rd")


class L2vpnLdpPwAii(Enum):
    """
    L2vpnLdpPwAii (Enum Class)

    L2vpn ldp pw aii

    .. data:: local_id = 0

    	AII Type 1

    .. data:: type2 = 1

    	AII Type 2

    """

    local_id = Enum.YLeaf(0, "local-id")

    type2 = Enum.YLeaf(1, "type2")


class L2vpnLdpPwFec(Enum):
    """
    L2vpnLdpPwFec (Enum Class)

    L2vpn ldp pw fec

    .. data:: fec128 = 0

    	FEC 128 pseudowire type

    .. data:: fec129 = 1

    	FEC 129 pseudowire type

    .. data:: fec130 = 2

    	FEC 130 pseudowire type

    .. data:: invalid = 3

    	FEC not applicable

    """

    fec128 = Enum.YLeaf(0, "fec128")

    fec129 = Enum.YLeaf(1, "fec129")

    fec130 = Enum.YLeaf(2, "fec130")

    invalid = Enum.YLeaf(3, "invalid")


class LabelValue(Enum):
    """
    LabelValue (Enum Class)

    Label Value Type

    .. data:: mpls_label = 0

    	MPLS Label

    .. data:: un_labelled = 1

    	Unlabelled

    .. data:: unknown = 2

    	Unknown label

    """

    mpls_label = Enum.YLeaf(0, "mpls-label")

    un_labelled = Enum.YLeaf(1, "un-labelled")

    unknown = Enum.YLeaf(2, "unknown")


class LdpAdjUnionDiscrim(Enum):
    """
    LdpAdjUnionDiscrim (Enum Class)

    MPLS LDP Hello Type

    .. data:: link_hello = 0

    	Link hello

    .. data:: targeted_hello = 1

    	Targeted hello

    """

    link_hello = Enum.YLeaf(0, "link-hello")

    targeted_hello = Enum.YLeaf(1, "targeted-hello")


class LdpAf(Enum):
    """
    LdpAf (Enum Class)

    Ldp af

    .. data:: ldp_show_af_none = 0

    	No Address Family

    .. data:: ldp_show_af_ipv4 = 1

    	IPv4 AFI

    .. data:: ldp_show_af_ipv6 = 2

    	IPv6 AFI

    .. data:: ldp_show_af_ipv4_ipv6 = 3

    	Both IPv4/IPv6 AFIs

    """

    ldp_show_af_none = Enum.YLeaf(0, "ldp-show-af-none")

    ldp_show_af_ipv4 = Enum.YLeaf(1, "ldp-show-af-ipv4")

    ldp_show_af_ipv6 = Enum.YLeaf(2, "ldp-show-af-ipv6")

    ldp_show_af_ipv4_ipv6 = Enum.YLeaf(3, "ldp-show-af-ipv4-ipv6")


class LdpAfId(Enum):
    """
    LdpAfId (Enum Class)

    Ldp af id

    .. data:: ldp_af_id_none = 0

    	No Address Family

    .. data:: ldp_af_id_ipv4 = 2

    	IPv4 AFI

    .. data:: ldp_af_id_ipv6 = 10

    	IPv6 AFI

    """

    ldp_af_id_none = Enum.YLeaf(0, "ldp-af-id-none")

    ldp_af_id_ipv4 = Enum.YLeaf(2, "ldp-af-id-ipv4")

    ldp_af_id_ipv6 = Enum.YLeaf(10, "ldp-af-id-ipv6")


class LdpFwdUnlblRsn(Enum):
    """
    LdpFwdUnlblRsn (Enum Class)

    Ldp fwd unlbl rsn

    .. data:: ldp_fwd_labelled = 0

    	ldp fwd labelled

    .. data:: ldp_fwd_un_labelled_vrf_down = 1

    	ldp fwd un labelled vrf down

    .. data:: ldp_fwd_un_labelled_no_nh = 2

    	ldp fwd un labelled no nh

    .. data:: ldp_fwd_un_labelled_recursive_path = 3

    	ldp fwd un labelled recursive path

    .. data:: ldp_fwd_un_labelled_intf_not_ldp = 4

    	ldp fwd un labelled intf not ldp

    .. data:: ldp_fwd_un_labelled_no_rmt = 5

    	ldp fwd un labelled no rmt

    .. data:: ldp_fwd_un_labelled_no_ldp_adj = 6

    	ldp fwd un labelled no ldp adj

    .. data:: ldp_fwd_un_labelled_no_session = 7

    	ldp fwd un labelled no session

    .. data:: ldp_fwd_un_labelled_unknown = 8

    	ldp fwd un labelled unknown

    """

    ldp_fwd_labelled = Enum.YLeaf(0, "ldp-fwd-labelled")

    ldp_fwd_un_labelled_vrf_down = Enum.YLeaf(1, "ldp-fwd-un-labelled-vrf-down")

    ldp_fwd_un_labelled_no_nh = Enum.YLeaf(2, "ldp-fwd-un-labelled-no-nh")

    ldp_fwd_un_labelled_recursive_path = Enum.YLeaf(3, "ldp-fwd-un-labelled-recursive-path")

    ldp_fwd_un_labelled_intf_not_ldp = Enum.YLeaf(4, "ldp-fwd-un-labelled-intf-not-ldp")

    ldp_fwd_un_labelled_no_rmt = Enum.YLeaf(5, "ldp-fwd-un-labelled-no-rmt")

    ldp_fwd_un_labelled_no_ldp_adj = Enum.YLeaf(6, "ldp-fwd-un-labelled-no-ldp-adj")

    ldp_fwd_un_labelled_no_session = Enum.YLeaf(7, "ldp-fwd-un-labelled-no-session")

    ldp_fwd_un_labelled_unknown = Enum.YLeaf(8, "ldp-fwd-un-labelled-unknown")


class LdpIgpSyncDownReason(Enum):
    """
    LdpIgpSyncDownReason (Enum Class)

    Reason IGP Sync Not Achieved

    .. data:: igp_sync_down_reason_not_applicable = 0

    	Not Applicable

    .. data:: no_hello_adjacency = 1

    	No hello adjacency

    .. data:: no_peer_session = 2

    	No peer session

    .. data:: initial_update_to_peer_not_done = 3

    	Initial update to peer not done yet

    .. data:: initial_update_from_peer_not_received = 4

    	Initial update from peer not received yet

    .. data:: internal_reason = 5

    	Internal reason

    """

    igp_sync_down_reason_not_applicable = Enum.YLeaf(0, "igp-sync-down-reason-not-applicable")

    no_hello_adjacency = Enum.YLeaf(1, "no-hello-adjacency")

    no_peer_session = Enum.YLeaf(2, "no-peer-session")

    initial_update_to_peer_not_done = Enum.YLeaf(3, "initial-update-to-peer-not-done")

    initial_update_from_peer_not_received = Enum.YLeaf(4, "initial-update-from-peer-not-received")

    internal_reason = Enum.YLeaf(5, "internal-reason")


class LdpIgpSyncState(Enum):
    """
    LdpIgpSyncState (Enum Class)

    IGP Sync State

    .. data:: isync_ready = 0

    	Acheived

    .. data:: isync_not_ready = 1

    	Not acheived

    .. data:: isync_deferred = 2

    	Deferred due to interface delay or global

    	restart delay

    """

    isync_ready = Enum.YLeaf(0, "isync-ready")

    isync_not_ready = Enum.YLeaf(1, "isync-not-ready")

    isync_deferred = Enum.YLeaf(2, "isync-deferred")


class LdpRoutePathFlags(Enum):
    """
    LdpRoutePathFlags (Enum Class)

    Route path flags

    .. data:: ip_path_no_flag = 0

    	A primary path with no special flag/attribute

    .. data:: ip_path_protected = 1

    	A primary path with LFA FRR protection

    .. data:: ip_path_backup = 2

    	A non-primary local LFA FRR (pure) backup path

    .. data:: ip_path_backup_remote = 3

    	A non-primary remote LFA FRR (pure) backup path

    .. data:: ip_path_bgp_backup = 4

    	A non-primary BGP backup path

    """

    ip_path_no_flag = Enum.YLeaf(0, "ip-path-no-flag")

    ip_path_protected = Enum.YLeaf(1, "ip-path-protected")

    ip_path_backup = Enum.YLeaf(2, "ip-path-backup")

    ip_path_backup_remote = Enum.YLeaf(3, "ip-path-backup-remote")

    ip_path_bgp_backup = Enum.YLeaf(4, "ip-path-bgp-backup")


class LdpRoutePathLblOwner(Enum):
    """
    LdpRoutePathLblOwner (Enum Class)

    Route path label owner

    .. data:: ip_path_lbl_owner_none = 0

    	No label and no owner

    .. data:: ip_path_lbl_owner_ldp = 1

    	Path outgoing label owned by LDP

    .. data:: ip_path_lbl_owner_bgp = 2

    	Path outgoing label owned by BGP

    """

    ip_path_lbl_owner_none = Enum.YLeaf(0, "ip-path-lbl-owner-none")

    ip_path_lbl_owner_ldp = Enum.YLeaf(1, "ip-path-lbl-owner-ldp")

    ip_path_lbl_owner_bgp = Enum.YLeaf(2, "ip-path-lbl-owner-bgp")


class LocalLabelState(Enum):
    """
    LocalLabelState (Enum Class)

    MPLS LDP Local Label State Type

    .. data:: local_label_state_none = 1

    	None

    .. data:: local_label_state_assigned = 2

    	Assigned

    .. data:: local_label_state_withdrawn = 3

    	Withdrawn

    """

    local_label_state_none = Enum.YLeaf(1, "local-label-state-none")

    local_label_state_assigned = Enum.YLeaf(2, "local-label-state-assigned")

    local_label_state_withdrawn = Enum.YLeaf(3, "local-label-state-withdrawn")


class MgmtLdpNbrBgpAdvtState(Enum):
    """
    MgmtLdpNbrBgpAdvtState (Enum Class)

    MPLS LDP Neighbor BGP Label Advertisement State

    Type

    .. data:: not_applicable = 0

    	Not applicable

    .. data:: permit = 1

    	Advertisement permitted

    .. data:: deny = 2

    	Advertisement denied

    """

    not_applicable = Enum.YLeaf(0, "not-applicable")

    permit = Enum.YLeaf(1, "permit")

    deny = Enum.YLeaf(2, "deny")


class MgmtLdpNsrPeerLdpSyncNackRsn(Enum):
    """
    MgmtLdpNsrPeerLdpSyncNackRsn (Enum Class)

    Mgmt ldp nsr peer ldp sync nack rsn

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_none = 0

    	mgmt ldp nsr peer ldp sync nack rsn none

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_tbl_id_mismatch = 1

    	mgmt ldp nsr peer ldp sync nack rsn tbl id

    	mismatch

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_pp_exists = 2

    	mgmt ldp nsr peer ldp sync nack rsn pp exists

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_missing_elem = 3

    	mgmt ldp nsr peer ldp sync nack rsn missing

    	elem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_p_end_sock = 4

    	mgmt ldp nsr peer ldp sync nack rsn no p end

    	sock

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_p_end_sock_not_synced = 5

    	mgmt ldp nsr peer ldp sync nack rsn p end sock

    	not synced

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_add = 6

    	mgmt ldp nsr peer ldp sync nack rsn err adj add

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_dhcb_add = 7

    	mgmt ldp nsr peer ldp sync nack rsn err dhcb

    	add

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_enomem = 8

    	mgmt ldp nsr peer ldp sync nack rsn enomem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tp_create = 9

    	mgmt ldp nsr peer ldp sync nack rsn err tp

    	create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pp_create = 10

    	mgmt ldp nsr peer ldp sync nack rsn err pp

    	create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_addr_bind = 11

    	mgmt ldp nsr peer ldp sync nack rsn err addr

    	bind

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_bad_pie = 12

    	mgmt ldp nsr peer ldp sync nack rsn err rx bad

    	pie

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_notif = 13

    	mgmt ldp nsr peer ldp sync nack rsn err rx

    	notif

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_unexp_open = 14

    	mgmt ldp nsr peer ldp sync nack rsn err rx

    	unexp open

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_unexp_peer_down = 15

    	mgmt ldp nsr peer ldp sync nack rsn err unexp

    	peer down

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_not_found = 16

    	mgmt ldp nsr peer ldp sync nack rsn err app not

    	found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_invalid = 17

    	mgmt ldp nsr peer ldp sync nack rsn err app

    	invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_grp_not_found = 18

    	mgmt ldp nsr peer ldp sync nack rsn err adj grp

    	not found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_invalid_elem = 19

    	mgmt ldp nsr peer ldp sync nack rsn invalid

    	elem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_data_invalid = 20

    	mgmt ldp nsr peer ldp sync nack rsn err app

    	data invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_invalid_per_idx = 21

    	mgmt ldp nsr peer ldp sync nack rsn err invalid

    	per idx

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pfx_not_found = 22

    	mgmt ldp nsr peer ldp sync nack rsn err pfx not

    	found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_bm_size_invalid = 23

    	mgmt ldp nsr peer ldp sync nack rsn err bm size

    	invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adv_bm_clear = 24

    	mgmt ldp nsr peer ldp sync nack rsn err adv bm

    	clear

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tcp_struct_create = 25

    	mgmt ldp nsr peer ldp sync nack rsn err tcp

    	struct create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_ctx = 26

    	mgmt ldp nsr peer ldp sync nack rsn no ctx

    """

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-none")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_tbl_id_mismatch = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-tbl-id-mismatch")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_pp_exists = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-pp-exists")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_missing_elem = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-missing-elem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_p_end_sock = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-no-p-end-sock")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_p_end_sock_not_synced = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-p-end-sock-not-synced")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_add = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adj-add")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_dhcb_add = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-dhcb-add")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_enomem = Enum.YLeaf(8, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-enomem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tp_create = Enum.YLeaf(9, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-tp-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pp_create = Enum.YLeaf(10, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-pp-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_addr_bind = Enum.YLeaf(11, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-addr-bind")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_bad_pie = Enum.YLeaf(12, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-bad-pie")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_notif = Enum.YLeaf(13, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-notif")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_unexp_open = Enum.YLeaf(14, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-unexp-open")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_unexp_peer_down = Enum.YLeaf(15, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-unexp-peer-down")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_not_found = Enum.YLeaf(16, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_invalid = Enum.YLeaf(17, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_grp_not_found = Enum.YLeaf(18, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adj-grp-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_invalid_elem = Enum.YLeaf(19, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-invalid-elem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_data_invalid = Enum.YLeaf(20, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-data-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_invalid_per_idx = Enum.YLeaf(21, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-invalid-per-idx")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pfx_not_found = Enum.YLeaf(22, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-pfx-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_bm_size_invalid = Enum.YLeaf(23, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-bm-size-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adv_bm_clear = Enum.YLeaf(24, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adv-bm-clear")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tcp_struct_create = Enum.YLeaf(25, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-tcp-struct-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_ctx = Enum.YLeaf(26, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-no-ctx")


class MgmtLdpNsrPeerSyncErr(Enum):
    """
    MgmtLdpNsrPeerSyncErr (Enum Class)

    Mgmt ldp nsr peer sync err

    .. data:: mgmt_ldp_nsr_peer_sync_err_none = 0

    	mgmt ldp nsr peer sync err none

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_sync_nack = 1

    	mgmt ldp nsr peer sync err ldp sync nack

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_prep = 2

    	mgmt ldp nsr peer sync err sync prep

    .. data:: mgmt_ldp_nsr_peer_sync_err_tcp_peer = 3

    	mgmt ldp nsr peer sync err tcp peer

    .. data:: mgmt_ldp_nsr_peer_sync_err_tcp_gbl = 4

    	mgmt ldp nsr peer sync err tcp gbl

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_peer = 5

    	mgmt ldp nsr peer sync err ldp peer

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_gbl = 6

    	mgmt ldp nsr peer sync err ldp gbl

    .. data:: mgmt_ldp_nsr_peer_sync_err_app_fail = 7

    	mgmt ldp nsr peer sync err app fail

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase1 = 8

    	mgmt ldp nsr peer sync err sync tcp phase1

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase2 = 9

    	mgmt ldp nsr peer sync err sync tcp phase2

    """

    mgmt_ldp_nsr_peer_sync_err_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-sync-err-none")

    mgmt_ldp_nsr_peer_sync_err_ldp_sync_nack = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-sync-err-ldp-sync-nack")

    mgmt_ldp_nsr_peer_sync_err_sync_prep = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-sync-err-sync-prep")

    mgmt_ldp_nsr_peer_sync_err_tcp_peer = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-sync-err-tcp-peer")

    mgmt_ldp_nsr_peer_sync_err_tcp_gbl = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-sync-err-tcp-gbl")

    mgmt_ldp_nsr_peer_sync_err_ldp_peer = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-sync-err-ldp-peer")

    mgmt_ldp_nsr_peer_sync_err_ldp_gbl = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-sync-err-ldp-gbl")

    mgmt_ldp_nsr_peer_sync_err_app_fail = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-sync-err-app-fail")

    mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase1 = Enum.YLeaf(8, "mgmt-ldp-nsr-peer-sync-err-sync-tcp-phase1")

    mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase2 = Enum.YLeaf(9, "mgmt-ldp-nsr-peer-sync-err-sync-tcp-phase2")


class MgmtLdpNsrPeerSyncState(Enum):
    """
    MgmtLdpNsrPeerSyncState (Enum Class)

    Mgmt ldp nsr peer sync state

    .. data:: mgmt_ldp_nsr_peer_sync_st_none = 0

    	mgmt ldp nsr peer sync st none

    .. data:: mgmt_ldp_nsr_peer_sync_st_wait = 1

    	mgmt ldp nsr peer sync st wait

    .. data:: mgmt_ldp_nsr_peer_sync_st_ready = 2

    	mgmt ldp nsr peer sync st ready

    .. data:: mgmt_ldp_nsr_peer_sync_st_prep = 3

    	mgmt ldp nsr peer sync st prep

    .. data:: mgmt_ldp_nsr_peer_sync_st_app_wait = 4

    	mgmt ldp nsr peer sync st app wait

    .. data:: mgmt_ldp_nsr_peer_sync_st_oper = 5

    	mgmt ldp nsr peer sync st oper

    .. data:: mgmt_ldp_nsr_peer_sync_st_tcp_phase1 = 6

    	mgmt ldp nsr peer sync st tcp phase1

    .. data:: mgmt_ldp_nsr_peer_sync_st_tcp_phase2 = 7

    	mgmt ldp nsr peer sync st tcp phase2

    """

    mgmt_ldp_nsr_peer_sync_st_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-sync-st-none")

    mgmt_ldp_nsr_peer_sync_st_wait = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-sync-st-wait")

    mgmt_ldp_nsr_peer_sync_st_ready = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-sync-st-ready")

    mgmt_ldp_nsr_peer_sync_st_prep = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-sync-st-prep")

    mgmt_ldp_nsr_peer_sync_st_app_wait = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-sync-st-app-wait")

    mgmt_ldp_nsr_peer_sync_st_oper = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-sync-st-oper")

    mgmt_ldp_nsr_peer_sync_st_tcp_phase1 = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-sync-st-tcp-phase1")

    mgmt_ldp_nsr_peer_sync_st_tcp_phase2 = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-sync-st-tcp-phase2")


class MplsLdpOperAfName(Enum):
    """
    MplsLdpOperAfName (Enum Class)

    Mpls ldp oper af name

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    .. data:: all = 65535

    	All

    """

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")

    all = Enum.YLeaf(65535, "all")


class ShowNsrState(Enum):
    """
    ShowNsrState (Enum Class)

    NSR State Type

    .. data:: nsr_ready = 0

    	NSR ready

    .. data:: nsr_not_ready = 1

    	NSR not ready

    .. data:: nsr_na = 2

    	NSR not applicable

    """

    nsr_ready = Enum.YLeaf(0, "nsr-ready")

    nsr_not_ready = Enum.YLeaf(1, "nsr-not-ready")

    nsr_na = Enum.YLeaf(2, "nsr-na")



class MplsLdp(Entity):
    """
    MPLS LDP operational data
    
    .. attribute:: global_
    
    	Global MPLS LDP operational data
    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global>`
    
    .. attribute:: nodes
    
    	Location MPLS LDP operational data
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes>`
    
    

    """

    _prefix = 'mpls-ldp-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(MplsLdp, self).__init__()
        self._top_entity = None

        self.yang_name = "mpls-ldp"
        self.yang_parent_name = "Cisco-IOS-XR-mpls-ldp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("global", ("global_", MplsLdp.Global)), ("nodes", ("nodes", MplsLdp.Nodes))])
        self._leafs = OrderedDict()

        self.global_ = MplsLdp.Global()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"

        self.nodes = MplsLdp.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(MplsLdp, [], name, value)


    class Global(Entity):
        """
        Global MPLS LDP operational data
        
        .. attribute:: standby
        
        	Standby MPLS LDP operational data
        	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby>`
        
        .. attribute:: active
        
        	Active MPLS LDP operational data
        	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active>`
        
        

        """

        _prefix = 'mpls-ldp-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(MplsLdp.Global, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "mpls-ldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("standby", ("standby", MplsLdp.Global.Standby)), ("active", ("active", MplsLdp.Global.Active))])
            self._leafs = OrderedDict()

            self.standby = MplsLdp.Global.Standby()
            self.standby.parent = self
            self._children_name_map["standby"] = "standby"

            self.active = MplsLdp.Global.Active()
            self.active.parent = self
            self._children_name_map["active"] = "active"
            self._segment_path = lambda: "global"
            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(MplsLdp.Global, [], name, value)


        class Standby(Entity):
            """
            Standby MPLS LDP operational data
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:  :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:  :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.BindingsSummaryAll>`
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:  :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:  :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:  :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DiscoverySummaryAll>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(MplsLdp.Global.Standby, self).__init__()

                self.yang_name = "standby"
                self.yang_parent_name = "global"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default-vrf", ("default_vrf", MplsLdp.Global.Standby.DefaultVrf)), ("forwarding-summary-all", ("forwarding_summary_all", MplsLdp.Global.Standby.ForwardingSummaryAll)), ("bindings-summary-all", ("bindings_summary_all", MplsLdp.Global.Standby.BindingsSummaryAll)), ("ato-mdb-table-entries", ("ato_mdb_table_entries", MplsLdp.Global.Standby.AtoMdbTableEntries)), ("nsr-summary-all", ("nsr_summary_all", MplsLdp.Global.Standby.NsrSummaryAll)), ("summary", ("summary", MplsLdp.Global.Standby.Summary)), ("vrfs", ("vrfs", MplsLdp.Global.Standby.Vrfs)), ("discovery-summary-all", ("discovery_summary_all", MplsLdp.Global.Standby.DiscoverySummaryAll))])
                self._leafs = OrderedDict()

                self.default_vrf = MplsLdp.Global.Standby.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"

                self.forwarding_summary_all = MplsLdp.Global.Standby.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"

                self.bindings_summary_all = MplsLdp.Global.Standby.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"

                self.ato_mdb_table_entries = MplsLdp.Global.Standby.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"

                self.nsr_summary_all = MplsLdp.Global.Standby.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"

                self.summary = MplsLdp.Global.Standby.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.vrfs = MplsLdp.Global.Standby.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"

                self.discovery_summary_all = MplsLdp.Global.Standby.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._segment_path = lambda: "standby"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(MplsLdp.Global.Standby, [], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Capabilities>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Summary>`
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Backoffs>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Parameters>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.LdpId>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Statistics>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Global.Standby.DefaultVrf.Capabilities)), ("summary", ("summary", MplsLdp.Global.Standby.DefaultVrf.Summary)), ("afs", ("afs", MplsLdp.Global.Standby.DefaultVrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Global.Standby.DefaultVrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Global.Standby.DefaultVrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Global.Standby.DefaultVrf.Nsr)), ("parameters", ("parameters", MplsLdp.Global.Standby.DefaultVrf.Parameters)), ("issu", ("issu", MplsLdp.Global.Standby.DefaultVrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Global.Standby.DefaultVrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Global.Standby.DefaultVrf.LdpId)), ("statistics", ("statistics", MplsLdp.Global.Standby.DefaultVrf.Statistics))])
                    self._leafs = OrderedDict()

                    self.graceful_restart = MplsLdp.Global.Standby.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.capabilities = MplsLdp.Global.Standby.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"

                    self.summary = MplsLdp.Global.Standby.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.afs = MplsLdp.Global.Standby.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"

                    self.neighbor_briefs = MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                    self.backoff_parameters = MplsLdp.Global.Standby.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"

                    self.backoffs = MplsLdp.Global.Standby.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"

                    self.nsr = MplsLdp.Global.Standby.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"

                    self.parameters = MplsLdp.Global.Standby.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"

                    self.issu = MplsLdp.Global.Standby.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"

                    self.neighbor_capabilities = MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                    self.neighbors = MplsLdp.Global.Standby.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"

                    self.ldp_id = MplsLdp.Global.Standby.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"

                    self.statistics = MplsLdp.Global.Standby.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._segment_path = lambda: "default-vrf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf, [], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.Vrf>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\: bool
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.Vrf)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor))])
                        self._leafs = OrderedDict([
                            ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                            ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                        ])
                        self.is_forwarding_state_hold_timer_running = None
                        self.forwarding_state_hold_timer_remaining_seconds = None

                        self.vrf = MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.Vrf, [u'name', u'id'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\: bool
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\: bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\: bool
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                            self._leafs = OrderedDict([
                                ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                            ])
                            self.connect_count = None
                            self.is_neighbor_up = None
                            self.is_liveness_timer_running = None
                            self.liveness_timer_remaining_seconds = None
                            self.is_recovery_timer_running = None
                            self.recovery_timer_remaining_seconds = None
                            self.down_nbr_flap_count = None
                            self.down_nbr_flags = None
                            self.down_nbr_down_reason = None

                            self.gr_peer = MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"

                            self.down_nbr_interface = YList(self)
                            self.down_nbr_address = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.ldp_id = None
                                self._segment_path = lambda: "gr-peer"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                ])
                                self.address_family = None
                                self.interface_handle = None
                                self._segment_path = lambda: "down-nbr-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "down-nbr-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability))])
                        self._leafs = OrderedDict()

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  (key)
                        
                        	The capability type (IANA assigned)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability.Capability_>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['capability_type']
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability.Capability_))])
                            self._leafs = OrderedDict([
                                ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                            ])
                            self.capability_type = None
                            self.capability_owner = None

                            self.capability = MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability.Capability_()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/capabilities/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                        class Capability_(Entity):
                            """
                            Capability information
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability.Capability_, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Summary.Vrf>`
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Summary.Common>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Summary.Vrf)), ("common", ("common", MplsLdp.Global.Standby.DefaultVrf.Summary.Common))])
                        self._leafs = OrderedDict()

                        self.vrf = MplsLdp.Global.Standby.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.common = MplsLdp.Global.Standby.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._segment_path = lambda: "summary"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Summary, [], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/summary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Summary.Vrf, [u'name', u'id'], name, value)


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                            ])
                            self.address_families = None
                            self.number_of_ipv4af = None
                            self.number_of_ipv6af = None
                            self.number_of_neighbors = None
                            self.number_of_nsr_synced_neighbors = None
                            self.number_of_graceful_restart_neighbors = None
                            self.number_of_downstream_on_demand_neighbors = None
                            self.number_of_ipv4_hello_adj = None
                            self.number_of_ipv6_hello_adj = None
                            self.number_of_ipv4_routes = None
                            self.number_of_ipv6_routes = None
                            self.number_of_ipv4_local_addresses = None
                            self.number_of_ipv6_local_addresses = None
                            self.number_of_ldp_interfaces = None
                            self.number_of_ipv4ldp_interfaces = None
                            self.number_of_ipv6ldp_interfaces = None
                            self.number_of_bindings_ipv4 = None
                            self.number_of_bindings_ipv6 = None
                            self.number_of_local_bindings_ipv4 = None
                            self.number_of_local_bindings_ipv6 = None
                            self.number_of_remote_bindings_ipv4 = None
                            self.number_of_remote_bindings_ipv6 = None
                            self._segment_path = lambda: "common"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/summary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("af", ("af", MplsLdp.Global.Standby.DefaultVrf.Afs.Af))])
                        self._leafs = OrderedDict()

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  (key)
                        
                        	Address Family name
                        	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                            ])
                            self.af_name = None

                            self.interface_summary = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"

                            self.bindings = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"

                            self.igp = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"

                            self.bindings_summary = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"

                            self.interfaces = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"

                            self.discovery = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"

                            self.forwardings = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"

                            self.bindings_advertise_spec = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                            self.forwarding_summary = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/afs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                    ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                    ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                    ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                    ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                    ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                    ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                    ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                ])
                                self.known_ip_interface_count = None
                                self.known_ip_interface_ldp_enabled = None
                                self.ldp_configured_attached_interface = None
                                self.ldp_configured_te_interface = None
                                self.forward_references = None
                                self.auto_config_disabled = None
                                self.auto_config = None
                                self.auto_config_forward_reference_interfaces = None
                                self._segment_path = lambda: "interface-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding))])
                                self._leafs = OrderedDict()

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\: bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\: bool
                                
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\: str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\: str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\: bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\: bool
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                        ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                        ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                        ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                        ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                        ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                        ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                        ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                        ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None
                                    self.local_label = None
                                    self.le_local_binding_revision = None
                                    self.le_local_label_state = None
                                    self.is_no_route = None
                                    self.label_oor = None
                                    self.advertise_prefix_acl = None
                                    self.advertise_tsr_acl = None
                                    self.config_enforced_local_label_value = None
                                    self.is_elc = None

                                    self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.remote_binding = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.peers_acked = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                        self._leafs = OrderedDict([
                                            ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.remote_label = None
                                        self.is_stale = None
                                        self.is_elc = None

                                        self.assigning_peer_ldp_ident = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._segment_path = lambda: "remote-binding"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-advertised-to"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-acked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart))])
                                self._leafs = OrderedDict()

                                self.syncs = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"

                                self.sync_delay_restart = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._segment_path = lambda: "igp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp, [], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync))])
                                    self._leafs = OrderedDict()

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)), ("peers", ("peers", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                            ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                            ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                            ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                            ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                        ])
                                        self.interface_name = None
                                        self.interface_name_xr = None
                                        self.igp_sync_state = None
                                        self.igp_sync_delay = None
                                        self.is_delay_timer_running = None
                                        self.delay_timer_remaining = None
                                        self.igp_sync_down_reason = None

                                        self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.peers = YList(self)
                                        self.gr_only_peer = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, [u'name', u'id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_gr_enabled = None
                                            self._segment_path = lambda: "peers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_chkpt_created = None
                                            self._segment_path = lambda: "gr-only-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\: bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\: bool
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                        ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                        ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                        ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                    ])
                                    self.configured = None
                                    self.delay_secs = None
                                    self.timer_running = None
                                    self.remaining_secs = None
                                    self._segment_path = lambda: "sync-delay-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf)), ("bind-af", ("bind_af", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                    ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                    ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                    ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                    ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                    ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                    ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                    ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                    ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                ])
                                self.address_family = None
                                self.binding_no_route = None
                                self.binding_local_no_route = None
                                self.binding_local_null = None
                                self.binding_local_implicit_null = None
                                self.binding_local_explicit_null = None
                                self.binding_local_non_null = None
                                self.binding_local_oor = None
                                self.lowest_allocated_label = None
                                self.highest_allocated_label = None

                                self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf, [u'name', u'id'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                        ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                        ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                        ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                        ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.last_lib_update = None
                                    self.lib_minimum_revision_sent_all = None
                                    self.binding_total = None
                                    self.binding_local = None
                                    self.binding_remote = None
                                    self._segment_path = lambda: "bind-af"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  (key)
                                
                                	The Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\: str
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\: bool
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\: bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\: bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\: bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                        ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                        ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                        ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                        ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.interface = None
                                    self.interface_name_xr = None
                                    self.ldp_enabled = None
                                    self.is_im_stale = None
                                    self.ldp_config_mode = None
                                    self.ldp_autoconfig_disable = None

                                    self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.te_mesh_grp = YList(self)
                                    self.auto_config = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, [u'name', u'id'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                            ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                            ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                        ])
                                        self.ldp_te_mesh_group_all_cfgd = None
                                        self.ldp_mesh_group_enabled = None
                                        self.te_mesh_group_id = None
                                        self._segment_path = lambda: "te-mesh-grp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                        ])
                                        self.tuple = None
                                        self._segment_path = lambda: "auto-config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats))])
                                self._leafs = OrderedDict()

                                self.link_hellos = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"

                                self.summary = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"

                                self.targeted_hellos = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                self.brief = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"

                                self.stats = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._segment_path = lambda: "discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery, [], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                    self._leafs = OrderedDict()

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.next_hello = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.quick_start_disabled = None

                                        self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.hello_information = YList(self)
                                        self.discovery_link_af = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, [u'name', u'id'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\: bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\: bool
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.neighbor_ldp_identifier = None
                                            self.is_no_route = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.is_targeted = None
                                            self.session_up = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_bringup_failure_reason = None

                                            self.neighbor_src_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                            self.neighbor_transport_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                            self.target = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ])
                                            self.interval = None

                                            self.local_src_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"

                                            self.local_transport_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._segment_path = lambda: "discovery-link-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\: str
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                    ])
                                    self.local_ldp_id = None
                                    self.num_of_ldp_interfaces = None
                                    self.num_of_active_ldp_interfaces = None
                                    self.num_of_lnk_disc_xmit = None
                                    self.num_of_tgt_disc_xmit = None
                                    self.num_of_lnk_disc_recv = None
                                    self.num_of_tgt_disc_recv = None
                                    self.num_of_disc_with_bad_addr_recv = None
                                    self.num_of_disc_with_bad_hello_pdu = None
                                    self.num_of_disc_with_bad_xport_addr = None
                                    self.num_of_disc_with_same_router_id = None
                                    self.num_of_disc_with_wrong_router_id = None

                                    self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, [u'name', u'id'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                    self._leafs = OrderedDict()

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\: str
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\: bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\: str
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                        self._leafs = OrderedDict([
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                            ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                            ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                            ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                            ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                            ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                            ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                            ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                        ])
                                        self.local_address = None
                                        self.target_address = None
                                        self.state = None
                                        self.adjacency_ldp_identifier = None
                                        self.interval = None
                                        self.next_hello = None
                                        self.hold_time = None
                                        self.local_hold_time = None
                                        self.neighbor_hold_time = None
                                        self.disc_expiry = None
                                        self.quick_start_disabled = None
                                        self.established_time = None
                                        self.established_age = None
                                        self.session_up = None
                                        self.session_bringup_failure_reason = None

                                        self.dhcb_local_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                        self.dhcb_target_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-target-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                            ])
                                            self.last_session_down_reason = None
                                            self.last_session_down_time = None
                                            self.last_session_up_time = None
                                            self._segment_path = lambda: "last-session-down-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                    self._leafs = OrderedDict()

                                    self.link_hello_briefs = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                    self.targeted_hello_briefs = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._segment_path = lambda: "brief"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief, [], name, value)


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.address_family = None
                                            self.address_family_set = None
                                            self.interface = None
                                            self.interface_name_xr = None

                                            self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.address_family = None

                                            self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.dhcb_target_address = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat))])
                                    self._leafs = OrderedDict()

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                            ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                            ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                            ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.adjacency_group_up_time = None
                                        self.tcp_open_count = None
                                        self.tcp_arb_chg_count = None
                                        self.tcp_role = None
                                        self._segment_path = lambda: "stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding))])
                                self._leafs = OrderedDict()

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.table_id = None
                                    self.prefix_length = None

                                    self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.route = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\: bool
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                            ])
                                            self.version = None
                                            self.priority = None
                                            self.source = None
                                            self.type = None
                                            self.flags = None
                                            self.metric = None
                                            self.is_local_vrf_leaked = None
                                            self.routing_update_count = None
                                            self.routing_update_timestamp = None
                                            self.routing_update_age = None
                                            self.sr_local_label = None
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                            ])
                                            self.local_label = None
                                            self.forwarding_update_count = None
                                            self.forwarding_update_timestamp = None
                                            self.forwarding_update_age = None
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\: bool
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self.nh_is_overriden = None
                                            self.nexthop_id = None
                                            self.next_hop_table_id = None
                                            self.flags = None
                                            self.load_metric = None
                                            self.path_id = None
                                            self.bkup_path_id = None
                                            self.path_flags = None

                                            self.next_hop = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.remote_lfa = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\: bool
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                    ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None
                                                self.needs_tldp = None
                                                self.has_q_node = None

                                                self.remote_p_node_id = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                self.remote_q_node_id = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-p-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-q-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                            self._leafs = OrderedDict()

                                            self.mpls_outgoing_info = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                            self.remote_lfa = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                self._leafs = OrderedDict([
                                                    ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                    ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                    ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                    ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                    ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                    ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ])
                                                self.out_label = None
                                                self.out_label_rsn = None
                                                self.out_label_type = None
                                                self.out_label_owner = None
                                                self.is_from_graceful_restartable_neighbor = None
                                                self.is_stale = None

                                                self.nexthop_peer_ldp_ident = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._segment_path = lambda: "mpls-outgoing-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                    ])
                                                    self.lsr_id = None
                                                    self.label_space_id = None
                                                    self.ldp_id = None
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None

                                                self.mpls_outgoing_info = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                    self._leafs = OrderedDict()

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                        self._leafs = OrderedDict([
                                                            ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                            ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                            ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                            ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                            ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                        ])
                                                        self.out_label = None
                                                        self.out_label_rsn = None
                                                        self.out_label_type = None
                                                        self.out_label_owner = None
                                                        self.is_from_graceful_restartable_neighbor = None
                                                        self.is_stale = None

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._segment_path = lambda: "stack"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                            ])
                                                            self.lsr_id = None
                                                            self.label_space_id = None
                                                            self.ldp_id = None
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                self._leafs = OrderedDict()

                                self.allocation_acl = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\: bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                    ])
                                    self.has_acl = None
                                    self.prefix_acl = None
                                    self.is_host_route_only = None
                                    self._segment_path = lambda: "allocation-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                    ])
                                    self.prefix_acl = None
                                    self.peer_acl = None
                                    self._segment_path = lambda: "advt-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\: bool
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)), ("rws", ("rws", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws))])
                                self._leafs = OrderedDict([
                                    ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                    ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                    ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                    ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                ])
                                self.is_lsd_bound = None
                                self.fsht = None
                                self.intfs = None
                                self.lbls = None

                                self.vrf = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.rws = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._segment_path = lambda: "forwarding-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, [u'name', u'id'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                    self._leafs = OrderedDict()

                                    self.pfxs = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"

                                    self.nhs = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._segment_path = lambda: "rws"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                        self._leafs = OrderedDict([
                                            ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                            ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                            ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                        ])
                                        self.total_pfxs = None
                                        self.ecmp_pfxs = None
                                        self.protected_pfxs = None

                                        self.labeled_pfxs_aggr = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                        self.labeled_pfxs_primary = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                        self.labeled_pfxs_backup = MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._segment_path = lambda: "pfxs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-aggr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                            ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                            ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                            ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                            ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                            ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                        ])
                                        self.total_paths = None
                                        self.protected_paths = None
                                        self.backup_paths = None
                                        self.remote_backup_paths = None
                                        self.labeled_paths = None
                                        self.labeled_backup_paths = None
                                        self._segment_path = lambda: "nhs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief))])
                        self._leafs = OrderedDict()

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\: bool
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.is_graceful_restartable = None
                            self.nsr_state = None
                            self.up_time_seconds = None

                            self.vrf = MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, [u'name', u'id'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                    ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                    ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                ])
                                self.address_family = None
                                self.num_of_nbr_discovery = None
                                self.num_of_nbr_addresses = None
                                self.num_of_nbr_lbl = None
                                self._segment_path = lambda: "nbr-br-af-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                            ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                        ])
                        self.initial_seconds = None
                        self.maximum_seconds = None
                        self._segment_path = lambda: "backoff-parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Global.Standby.DefaultVrf.Backoffs.Backoff))])
                        self._leafs = OrderedDict()

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.backoff_seconds = None
                            self.waiting_seconds = None
                            self._segment_path = lambda: "backoff"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/backoffs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.nsr_pending = MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"

                        self.ha_summary = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "nsr"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr, [], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_neighbors = MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "nsr-pending"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending, [], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-global/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\: bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\: bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\: bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\: bool
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\: bool
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\: bool
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Global.Standby.DefaultVrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter))])
                        self._leafs = OrderedDict([
                            ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                            ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                            ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                            ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                            ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                            ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                            ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                            ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                            ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                            ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                            ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                            ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                            ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                            ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                            ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                            ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                            ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                            ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                            ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                            ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                        ])
                        self.role_is_active = None
                        self.global_md5_password_enabled = None
                        self.protocol_version = None
                        self.router_id = None
                        self.keepalive_interval = None
                        self.hello_hold_time = None
                        self.hello_interval = None
                        self.targeted_hello_hold_time = None
                        self.targeted_hello_interval = None
                        self.session_hold_time = None
                        self.housekeeping_timer_interval = None
                        self.le_no_route_timeout = None
                        self.ldp_recovery_timeout = None
                        self.af_binding_withdraw_delay = None
                        self.max_intf_attached = None
                        self.max_intf_te = None
                        self.max_peer = None
                        self.ldp_out_of_mem_state = None
                        self.nsr_enabled = None
                        self.nsr_synced = None
                        self.igp_sync_delay_time_for_interface = None
                        self.igp_sync_delay_time_on_restart = None
                        self.global_discovery_quick_start_disabled = None
                        self.discovery_quick_start_disabled_on_interfaces = None

                        self.graceful_restart_information = MplsLdp.Global.Standby.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\: bool
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                            ])
                            self.is_graceful_restart_configured = None
                            self.graceful_restart_reconnect_timeout = None
                            self.graceful_restart_forwarding_state_hold_time = None
                            self._segment_path = lambda: "graceful-restart-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\: str
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\: str
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\: bool
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                            self._leafs = OrderedDict([
                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                            ])
                            self.address_family = None
                            self.null_label = None
                            self.label_imp_null_override_acl = None
                            self.is_accepting_targeted_hellos = None
                            self.targeted_hello_acl = None

                            self.discovery_transport_address = MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._segment_path = lambda: "address-family-parameter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "discovery-transport-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/address-family-parameter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.ha_summary = MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "issu"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu, [], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-global/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability))])
                        self._leafs = OrderedDict()

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.sent = YList(self)
                            self.received = YList(self)
                            self._segment_path = lambda: "neighbor-capability"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "sent"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "received"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.protocol_information = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"

                            self.tcp_information = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"

                            self.detailed_information = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\: str
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                self._leafs = OrderedDict([
                                    ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                    ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                    ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                    ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                    ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                    ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                ])
                                self.ta_holdtime = None
                                self.ta_state = None
                                self.ta_pies_sent = None
                                self.ta_pies_rcvd = None
                                self.ta_up_time_seconds = None
                                self.downstream_on_demand = None

                                self.ta_graceful_restart_adjacency = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._segment_path = lambda: "protocol-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\: bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                        ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                        ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                    ])
                                    self.is_graceful_restartable = None
                                    self.reconnect_timeout = None
                                    self.recovery_time = None
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/protocol-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                self._leafs = OrderedDict([
                                    ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                    ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                    ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                ])
                                self.foreign_port = None
                                self.local_port = None
                                self.is_md5_on = None

                                self.foreign_host = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"

                                self.local_host = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._segment_path = lambda: "tcp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "foreign-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "local-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\: bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\: bool
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\: bool
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\: bool
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\: bool
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                self._leafs = OrderedDict([
                                    ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                    ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                    ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                    ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                    ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                    ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                    ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                    ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                    ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                    ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                    ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                    ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                    ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                    ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                    ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                    ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                    ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                    ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                    ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                    ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                    ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                    ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                ])
                                self.peer_holdtime = None
                                self.keep_alive_interval = None
                                self.peer_state = None
                                self.has_ipv4_inbound = None
                                self.inbound_ipv4acl = None
                                self.has_ipv6_inbound = None
                                self.inbound_ipv6acl = None
                                self.has_ipv4_outbound = None
                                self.outbound_ipv4acl = None
                                self.has_ipv6_outbound = None
                                self.outbound_ipv6acl = None
                                self.has_sp = None
                                self.sp_state = None
                                self.sp_has_acl = None
                                self.spacl = None
                                self.sp_has_duration = None
                                self.sp_duration = None
                                self.spht_running = None
                                self.spht_remaining = None
                                self.nsr_sync_state = None
                                self.nsr_last_sync_error = None
                                self.nsr_last_sync_nack_reason = None
                                self.bgp_advertisement_state = None
                                self.advertise_bgp_prefixes = None

                                self.capabilities = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                    self._leafs = OrderedDict()

                                    self.sent = YList(self)
                                    self.received = YList(self)
                                    self._segment_path = lambda: "capabilities"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "sent"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "received"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "client"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv4-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/ipv4-duplicate-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv6-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/ipv6-duplicate-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv4-address-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv6-address-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                        ])
                        self.lsr_id = None
                        self.label_space_id = None
                        self.ldp_id = None
                        self._segment_path = lambda: "ldp-id"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic))])
                        self._leafs = OrderedDict()

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageIn))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.iccp_enabled = None

                            self.message_out = MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"

                            self.message_in = MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._segment_path = lambda: "statistic"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-out"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/statistic/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-in"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/statistic/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.DefaultVrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Vrf>`
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws>`
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\: bool
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.ForwardingSummaryAll.Vrf)), ("rws", ("rws", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws))])
                    self._leafs = OrderedDict([
                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                    ])
                    self.is_lsd_bound = None
                    self.fsht = None
                    self.intfs = None
                    self.lbls = None

                    self.vrf = MplsLdp.Global.Standby.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.rws = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._segment_path = lambda: "forwarding-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Nhs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Nhs))])
                        self._leafs = OrderedDict()

                        self.pfxs = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"

                        self.nhs = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._segment_path = lambda: "rws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws, [], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup))])
                            self._leafs = OrderedDict([
                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                            ])
                            self.total_pfxs = None
                            self.ecmp_pfxs = None
                            self.protected_pfxs = None

                            self.labeled_pfxs_aggr = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                            self.labeled_pfxs_primary = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                            self.labeled_pfxs_backup = MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._segment_path = lambda: "pfxs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-primary"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-backup"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                            ])
                            self.total_paths = None
                            self.protected_paths = None
                            self.backup_paths = None
                            self.remote_backup_paths = None
                            self.labeled_paths = None
                            self.labeled_backup_paths = None
                            self._segment_path = lambda: "nhs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.ForwardingSummaryAll.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.BindingsSummaryAll.Vrf>`
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.BindingsSummaryAll.BindAf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.BindingsSummaryAll.Vrf)), ("bind-af", ("bind_af", MplsLdp.Global.Standby.BindingsSummaryAll.BindAf))])
                    self._leafs = OrderedDict([
                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                    ])
                    self.address_family = None
                    self.binding_no_route = None
                    self.binding_local_no_route = None
                    self.binding_local_null = None
                    self.binding_local_implicit_null = None
                    self.binding_local_explicit_null = None
                    self.binding_local_non_null = None
                    self.binding_local_oor = None
                    self.lowest_allocated_label = None
                    self.highest_allocated_label = None

                    self.vrf = MplsLdp.Global.Standby.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.BindingsSummaryAll, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/bindings-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.BindingsSummaryAll.Vrf, [u'name', u'id'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                        ])
                        self.address_family = None
                        self.last_lib_update = None
                        self.lib_minimum_revision_sent_all = None
                        self.binding_total = None
                        self.binding_local = None
                        self.binding_remote = None
                        self._segment_path = lambda: "bind-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/bindings-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.BindingsSummaryAll.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of  		 :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ato-mdb-table-entry", ("ato_mdb_table_entry", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry))])
                    self._leafs = OrderedDict()

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:  :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fec-info", ("fec_info", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo))])
                        self._leafs = OrderedDict([
                            ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str','str'])),
                            ('fe_ctype', (YLeaf(YType.uint32, 'fe-ctype'), ['int'])),
                            ('pw_id', (YLeaf(YType.uint32, 'pw-id'), ['int'])),
                            ('agi_type', (YLeaf(YType.uint32, 'agi-type'), ['int'])),
                            ('agi', (YLeaf(YType.uint32, 'agi'), ['int'])),
                            ('saii_type', (YLeaf(YType.uint32, 'saii-type'), ['int'])),
                            ('saii_local_id', (YLeaf(YType.str, 'saii-local-id'), ['str','str'])),
                            ('saii_global_id', (YLeaf(YType.uint32, 'saii-global-id'), ['int'])),
                            ('saii_prefix', (YLeaf(YType.str, 'saii-prefix'), ['str'])),
                            ('saii_ac_id', (YLeaf(YType.uint32, 'saii-ac-id'), ['int'])),
                            ('taii_type', (YLeaf(YType.uint32, 'taii-type'), ['int'])),
                            ('taii_local_id', (YLeaf(YType.str, 'taii-local-id'), ['str','str'])),
                            ('taii_global_id', (YLeaf(YType.uint32, 'taii-global-id'), ['int'])),
                            ('taii_prefix', (YLeaf(YType.str, 'taii-prefix'), ['str'])),
                            ('taii_ac_id', (YLeaf(YType.uint32, 'taii-ac-id'), ['int'])),
                            ('peer_id_xr', (YLeaf(YType.str, 'peer-id-xr'), ['str'])),
                            ('mapping_tlv_count', (YLeaf(YType.uint32, 'mapping-tlv-count'), ['int'])),
                            ('notification_tlv_count', (YLeaf(YType.uint32, 'notification-tlv-count'), ['int'])),
                        ])
                        self.peer_id = None
                        self.fe_ctype = None
                        self.pw_id = None
                        self.agi_type = None
                        self.agi = None
                        self.saii_type = None
                        self.saii_local_id = None
                        self.saii_global_id = None
                        self.saii_prefix = None
                        self.saii_ac_id = None
                        self.taii_type = None
                        self.taii_local_id = None
                        self.taii_global_id = None
                        self.taii_prefix = None
                        self.taii_ac_id = None
                        self.peer_id_xr = None
                        self.mapping_tlv_count = None
                        self.notification_tlv_count = None

                        self.fec_info = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._segment_path = lambda: "ato-mdb-table-entry"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry, ['peer_id', 'fe_ctype', 'pw_id', 'agi_type', 'agi', 'saii_type', 'saii_local_id', 'saii_global_id', 'saii_prefix', 'saii_ac_id', 'taii_type', 'taii_local_id', 'taii_global_id', 'taii_prefix', 'taii_ac_id', 'peer_id_xr', 'mapping_tlv_count', 'notification_tlv_count'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:  :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:  :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:  :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:  :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fec128", ("fec128", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128)), ("fec129", ("fec129", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129)), ("fec130", ("fec130", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130))])
                            self._leafs = OrderedDict([
                                ('fe_ctype', (YLeaf(YType.enumeration, 'fe-ctype'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwFec', '')])),
                            ])
                            self.fe_ctype = None

                            self.fec128 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"

                            self.fec129 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"

                            self.fec130 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._segment_path = lambda: "fec-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pseudowire_id', (YLeaf(YType.uint32, 'pseudowire-id'), ['int'])),
                                ])
                                self.pseudowire_id = None
                                self._segment_path = lambda: "fec128"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:  :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi)), ("saii", ("saii", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii)), ("taii", ("taii", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"

                                self.taii = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._segment_path = lambda: "fec129"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/agi/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "taii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi)), ("saii", ("saii", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._segment_path = lambda: "fec130"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/agi/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.NsrSummaryAll.Vrf>`
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.NsrSummaryAll.Sessions>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.NsrSummaryAll.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Standby.NsrSummaryAll.Sessions))])
                    self._leafs = OrderedDict()

                    self.vrf = MplsLdp.Global.Standby.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.sessions = MplsLdp.Global.Standby.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._segment_path = lambda: "nsr-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.NsrSummaryAll, [], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/nsr-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.NsrSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                            ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                            ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                            ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                            ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                            ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                            ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                            ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                            ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                            ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                        ])
                        self.total = None
                        self.nsr_eligible = None
                        self.nsr_state_none = None
                        self.nsr_state_wait = None
                        self.nsr_state_ready = None
                        self.nsr_state_prepare = None
                        self.nsr_state_app_wait = None
                        self.nsr_state_operational = None
                        self.nsr_state_tcp_phase1 = None
                        self.nsr_state_tcp_phase2 = None
                        self._segment_path = lambda: "sessions"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/nsr-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.NsrSummaryAll.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Summary.Common>`
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\: bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\: bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\: bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\: bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\: bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\: bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\: bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\: bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\: bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\: bool
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("common", ("common", MplsLdp.Global.Standby.Summary.Common))])
                    self._leafs = OrderedDict([
                        ('number_of_vrf', (YLeaf(YType.uint32, 'number-of-vrf'), ['int'])),
                        ('number_of_vrf_oper', (YLeaf(YType.uint32, 'number-of-vrf-oper'), ['int'])),
                        ('number_of_interfaces', (YLeaf(YType.uint32, 'number-of-interfaces'), ['int'])),
                        ('number_of_fwd_ref_interfaces', (YLeaf(YType.uint32, 'number-of-fwd-ref-interfaces'), ['int'])),
                        ('number_of_autocfg_interfaces', (YLeaf(YType.uint32, 'number-of-autocfg-interfaces'), ['int'])),
                        ('is_bound_with_sysdb', (YLeaf(YType.boolean, 'is-bound-with-sysdb'), ['bool'])),
                        ('is_registered_with_sysdb', (YLeaf(YType.boolean, 'is-registered-with-sysdb'), ['bool'])),
                        ('is_bound_with_rsi', (YLeaf(YType.boolean, 'is-bound-with-rsi'), ['bool'])),
                        ('is_bound_with_interface_manager', (YLeaf(YType.boolean, 'is-bound-with-interface-manager'), ['bool'])),
                        ('is_registered_with_interface_manager', (YLeaf(YType.boolean, 'is-registered-with-interface-manager'), ['bool'])),
                        ('is_bound_with_ip_arm', (YLeaf(YType.boolean, 'is-bound-with-ip-arm'), ['bool'])),
                        ('is_bound_with_lsd', (YLeaf(YType.boolean, 'is-bound-with-lsd'), ['bool'])),
                        ('is_registered_with_lsd', (YLeaf(YType.boolean, 'is-registered-with-lsd'), ['bool'])),
                        ('is_bound_with_ipv4_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv4-rib'), ['bool'])),
                        ('is_registered_with_ipv4_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv4-rib'), ['bool'])),
                        ('number_of_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-ipv4rib-tables'), ['int'])),
                        ('number_of_registered_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv4rib-tables'), ['int'])),
                        ('is_bound_with_ipv6_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv6-rib'), ['bool'])),
                        ('is_registered_with_ipv6_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv6-rib'), ['bool'])),
                        ('number_of_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-ipv6rib-tables'), ['int'])),
                        ('number_of_registered_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv6rib-tables'), ['int'])),
                        ('is_bound_with_atom', (YLeaf(YType.boolean, 'is-bound-with-atom'), ['bool'])),
                        ('is_bound_with_nsr_mate', (YLeaf(YType.boolean, 'is-bound-with-nsr-mate'), ['bool'])),
                        ('is_nsr_configured', (YLeaf(YType.boolean, 'is-nsr-configured'), ['bool'])),
                        ('is_mldp_registered', (YLeaf(YType.boolean, 'is-mldp-registered'), ['bool'])),
                    ])
                    self.number_of_vrf = None
                    self.number_of_vrf_oper = None
                    self.number_of_interfaces = None
                    self.number_of_fwd_ref_interfaces = None
                    self.number_of_autocfg_interfaces = None
                    self.is_bound_with_sysdb = None
                    self.is_registered_with_sysdb = None
                    self.is_bound_with_rsi = None
                    self.is_bound_with_interface_manager = None
                    self.is_registered_with_interface_manager = None
                    self.is_bound_with_ip_arm = None
                    self.is_bound_with_lsd = None
                    self.is_registered_with_lsd = None
                    self.is_bound_with_ipv4_rib = None
                    self.is_registered_with_ipv4_rib = None
                    self.number_of_ipv4rib_tables = None
                    self.number_of_registered_ipv4rib_tables = None
                    self.is_bound_with_ipv6_rib = None
                    self.is_registered_with_ipv6_rib = None
                    self.number_of_ipv6rib_tables = None
                    self.number_of_registered_ipv6rib_tables = None
                    self.is_bound_with_atom = None
                    self.is_bound_with_nsr_mate = None
                    self.is_nsr_configured = None
                    self.is_mldp_registered = None

                    self.common = MplsLdp.Global.Standby.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.Summary, [u'number_of_vrf', u'number_of_vrf_oper', u'number_of_interfaces', u'number_of_fwd_ref_interfaces', u'number_of_autocfg_interfaces', u'is_bound_with_sysdb', u'is_registered_with_sysdb', u'is_bound_with_rsi', u'is_bound_with_interface_manager', u'is_registered_with_interface_manager', u'is_bound_with_ip_arm', u'is_bound_with_lsd', u'is_registered_with_lsd', u'is_bound_with_ipv4_rib', u'is_registered_with_ipv4_rib', u'number_of_ipv4rib_tables', u'number_of_registered_ipv4rib_tables', u'is_bound_with_ipv6_rib', u'is_registered_with_ipv6_rib', u'number_of_ipv6rib_tables', u'number_of_registered_ipv6rib_tables', u'is_bound_with_atom', u'is_bound_with_nsr_mate', u'is_nsr_configured', u'is_mldp_registered'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                            ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                            ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                            ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                            ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                            ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                            ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                            ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                            ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                            ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                            ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                            ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                            ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                            ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                            ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                            ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                            ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                            ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                            ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                            ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                            ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                        ])
                        self.address_families = None
                        self.number_of_ipv4af = None
                        self.number_of_ipv6af = None
                        self.number_of_neighbors = None
                        self.number_of_nsr_synced_neighbors = None
                        self.number_of_graceful_restart_neighbors = None
                        self.number_of_downstream_on_demand_neighbors = None
                        self.number_of_ipv4_hello_adj = None
                        self.number_of_ipv6_hello_adj = None
                        self.number_of_ipv4_routes = None
                        self.number_of_ipv6_routes = None
                        self.number_of_ipv4_local_addresses = None
                        self.number_of_ipv6_local_addresses = None
                        self.number_of_ldp_interfaces = None
                        self.number_of_ipv4ldp_interfaces = None
                        self.number_of_ipv6ldp_interfaces = None
                        self.number_of_bindings_ipv4 = None
                        self.number_of_bindings_ipv6 = None
                        self.number_of_local_bindings_ipv4 = None
                        self.number_of_local_bindings_ipv6 = None
                        self.number_of_remote_bindings_ipv4 = None
                        self.number_of_remote_bindings_ipv6 = None
                        self._segment_path = lambda: "common"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/summary/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  (key)
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Statistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['vrf_name']
                        self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities)), ("summary", ("summary", MplsLdp.Global.Standby.Vrfs.Vrf.Summary)), ("afs", ("afs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Global.Standby.Vrfs.Vrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr)), ("parameters", ("parameters", MplsLdp.Global.Standby.Vrfs.Vrf.Parameters)), ("issu", ("issu", MplsLdp.Global.Standby.Vrfs.Vrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Global.Standby.Vrfs.Vrf.LdpId)), ("statistics", ("statistics", MplsLdp.Global.Standby.Vrfs.Vrf.Statistics))])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.vrf_name = None

                        self.graceful_restart = MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"

                        self.capabilities = MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"

                        self.summary = MplsLdp.Global.Standby.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"

                        self.afs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"

                        self.neighbor_briefs = MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                        self.backoff_parameters = MplsLdp.Global.Standby.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"

                        self.backoffs = MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"

                        self.nsr = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"

                        self.parameters = MplsLdp.Global.Standby.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"

                        self.issu = MplsLdp.Global.Standby.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"

                        self.neighbor_capabilities = MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                        self.neighbors = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.ldp_id = MplsLdp.Global.Standby.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"

                        self.statistics = MplsLdp.Global.Standby.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/vrfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.Vrf_>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\: bool
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.Vrf_)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor))])
                            self._leafs = OrderedDict([
                                ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                                ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                            ])
                            self.is_forwarding_state_hold_timer_running = None
                            self.forwarding_state_hold_timer_remaining_seconds = None

                            self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.Vrf_, [u'name', u'id'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\: bool
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\: bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\: bool
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                                self._leafs = OrderedDict([
                                    ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                    ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                    ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                    ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                    ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                    ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                    ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                    ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                    ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                                ])
                                self.connect_count = None
                                self.is_neighbor_up = None
                                self.is_liveness_timer_running = None
                                self.liveness_timer_remaining_seconds = None
                                self.is_recovery_timer_running = None
                                self.recovery_timer_remaining_seconds = None
                                self.down_nbr_flap_count = None
                                self.down_nbr_flags = None
                                self.down_nbr_down_reason = None

                                self.gr_peer = MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"

                                self.down_nbr_interface = YList(self)
                                self.down_nbr_address = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.ldp_id = None
                                    self._segment_path = lambda: "gr-peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                    ])
                                    self.address_family = None
                                    self.interface_handle = None
                                    self._segment_path = lambda: "down-nbr-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "down-nbr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability))])
                            self._leafs = OrderedDict()

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  (key)
                            
                            	The capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability.Capability_>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['capability_type']
                                self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability.Capability_))])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                    ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                                ])
                                self.capability_type = None
                                self.capability_owner = None

                                self.capability = MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability.Capability_()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                            class Capability_(Entity):
                                """
                                Capability information
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability.Capability_, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Vrf_>`
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Common>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Vrf_)), ("common", ("common", MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Common))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.common = MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._segment_path = lambda: "summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Summary, [], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Vrf_, [u'name', u'id'], name, value)


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                    ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                    ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                    ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                    ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                    ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                    ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                    ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                    ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                    ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                    ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                    ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                    ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                    ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                    ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                    ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                    ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                    ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                    ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                    ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                    ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                                ])
                                self.address_families = None
                                self.number_of_ipv4af = None
                                self.number_of_ipv6af = None
                                self.number_of_neighbors = None
                                self.number_of_nsr_synced_neighbors = None
                                self.number_of_graceful_restart_neighbors = None
                                self.number_of_downstream_on_demand_neighbors = None
                                self.number_of_ipv4_hello_adj = None
                                self.number_of_ipv6_hello_adj = None
                                self.number_of_ipv4_routes = None
                                self.number_of_ipv6_routes = None
                                self.number_of_ipv4_local_addresses = None
                                self.number_of_ipv6_local_addresses = None
                                self.number_of_ldp_interfaces = None
                                self.number_of_ipv4ldp_interfaces = None
                                self.number_of_ipv6ldp_interfaces = None
                                self.number_of_bindings_ipv4 = None
                                self.number_of_bindings_ipv6 = None
                                self.number_of_local_bindings_ipv4 = None
                                self.number_of_local_bindings_ipv6 = None
                                self.number_of_remote_bindings_ipv4 = None
                                self.number_of_remote_bindings_ipv6 = None
                                self._segment_path = lambda: "common"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("af", ("af", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af))])
                            self._leafs = OrderedDict()

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  (key)
                            
                            	Address Family name
                            	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['af_name']
                                self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary))])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                                ])
                                self.af_name = None

                                self.interface_summary = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"

                                self.bindings = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"

                                self.igp = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"

                                self.bindings_summary = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"

                                self.interfaces = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"

                                self.discovery = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"

                                self.forwardings = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"

                                self.bindings_advertise_spec = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                                self.forwarding_summary = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                        ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                        ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                        ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                        ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                        ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                        ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                        ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                    ])
                                    self.known_ip_interface_count = None
                                    self.known_ip_interface_ldp_enabled = None
                                    self.ldp_configured_attached_interface = None
                                    self.ldp_configured_te_interface = None
                                    self.forward_references = None
                                    self.auto_config_disabled = None
                                    self.auto_config = None
                                    self.auto_config_forward_reference_interfaces = None
                                    self._segment_path = lambda: "interface-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding))])
                                    self._leafs = OrderedDict()

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\: str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\: str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                            ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                            ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                            ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                            ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                            ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.local_label = None
                                        self.le_local_binding_revision = None
                                        self.le_local_label_state = None
                                        self.is_no_route = None
                                        self.label_oor = None
                                        self.advertise_prefix_acl = None
                                        self.advertise_tsr_acl = None
                                        self.config_enforced_local_label_value = None
                                        self.is_elc = None

                                        self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.remote_binding = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.peers_acked = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\: bool
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                            self._leafs = OrderedDict([
                                                ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                            ])
                                            self.remote_label = None
                                            self.is_stale = None
                                            self.is_elc = None

                                            self.assigning_peer_ldp_ident = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._segment_path = lambda: "remote-binding"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                ])
                                                self.lsr_id = None
                                                self.label_space_id = None
                                                self.ldp_id = None
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-acked"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart))])
                                    self._leafs = OrderedDict()

                                    self.syncs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"

                                    self.sync_delay_restart = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._segment_path = lambda: "igp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp, [], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync))])
                                        self._leafs = OrderedDict()

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_)), ("peers", ("peers", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                                ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                                ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                                ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                                ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                            ])
                                            self.interface_name = None
                                            self.interface_name_xr = None
                                            self.igp_sync_state = None
                                            self.igp_sync_delay = None
                                            self.is_delay_timer_running = None
                                            self.delay_timer_remaining = None
                                            self.igp_sync_down_reason = None

                                            self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.peers = YList(self)
                                            self.gr_only_peer = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, [u'name', u'id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_gr_enabled = None
                                                self._segment_path = lambda: "peers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_chkpt_created = None
                                                self._segment_path = lambda: "gr-only-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                            ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                            ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                            ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                        ])
                                        self.configured = None
                                        self.delay_secs = None
                                        self.timer_running = None
                                        self.remaining_secs = None
                                        self._segment_path = lambda: "sync-delay-restart"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_>`
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_)), ("bind-af", ("bind_af", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf))])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.binding_no_route = None
                                    self.binding_local_no_route = None
                                    self.binding_local_null = None
                                    self.binding_local_implicit_null = None
                                    self.binding_local_explicit_null = None
                                    self.binding_local_non_null = None
                                    self.binding_local_oor = None
                                    self.lowest_allocated_label = None
                                    self.highest_allocated_label = None

                                    self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, [u'name', u'id'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                        ])
                                        self.address_family = None
                                        self.last_lib_update = None
                                        self.lib_minimum_revision_sent_all = None
                                        self.binding_total = None
                                        self.binding_local = None
                                        self.binding_remote = None
                                        self._segment_path = lambda: "bind-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface))])
                                    self._leafs = OrderedDict()

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                            ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                            ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                            ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.ldp_enabled = None
                                        self.is_im_stale = None
                                        self.ldp_config_mode = None
                                        self.ldp_autoconfig_disable = None

                                        self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.te_mesh_grp = YList(self)
                                        self.auto_config = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, [u'name', u'id'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\: bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                                ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                                ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                            ])
                                            self.ldp_te_mesh_group_all_cfgd = None
                                            self.ldp_mesh_group_enabled = None
                                            self.te_mesh_group_id = None
                                            self._segment_path = lambda: "te-mesh-grp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                            ])
                                            self.tuple = None
                                            self._segment_path = lambda: "auto-config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats))])
                                    self._leafs = OrderedDict()

                                    self.link_hellos = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"

                                    self.summary = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"

                                    self.targeted_hellos = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                    self.brief = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"

                                    self.stats = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._segment_path = lambda: "discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery, [], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                        self._leafs = OrderedDict()

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_>`
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hello = None
                                            self.interface = None
                                            self.interface_name_xr = None
                                            self.quick_start_disabled = None

                                            self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self.discovery_link_af = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\: bool
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\: bool
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                    ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                    ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                    ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                    ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                    ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.is_no_route = None
                                                self.hold_time = None
                                                self.local_hold_time = None
                                                self.neighbor_hold_time = None
                                                self.disc_expiry = None
                                                self.is_targeted = None
                                                self.session_up = None
                                                self.established_time = None
                                                self.established_age = None
                                                self.session_bringup_failure_reason = None

                                                self.neighbor_src_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                                self.neighbor_transport_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                                self.target = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "target"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\: str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                        ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                        ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                    ])
                                                    self.last_session_down_reason = None
                                                    self.last_session_down_time = None
                                                    self.last_session_up_time = None
                                                    self._segment_path = lambda: "last-session-down-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ])
                                                self.interval = None

                                                self.local_src_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"

                                                self.local_transport_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._segment_path = lambda: "discovery-link-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_>`
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\: str
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_))])
                                        self._leafs = OrderedDict([
                                            ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                            ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                            ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                            ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                            ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                            ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                            ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                            ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                            ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                            ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                            ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                            ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                        ])
                                        self.local_ldp_id = None
                                        self.num_of_ldp_interfaces = None
                                        self.num_of_active_ldp_interfaces = None
                                        self.num_of_lnk_disc_xmit = None
                                        self.num_of_tgt_disc_xmit = None
                                        self.num_of_lnk_disc_recv = None
                                        self.num_of_tgt_disc_recv = None
                                        self.num_of_disc_with_bad_addr_recv = None
                                        self.num_of_disc_with_bad_hello_pdu = None
                                        self.num_of_disc_with_bad_xport_addr = None
                                        self.num_of_disc_with_same_router_id = None
                                        self.num_of_disc_with_wrong_router_id = None

                                        self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, [u'name', u'id'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                                ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.state = None
                                            self.adjacency_ldp_identifier = None
                                            self.interval = None
                                            self.next_hello = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.quick_start_disabled = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_up = None
                                            self.session_bringup_failure_reason = None

                                            self.dhcb_local_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                            self.dhcb_target_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_briefs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                        self.targeted_hello_briefs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._segment_path = lambda: "brief"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief, [], name, value)


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	The Interface Name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.address_family = None
                                                self.address_family_set = None
                                                self.interface = None
                                                self.interface_name_xr = None

                                                self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                    ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ])
                                                self.local_address = None
                                                self.target_address = None
                                                self.address_family = None

                                                self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.dhcb_target_address = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "dhcb-target-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat))])
                                        self._leafs = OrderedDict()

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                                ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                                ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                                ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                                ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.adjacency_group_up_time = None
                                            self.tcp_open_count = None
                                            self.tcp_arb_chg_count = None
                                            self.tcp_role = None
                                            self._segment_path = lambda: "stat"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding))])
                                    self._leafs = OrderedDict()

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.table_id = None
                                        self.prefix_length = None

                                        self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.route = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\: bool
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                    ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                    ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                    ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                    ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                                ])
                                                self.version = None
                                                self.priority = None
                                                self.source = None
                                                self.type = None
                                                self.flags = None
                                                self.metric = None
                                                self.is_local_vrf_leaked = None
                                                self.routing_update_count = None
                                                self.routing_update_timestamp = None
                                                self.routing_update_age = None
                                                self.sr_local_label = None
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                    ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                    ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                                ])
                                                self.local_label = None
                                                self.forwarding_update_count = None
                                                self.forwarding_update_timestamp = None
                                                self.forwarding_update_age = None
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\: str
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                    ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                    ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                    ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                                ])
                                                self.interface = None
                                                self.interface_name = None
                                                self.nh_is_overriden = None
                                                self.nexthop_id = None
                                                self.next_hop_table_id = None
                                                self.flags = None
                                                self.load_metric = None
                                                self.path_id = None
                                                self.bkup_path_id = None
                                                self.path_flags = None

                                                self.next_hop = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.remote_lfa = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\: bool
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                        ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                        ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None
                                                    self.needs_tldp = None
                                                    self.has_q_node = None

                                                    self.remote_p_node_id = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                    self.remote_q_node_id = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-p-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-q-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                                self._leafs = OrderedDict()

                                                self.mpls_outgoing_info = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                                self.remote_lfa = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\: bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                    self._leafs = OrderedDict([
                                                        ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                        ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                        ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                        ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                        ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                        ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                    ])
                                                    self.out_label = None
                                                    self.out_label_rsn = None
                                                    self.out_label_type = None
                                                    self.out_label_owner = None
                                                    self.is_from_graceful_restartable_neighbor = None
                                                    self.is_stale = None

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                        ])
                                                        self.lsr_id = None
                                                        self.label_space_id = None
                                                        self.ldp_id = None
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None

                                                    self.mpls_outgoing_info = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                        self._leafs = OrderedDict()

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\: bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                            self._leafs = OrderedDict([
                                                                ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                                ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                                ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                                ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                                ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                            ])
                                                            self.out_label = None
                                                            self.out_label_rsn = None
                                                            self.out_label_type = None
                                                            self.out_label_owner = None
                                                            self.is_from_graceful_restartable_neighbor = None
                                                            self.is_stale = None

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._segment_path = lambda: "stack"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                                ])
                                                                self.lsr_id = None
                                                                self.label_space_id = None
                                                                self.ldp_id = None
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                    self._leafs = OrderedDict()

                                    self.allocation_acl = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                        ])
                                        self.has_acl = None
                                        self.prefix_acl = None
                                        self.is_host_route_only = None
                                        self._segment_path = lambda: "allocation-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                        ])
                                        self.prefix_acl = None
                                        self.peer_acl = None
                                        self._segment_path = lambda: "advt-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_>`
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\: bool
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_)), ("rws", ("rws", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws))])
                                    self._leafs = OrderedDict([
                                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                    ])
                                    self.is_lsd_bound = None
                                    self.fsht = None
                                    self.intfs = None
                                    self.lbls = None

                                    self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.rws = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._segment_path = lambda: "forwarding-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, [u'name', u'id'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                        self._leafs = OrderedDict()

                                        self.pfxs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"

                                        self.nhs = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._segment_path = lambda: "rws"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                            self._leafs = OrderedDict([
                                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                            ])
                                            self.total_pfxs = None
                                            self.ecmp_pfxs = None
                                            self.protected_pfxs = None

                                            self.labeled_pfxs_aggr = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                            self.labeled_pfxs_primary = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                            self.labeled_pfxs_backup = MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._segment_path = lambda: "pfxs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-primary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                            ])
                                            self.total_paths = None
                                            self.protected_paths = None
                                            self.backup_paths = None
                                            self.remote_backup_paths = None
                                            self.labeled_paths = None
                                            self.labeled_backup_paths = None
                                            self._segment_path = lambda: "nhs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief))])
                            self._leafs = OrderedDict()

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_>`
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\: bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                    ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.is_graceful_restartable = None
                                self.nsr_state = None
                                self.up_time_seconds = None

                                self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, [u'name', u'id'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                        ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                        ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.num_of_nbr_discovery = None
                                    self.num_of_nbr_addresses = None
                                    self.num_of_nbr_lbl = None
                                    self._segment_path = lambda: "nbr-br-af-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                                ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                            ])
                            self.initial_seconds = None
                            self.maximum_seconds = None
                            self._segment_path = lambda: "backoff-parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs.Backoff))])
                            self._leafs = OrderedDict()

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                    ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.backoff_seconds = None
                                self.waiting_seconds = None
                                self._segment_path = lambda: "backoff"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.nsr_pending = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"

                            self.ha_summary = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "nsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr, [], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_neighbors = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "nsr-pending"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending, [], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\: bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\: bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\: bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\: bool
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\: bool
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\: bool
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter))])
                            self._leafs = OrderedDict([
                                ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                                ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                                ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                                ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                                ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                                ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                                ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                                ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                                ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                                ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                                ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                                ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                                ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                                ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                                ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                                ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                                ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                            ])
                            self.role_is_active = None
                            self.global_md5_password_enabled = None
                            self.protocol_version = None
                            self.router_id = None
                            self.keepalive_interval = None
                            self.hello_hold_time = None
                            self.hello_interval = None
                            self.targeted_hello_hold_time = None
                            self.targeted_hello_interval = None
                            self.session_hold_time = None
                            self.housekeeping_timer_interval = None
                            self.le_no_route_timeout = None
                            self.ldp_recovery_timeout = None
                            self.af_binding_withdraw_delay = None
                            self.max_intf_attached = None
                            self.max_intf_te = None
                            self.max_peer = None
                            self.ldp_out_of_mem_state = None
                            self.nsr_enabled = None
                            self.nsr_synced = None
                            self.igp_sync_delay_time_for_interface = None
                            self.igp_sync_delay_time_on_restart = None
                            self.global_discovery_quick_start_disabled = None
                            self.discovery_quick_start_disabled_on_interfaces = None

                            self.graceful_restart_information = MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                    ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                    ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                                ])
                                self.is_graceful_restart_configured = None
                                self.graceful_restart_reconnect_timeout = None
                                self.graceful_restart_forwarding_state_hold_time = None
                                self._segment_path = lambda: "graceful-restart-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\: str
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\: str
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\: bool
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                    ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                    ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                    ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                                ])
                                self.address_family = None
                                self.null_label = None
                                self.label_imp_null_override_acl = None
                                self.is_accepting_targeted_hellos = None
                                self.targeted_hello_acl = None

                                self.discovery_transport_address = MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._segment_path = lambda: "address-family-parameter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "discovery-transport-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.ha_summary = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "issu"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu, [], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability))])
                            self._leafs = OrderedDict()

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.sent = YList(self)
                                self.received = YList(self)
                                self._segment_path = lambda: "neighbor-capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "sent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "received"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.protocol_information = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"

                                self.tcp_information = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"

                                self.detailed_information = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\: str
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                    self._leafs = OrderedDict([
                                        ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                        ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                        ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                        ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                        ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                        ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                    ])
                                    self.ta_holdtime = None
                                    self.ta_state = None
                                    self.ta_pies_sent = None
                                    self.ta_pies_rcvd = None
                                    self.ta_up_time_seconds = None
                                    self.downstream_on_demand = None

                                    self.ta_graceful_restart_adjacency = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._segment_path = lambda: "protocol-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\: bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                            ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                            ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                        ])
                                        self.is_graceful_restartable = None
                                        self.reconnect_timeout = None
                                        self.recovery_time = None
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                    self._leafs = OrderedDict([
                                        ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                        ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                        ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                    ])
                                    self.foreign_port = None
                                    self.local_port = None
                                    self.is_md5_on = None

                                    self.foreign_host = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"

                                    self.local_host = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._segment_path = lambda: "tcp-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "foreign-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "local-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\: bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\: bool
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\: bool
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\: bool
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\: bool
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                    self._leafs = OrderedDict([
                                        ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                        ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                        ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                        ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                        ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                        ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                        ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                        ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                        ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                        ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                        ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                        ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                        ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                        ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                        ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                        ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                        ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                        ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                        ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                        ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                        ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                    ])
                                    self.peer_holdtime = None
                                    self.keep_alive_interval = None
                                    self.peer_state = None
                                    self.has_ipv4_inbound = None
                                    self.inbound_ipv4acl = None
                                    self.has_ipv6_inbound = None
                                    self.inbound_ipv6acl = None
                                    self.has_ipv4_outbound = None
                                    self.outbound_ipv4acl = None
                                    self.has_ipv6_outbound = None
                                    self.outbound_ipv6acl = None
                                    self.has_sp = None
                                    self.sp_state = None
                                    self.sp_has_acl = None
                                    self.spacl = None
                                    self.sp_has_duration = None
                                    self.sp_duration = None
                                    self.spht_running = None
                                    self.spht_remaining = None
                                    self.nsr_sync_state = None
                                    self.nsr_last_sync_error = None
                                    self.nsr_last_sync_nack_reason = None
                                    self.bgp_advertisement_state = None
                                    self.advertise_bgp_prefixes = None

                                    self.capabilities = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                        self._leafs = OrderedDict()

                                        self.sent = YList(self)
                                        self.received = YList(self)
                                        self._segment_path = lambda: "capabilities"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "sent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "received"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "client"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv4-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv6-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.ldp_id = None
                            self._segment_path = lambda: "ldp-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic))])
                            self._leafs = OrderedDict()

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.iccp_enabled = None

                                self.message_out = MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"

                                self.message_in = MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._segment_path = lambda: "statistic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-out"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Standby.DiscoverySummaryAll.Vrf>`
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\: str
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Standby.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Standby.DiscoverySummaryAll.Vrf))])
                    self._leafs = OrderedDict([
                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                    ])
                    self.local_ldp_id = None
                    self.num_of_ldp_interfaces = None
                    self.num_of_active_ldp_interfaces = None
                    self.num_of_lnk_disc_xmit = None
                    self.num_of_tgt_disc_xmit = None
                    self.num_of_lnk_disc_recv = None
                    self.num_of_tgt_disc_recv = None
                    self.num_of_disc_with_bad_addr_recv = None
                    self.num_of_disc_with_bad_hello_pdu = None
                    self.num_of_disc_with_bad_xport_addr = None
                    self.num_of_disc_with_same_router_id = None
                    self.num_of_disc_with_wrong_router_id = None

                    self.vrf = MplsLdp.Global.Standby.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "discovery-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Standby.DiscoverySummaryAll, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Standby.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/discovery-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Standby.DiscoverySummaryAll.Vrf, [u'name', u'id'], name, value)


        class Active(Entity):
            """
            Active MPLS LDP operational data
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:  :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:  :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.BindingsSummaryAll>`
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:  :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:  :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:  :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DiscoverySummaryAll>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(MplsLdp.Global.Active, self).__init__()

                self.yang_name = "active"
                self.yang_parent_name = "global"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("default-vrf", ("default_vrf", MplsLdp.Global.Active.DefaultVrf)), ("forwarding-summary-all", ("forwarding_summary_all", MplsLdp.Global.Active.ForwardingSummaryAll)), ("bindings-summary-all", ("bindings_summary_all", MplsLdp.Global.Active.BindingsSummaryAll)), ("ato-mdb-table-entries", ("ato_mdb_table_entries", MplsLdp.Global.Active.AtoMdbTableEntries)), ("nsr-summary-all", ("nsr_summary_all", MplsLdp.Global.Active.NsrSummaryAll)), ("summary", ("summary", MplsLdp.Global.Active.Summary)), ("vrfs", ("vrfs", MplsLdp.Global.Active.Vrfs)), ("discovery-summary-all", ("discovery_summary_all", MplsLdp.Global.Active.DiscoverySummaryAll))])
                self._leafs = OrderedDict()

                self.default_vrf = MplsLdp.Global.Active.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"

                self.forwarding_summary_all = MplsLdp.Global.Active.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"

                self.bindings_summary_all = MplsLdp.Global.Active.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"

                self.ato_mdb_table_entries = MplsLdp.Global.Active.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"

                self.nsr_summary_all = MplsLdp.Global.Active.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"

                self.summary = MplsLdp.Global.Active.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.vrfs = MplsLdp.Global.Active.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"

                self.discovery_summary_all = MplsLdp.Global.Active.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._segment_path = lambda: "active"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(MplsLdp.Global.Active, [], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Capabilities>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Summary>`
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Backoffs>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Parameters>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.LdpId>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Statistics>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Global.Active.DefaultVrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Global.Active.DefaultVrf.Capabilities)), ("summary", ("summary", MplsLdp.Global.Active.DefaultVrf.Summary)), ("afs", ("afs", MplsLdp.Global.Active.DefaultVrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Global.Active.DefaultVrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Global.Active.DefaultVrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Global.Active.DefaultVrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Global.Active.DefaultVrf.Nsr)), ("parameters", ("parameters", MplsLdp.Global.Active.DefaultVrf.Parameters)), ("issu", ("issu", MplsLdp.Global.Active.DefaultVrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Global.Active.DefaultVrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Global.Active.DefaultVrf.LdpId)), ("statistics", ("statistics", MplsLdp.Global.Active.DefaultVrf.Statistics))])
                    self._leafs = OrderedDict()

                    self.graceful_restart = MplsLdp.Global.Active.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.capabilities = MplsLdp.Global.Active.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"

                    self.summary = MplsLdp.Global.Active.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.afs = MplsLdp.Global.Active.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"

                    self.neighbor_briefs = MplsLdp.Global.Active.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                    self.backoff_parameters = MplsLdp.Global.Active.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"

                    self.backoffs = MplsLdp.Global.Active.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"

                    self.nsr = MplsLdp.Global.Active.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"

                    self.parameters = MplsLdp.Global.Active.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"

                    self.issu = MplsLdp.Global.Active.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"

                    self.neighbor_capabilities = MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                    self.neighbors = MplsLdp.Global.Active.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"

                    self.ldp_id = MplsLdp.Global.Active.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"

                    self.statistics = MplsLdp.Global.Active.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._segment_path = lambda: "default-vrf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf, [], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart.Vrf>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\: bool
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.GracefulRestart.Vrf)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor))])
                        self._leafs = OrderedDict([
                            ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                            ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                        ])
                        self.is_forwarding_state_hold_timer_running = None
                        self.forwarding_state_hold_timer_remaining_seconds = None

                        self.vrf = MplsLdp.Global.Active.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.Vrf, [u'name', u'id'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\: bool
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\: bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\: bool
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                            self._leafs = OrderedDict([
                                ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                            ])
                            self.connect_count = None
                            self.is_neighbor_up = None
                            self.is_liveness_timer_running = None
                            self.liveness_timer_remaining_seconds = None
                            self.is_recovery_timer_running = None
                            self.recovery_timer_remaining_seconds = None
                            self.down_nbr_flap_count = None
                            self.down_nbr_flags = None
                            self.down_nbr_down_reason = None

                            self.gr_peer = MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"

                            self.down_nbr_interface = YList(self)
                            self.down_nbr_address = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.ldp_id = None
                                self._segment_path = lambda: "gr-peer"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                ])
                                self.address_family = None
                                self.interface_handle = None
                                self._segment_path = lambda: "down-nbr-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "down-nbr-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability))])
                        self._leafs = OrderedDict()

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  (key)
                        
                        	The capability type (IANA assigned)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability.Capability_>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['capability_type']
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability.Capability_))])
                            self._leafs = OrderedDict([
                                ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                            ])
                            self.capability_type = None
                            self.capability_owner = None

                            self.capability = MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability.Capability_()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/capabilities/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                        class Capability_(Entity):
                            """
                            Capability information
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability.Capability_, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Summary.Vrf>`
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Summary.Common>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Summary.Vrf)), ("common", ("common", MplsLdp.Global.Active.DefaultVrf.Summary.Common))])
                        self._leafs = OrderedDict()

                        self.vrf = MplsLdp.Global.Active.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.common = MplsLdp.Global.Active.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._segment_path = lambda: "summary"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Summary, [], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/summary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Summary.Vrf, [u'name', u'id'], name, value)


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                            ])
                            self.address_families = None
                            self.number_of_ipv4af = None
                            self.number_of_ipv6af = None
                            self.number_of_neighbors = None
                            self.number_of_nsr_synced_neighbors = None
                            self.number_of_graceful_restart_neighbors = None
                            self.number_of_downstream_on_demand_neighbors = None
                            self.number_of_ipv4_hello_adj = None
                            self.number_of_ipv6_hello_adj = None
                            self.number_of_ipv4_routes = None
                            self.number_of_ipv6_routes = None
                            self.number_of_ipv4_local_addresses = None
                            self.number_of_ipv6_local_addresses = None
                            self.number_of_ldp_interfaces = None
                            self.number_of_ipv4ldp_interfaces = None
                            self.number_of_ipv6ldp_interfaces = None
                            self.number_of_bindings_ipv4 = None
                            self.number_of_bindings_ipv6 = None
                            self.number_of_local_bindings_ipv4 = None
                            self.number_of_local_bindings_ipv6 = None
                            self.number_of_remote_bindings_ipv4 = None
                            self.number_of_remote_bindings_ipv6 = None
                            self._segment_path = lambda: "common"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/summary/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("af", ("af", MplsLdp.Global.Active.DefaultVrf.Afs.Af))])
                        self._leafs = OrderedDict()

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  (key)
                        
                        	Address Family name
                        	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Global.Active.DefaultVrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                            ])
                            self.af_name = None

                            self.interface_summary = MplsLdp.Global.Active.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"

                            self.bindings = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"

                            self.igp = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"

                            self.bindings_summary = MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"

                            self.interfaces = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"

                            self.discovery = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"

                            self.forwardings = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"

                            self.bindings_advertise_spec = MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                            self.forwarding_summary = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/afs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                    ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                    ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                    ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                    ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                    ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                    ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                    ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                ])
                                self.known_ip_interface_count = None
                                self.known_ip_interface_ldp_enabled = None
                                self.ldp_configured_attached_interface = None
                                self.ldp_configured_te_interface = None
                                self.forward_references = None
                                self.auto_config_disabled = None
                                self.auto_config = None
                                self.auto_config_forward_reference_interfaces = None
                                self._segment_path = lambda: "interface-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding))])
                                self._leafs = OrderedDict()

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\: bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\: bool
                                
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\: str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\: str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\: bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\: bool
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                        ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                        ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                        ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                        ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                        ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                        ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                        ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                        ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None
                                    self.local_label = None
                                    self.le_local_binding_revision = None
                                    self.le_local_label_state = None
                                    self.is_no_route = None
                                    self.label_oor = None
                                    self.advertise_prefix_acl = None
                                    self.advertise_tsr_acl = None
                                    self.config_enforced_local_label_value = None
                                    self.is_elc = None

                                    self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.remote_binding = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.peers_acked = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                        self._leafs = OrderedDict([
                                            ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.remote_label = None
                                        self.is_stale = None
                                        self.is_elc = None

                                        self.assigning_peer_ldp_ident = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._segment_path = lambda: "remote-binding"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-advertised-to"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-acked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart))])
                                self._leafs = OrderedDict()

                                self.syncs = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"

                                self.sync_delay_restart = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._segment_path = lambda: "igp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp, [], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync))])
                                    self._leafs = OrderedDict()

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)), ("peers", ("peers", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                            ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                            ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                            ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                            ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                        ])
                                        self.interface_name = None
                                        self.interface_name_xr = None
                                        self.igp_sync_state = None
                                        self.igp_sync_delay = None
                                        self.is_delay_timer_running = None
                                        self.delay_timer_remaining = None
                                        self.igp_sync_down_reason = None

                                        self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.peers = YList(self)
                                        self.gr_only_peer = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, [u'name', u'id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_gr_enabled = None
                                            self._segment_path = lambda: "peers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_chkpt_created = None
                                            self._segment_path = lambda: "gr-only-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\: bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\: bool
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                        ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                        ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                        ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                    ])
                                    self.configured = None
                                    self.delay_secs = None
                                    self.timer_running = None
                                    self.remaining_secs = None
                                    self._segment_path = lambda: "sync-delay-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf)), ("bind-af", ("bind_af", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                    ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                    ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                    ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                    ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                    ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                    ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                    ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                    ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                ])
                                self.address_family = None
                                self.binding_no_route = None
                                self.binding_local_no_route = None
                                self.binding_local_null = None
                                self.binding_local_implicit_null = None
                                self.binding_local_explicit_null = None
                                self.binding_local_non_null = None
                                self.binding_local_oor = None
                                self.lowest_allocated_label = None
                                self.highest_allocated_label = None

                                self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf, [u'name', u'id'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                        ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                        ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                        ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                        ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.last_lib_update = None
                                    self.lib_minimum_revision_sent_all = None
                                    self.binding_total = None
                                    self.binding_local = None
                                    self.binding_remote = None
                                    self._segment_path = lambda: "bind-af"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  (key)
                                
                                	The Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\: str
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\: bool
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\: bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\: bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\: bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                        ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                        ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                        ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                        ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.interface = None
                                    self.interface_name_xr = None
                                    self.ldp_enabled = None
                                    self.is_im_stale = None
                                    self.ldp_config_mode = None
                                    self.ldp_autoconfig_disable = None

                                    self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.te_mesh_grp = YList(self)
                                    self.auto_config = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, [u'name', u'id'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                            ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                            ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                        ])
                                        self.ldp_te_mesh_group_all_cfgd = None
                                        self.ldp_mesh_group_enabled = None
                                        self.te_mesh_group_id = None
                                        self._segment_path = lambda: "te-mesh-grp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                        ])
                                        self.tuple = None
                                        self._segment_path = lambda: "auto-config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats))])
                                self._leafs = OrderedDict()

                                self.link_hellos = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"

                                self.summary = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"

                                self.targeted_hellos = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                self.brief = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"

                                self.stats = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._segment_path = lambda: "discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery, [], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                    self._leafs = OrderedDict()

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)), ("hello-information", ("hello_information", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.next_hello = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.quick_start_disabled = None

                                        self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.hello_information = YList(self)
                                        self.discovery_link_af = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, [u'name', u'id'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\: bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\: bool
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.neighbor_ldp_identifier = None
                                            self.is_no_route = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.is_targeted = None
                                            self.session_up = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_bringup_failure_reason = None

                                            self.neighbor_src_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                            self.neighbor_transport_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                            self.target = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ])
                                            self.interval = None

                                            self.local_src_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"

                                            self.local_transport_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._segment_path = lambda: "discovery-link-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\: str
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                    ])
                                    self.local_ldp_id = None
                                    self.num_of_ldp_interfaces = None
                                    self.num_of_active_ldp_interfaces = None
                                    self.num_of_lnk_disc_xmit = None
                                    self.num_of_tgt_disc_xmit = None
                                    self.num_of_lnk_disc_recv = None
                                    self.num_of_tgt_disc_recv = None
                                    self.num_of_disc_with_bad_addr_recv = None
                                    self.num_of_disc_with_bad_hello_pdu = None
                                    self.num_of_disc_with_bad_xport_addr = None
                                    self.num_of_disc_with_same_router_id = None
                                    self.num_of_disc_with_wrong_router_id = None

                                    self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, [u'name', u'id'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                    self._leafs = OrderedDict()

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\: str
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\: bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\: str
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                        self._leafs = OrderedDict([
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                            ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                            ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                            ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                            ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                            ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                            ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                            ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                        ])
                                        self.local_address = None
                                        self.target_address = None
                                        self.state = None
                                        self.adjacency_ldp_identifier = None
                                        self.interval = None
                                        self.next_hello = None
                                        self.hold_time = None
                                        self.local_hold_time = None
                                        self.neighbor_hold_time = None
                                        self.disc_expiry = None
                                        self.quick_start_disabled = None
                                        self.established_time = None
                                        self.established_age = None
                                        self.session_up = None
                                        self.session_bringup_failure_reason = None

                                        self.dhcb_local_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                        self.dhcb_target_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-target-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                            ])
                                            self.last_session_down_reason = None
                                            self.last_session_down_time = None
                                            self.last_session_up_time = None
                                            self._segment_path = lambda: "last-session-down-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                    self._leafs = OrderedDict()

                                    self.link_hello_briefs = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                    self.targeted_hello_briefs = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._segment_path = lambda: "brief"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief, [], name, value)


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)), ("hello-information", ("hello_information", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.address_family = None
                                            self.address_family_set = None
                                            self.interface = None
                                            self.interface_name_xr = None

                                            self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.address_family = None

                                            self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.dhcb_target_address = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat))])
                                    self._leafs = OrderedDict()

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                            ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                            ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                            ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.adjacency_group_up_time = None
                                        self.tcp_open_count = None
                                        self.tcp_arb_chg_count = None
                                        self.tcp_role = None
                                        self._segment_path = lambda: "stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding))])
                                self._leafs = OrderedDict()

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.table_id = None
                                    self.prefix_length = None

                                    self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.route = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\: bool
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                            ])
                                            self.version = None
                                            self.priority = None
                                            self.source = None
                                            self.type = None
                                            self.flags = None
                                            self.metric = None
                                            self.is_local_vrf_leaked = None
                                            self.routing_update_count = None
                                            self.routing_update_timestamp = None
                                            self.routing_update_age = None
                                            self.sr_local_label = None
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                            ])
                                            self.local_label = None
                                            self.forwarding_update_count = None
                                            self.forwarding_update_timestamp = None
                                            self.forwarding_update_age = None
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\: bool
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self.nh_is_overriden = None
                                            self.nexthop_id = None
                                            self.next_hop_table_id = None
                                            self.flags = None
                                            self.load_metric = None
                                            self.path_id = None
                                            self.bkup_path_id = None
                                            self.path_flags = None

                                            self.next_hop = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.remote_lfa = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\: bool
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                    ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None
                                                self.needs_tldp = None
                                                self.has_q_node = None

                                                self.remote_p_node_id = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                self.remote_q_node_id = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-p-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-q-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                            self._leafs = OrderedDict()

                                            self.mpls_outgoing_info = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                            self.remote_lfa = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                self._leafs = OrderedDict([
                                                    ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                    ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                    ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                    ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                    ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                    ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ])
                                                self.out_label = None
                                                self.out_label_rsn = None
                                                self.out_label_type = None
                                                self.out_label_owner = None
                                                self.is_from_graceful_restartable_neighbor = None
                                                self.is_stale = None

                                                self.nexthop_peer_ldp_ident = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._segment_path = lambda: "mpls-outgoing-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                    ])
                                                    self.lsr_id = None
                                                    self.label_space_id = None
                                                    self.ldp_id = None
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None

                                                self.mpls_outgoing_info = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                    self._leafs = OrderedDict()

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                        self._leafs = OrderedDict([
                                                            ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                            ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                            ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                            ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                            ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                        ])
                                                        self.out_label = None
                                                        self.out_label_rsn = None
                                                        self.out_label_type = None
                                                        self.out_label_owner = None
                                                        self.is_from_graceful_restartable_neighbor = None
                                                        self.is_stale = None

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._segment_path = lambda: "stack"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                            ])
                                                            self.lsr_id = None
                                                            self.label_space_id = None
                                                            self.ldp_id = None
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                self._leafs = OrderedDict()

                                self.allocation_acl = MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\: bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                    ])
                                    self.has_acl = None
                                    self.prefix_acl = None
                                    self.is_host_route_only = None
                                    self._segment_path = lambda: "allocation-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                    ])
                                    self.prefix_acl = None
                                    self.peer_acl = None
                                    self._segment_path = lambda: "advt-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\: bool
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)), ("rws", ("rws", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws))])
                                self._leafs = OrderedDict([
                                    ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                    ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                    ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                    ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                ])
                                self.is_lsd_bound = None
                                self.fsht = None
                                self.intfs = None
                                self.lbls = None

                                self.vrf = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.rws = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._segment_path = lambda: "forwarding-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, [u'name', u'id'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                    self._leafs = OrderedDict()

                                    self.pfxs = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"

                                    self.nhs = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._segment_path = lambda: "rws"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                        self._leafs = OrderedDict([
                                            ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                            ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                            ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                        ])
                                        self.total_pfxs = None
                                        self.ecmp_pfxs = None
                                        self.protected_pfxs = None

                                        self.labeled_pfxs_aggr = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                        self.labeled_pfxs_primary = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                        self.labeled_pfxs_backup = MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._segment_path = lambda: "pfxs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-aggr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                            ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                            ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                            ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                            ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                            ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                        ])
                                        self.total_paths = None
                                        self.protected_paths = None
                                        self.backup_paths = None
                                        self.remote_backup_paths = None
                                        self.labeled_paths = None
                                        self.labeled_backup_paths = None
                                        self._segment_path = lambda: "nhs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief))])
                        self._leafs = OrderedDict()

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\: bool
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.is_graceful_restartable = None
                            self.nsr_state = None
                            self.up_time_seconds = None

                            self.vrf = MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, [u'name', u'id'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                    ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                    ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                ])
                                self.address_family = None
                                self.num_of_nbr_discovery = None
                                self.num_of_nbr_addresses = None
                                self.num_of_nbr_lbl = None
                                self._segment_path = lambda: "nbr-br-af-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                            ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                        ])
                        self.initial_seconds = None
                        self.maximum_seconds = None
                        self._segment_path = lambda: "backoff-parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Global.Active.DefaultVrf.Backoffs.Backoff))])
                        self._leafs = OrderedDict()

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.backoff_seconds = None
                            self.waiting_seconds = None
                            self._segment_path = lambda: "backoff"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/backoffs/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.nsr_pending = MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"

                        self.ha_summary = MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "nsr"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr, [], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_neighbors = MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "nsr-pending"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending, [], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-global/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\: bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\: bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\: bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\: bool
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\: bool
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\: bool
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Global.Active.DefaultVrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter))])
                        self._leafs = OrderedDict([
                            ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                            ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                            ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                            ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                            ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                            ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                            ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                            ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                            ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                            ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                            ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                            ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                            ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                            ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                            ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                            ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                            ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                            ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                            ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                            ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                        ])
                        self.role_is_active = None
                        self.global_md5_password_enabled = None
                        self.protocol_version = None
                        self.router_id = None
                        self.keepalive_interval = None
                        self.hello_hold_time = None
                        self.hello_interval = None
                        self.targeted_hello_hold_time = None
                        self.targeted_hello_interval = None
                        self.session_hold_time = None
                        self.housekeeping_timer_interval = None
                        self.le_no_route_timeout = None
                        self.ldp_recovery_timeout = None
                        self.af_binding_withdraw_delay = None
                        self.max_intf_attached = None
                        self.max_intf_te = None
                        self.max_peer = None
                        self.ldp_out_of_mem_state = None
                        self.nsr_enabled = None
                        self.nsr_synced = None
                        self.igp_sync_delay_time_for_interface = None
                        self.igp_sync_delay_time_on_restart = None
                        self.global_discovery_quick_start_disabled = None
                        self.discovery_quick_start_disabled_on_interfaces = None

                        self.graceful_restart_information = MplsLdp.Global.Active.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\: bool
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                            ])
                            self.is_graceful_restart_configured = None
                            self.graceful_restart_reconnect_timeout = None
                            self.graceful_restart_forwarding_state_hold_time = None
                            self._segment_path = lambda: "graceful-restart-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\: str
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\: str
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\: bool
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                            self._leafs = OrderedDict([
                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                            ])
                            self.address_family = None
                            self.null_label = None
                            self.label_imp_null_override_acl = None
                            self.is_accepting_targeted_hellos = None
                            self.targeted_hello_acl = None

                            self.discovery_transport_address = MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._segment_path = lambda: "address-family-parameter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "discovery-transport-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/address-family-parameter/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.ha_summary = MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "issu"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu, [], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-summary/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-global/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability))])
                        self._leafs = OrderedDict()

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.sent = YList(self)
                            self.received = YList(self)
                            self._segment_path = lambda: "neighbor-capability"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "sent"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "received"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.protocol_information = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"

                            self.tcp_information = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"

                            self.detailed_information = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\: str
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                self._leafs = OrderedDict([
                                    ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                    ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                    ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                    ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                    ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                    ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                ])
                                self.ta_holdtime = None
                                self.ta_state = None
                                self.ta_pies_sent = None
                                self.ta_pies_rcvd = None
                                self.ta_up_time_seconds = None
                                self.downstream_on_demand = None

                                self.ta_graceful_restart_adjacency = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._segment_path = lambda: "protocol-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\: bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                        ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                        ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                    ])
                                    self.is_graceful_restartable = None
                                    self.reconnect_timeout = None
                                    self.recovery_time = None
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/protocol-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                self._leafs = OrderedDict([
                                    ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                    ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                    ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                ])
                                self.foreign_port = None
                                self.local_port = None
                                self.is_md5_on = None

                                self.foreign_host = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"

                                self.local_host = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._segment_path = lambda: "tcp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "foreign-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "local-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\: bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\: bool
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\: bool
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\: bool
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\: bool
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                self._leafs = OrderedDict([
                                    ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                    ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                    ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                    ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                    ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                    ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                    ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                    ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                    ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                    ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                    ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                    ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                    ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                    ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                    ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                    ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                    ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                    ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                    ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                    ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                    ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                    ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                ])
                                self.peer_holdtime = None
                                self.keep_alive_interval = None
                                self.peer_state = None
                                self.has_ipv4_inbound = None
                                self.inbound_ipv4acl = None
                                self.has_ipv6_inbound = None
                                self.inbound_ipv6acl = None
                                self.has_ipv4_outbound = None
                                self.outbound_ipv4acl = None
                                self.has_ipv6_outbound = None
                                self.outbound_ipv6acl = None
                                self.has_sp = None
                                self.sp_state = None
                                self.sp_has_acl = None
                                self.spacl = None
                                self.sp_has_duration = None
                                self.sp_duration = None
                                self.spht_running = None
                                self.spht_remaining = None
                                self.nsr_sync_state = None
                                self.nsr_last_sync_error = None
                                self.nsr_last_sync_nack_reason = None
                                self.bgp_advertisement_state = None
                                self.advertise_bgp_prefixes = None

                                self.capabilities = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                    self._leafs = OrderedDict()

                                    self.sent = YList(self)
                                    self.received = YList(self)
                                    self._segment_path = lambda: "capabilities"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "sent"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "received"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "client"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv4-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/ipv4-duplicate-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv6-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/ipv6-duplicate-address/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv4-address-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv6-address-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                        ])
                        self.lsr_id = None
                        self.label_space_id = None
                        self.ldp_id = None
                        self._segment_path = lambda: "ldp-id"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic))])
                        self._leafs = OrderedDict()

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageIn))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.iccp_enabled = None

                            self.message_out = MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"

                            self.message_in = MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._segment_path = lambda: "statistic"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-out"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/statistic/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-in"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/statistic/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.DefaultVrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Vrf>`
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws>`
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\: bool
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.ForwardingSummaryAll.Vrf)), ("rws", ("rws", MplsLdp.Global.Active.ForwardingSummaryAll.Rws))])
                    self._leafs = OrderedDict([
                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                    ])
                    self.is_lsd_bound = None
                    self.fsht = None
                    self.intfs = None
                    self.lbls = None

                    self.vrf = MplsLdp.Global.Active.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.rws = MplsLdp.Global.Active.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._segment_path = lambda: "forwarding-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Nhs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Nhs))])
                        self._leafs = OrderedDict()

                        self.pfxs = MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"

                        self.nhs = MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._segment_path = lambda: "rws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws, [], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup))])
                            self._leafs = OrderedDict([
                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                            ])
                            self.total_pfxs = None
                            self.ecmp_pfxs = None
                            self.protected_pfxs = None

                            self.labeled_pfxs_aggr = MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                            self.labeled_pfxs_primary = MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                            self.labeled_pfxs_backup = MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._segment_path = lambda: "pfxs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-primary"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-backup"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                            ])
                            self.total_paths = None
                            self.protected_paths = None
                            self.backup_paths = None
                            self.remote_backup_paths = None
                            self.labeled_paths = None
                            self.labeled_backup_paths = None
                            self._segment_path = lambda: "nhs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.ForwardingSummaryAll.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.BindingsSummaryAll.Vrf>`
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.BindingsSummaryAll.BindAf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.BindingsSummaryAll.Vrf)), ("bind-af", ("bind_af", MplsLdp.Global.Active.BindingsSummaryAll.BindAf))])
                    self._leafs = OrderedDict([
                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                    ])
                    self.address_family = None
                    self.binding_no_route = None
                    self.binding_local_no_route = None
                    self.binding_local_null = None
                    self.binding_local_implicit_null = None
                    self.binding_local_explicit_null = None
                    self.binding_local_non_null = None
                    self.binding_local_oor = None
                    self.lowest_allocated_label = None
                    self.highest_allocated_label = None

                    self.vrf = MplsLdp.Global.Active.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.BindingsSummaryAll, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/bindings-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.BindingsSummaryAll.Vrf, [u'name', u'id'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                        ])
                        self.address_family = None
                        self.last_lib_update = None
                        self.lib_minimum_revision_sent_all = None
                        self.binding_total = None
                        self.binding_local = None
                        self.binding_remote = None
                        self._segment_path = lambda: "bind-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/bindings-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.BindingsSummaryAll.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of  		 :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ato-mdb-table-entry", ("ato_mdb_table_entry", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry))])
                    self._leafs = OrderedDict()

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:  :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fec-info", ("fec_info", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo))])
                        self._leafs = OrderedDict([
                            ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str','str'])),
                            ('fe_ctype', (YLeaf(YType.uint32, 'fe-ctype'), ['int'])),
                            ('pw_id', (YLeaf(YType.uint32, 'pw-id'), ['int'])),
                            ('agi_type', (YLeaf(YType.uint32, 'agi-type'), ['int'])),
                            ('agi', (YLeaf(YType.uint32, 'agi'), ['int'])),
                            ('saii_type', (YLeaf(YType.uint32, 'saii-type'), ['int'])),
                            ('saii_local_id', (YLeaf(YType.str, 'saii-local-id'), ['str','str'])),
                            ('saii_global_id', (YLeaf(YType.uint32, 'saii-global-id'), ['int'])),
                            ('saii_prefix', (YLeaf(YType.str, 'saii-prefix'), ['str'])),
                            ('saii_ac_id', (YLeaf(YType.uint32, 'saii-ac-id'), ['int'])),
                            ('taii_type', (YLeaf(YType.uint32, 'taii-type'), ['int'])),
                            ('taii_local_id', (YLeaf(YType.str, 'taii-local-id'), ['str','str'])),
                            ('taii_global_id', (YLeaf(YType.uint32, 'taii-global-id'), ['int'])),
                            ('taii_prefix', (YLeaf(YType.str, 'taii-prefix'), ['str'])),
                            ('taii_ac_id', (YLeaf(YType.uint32, 'taii-ac-id'), ['int'])),
                            ('peer_id_xr', (YLeaf(YType.str, 'peer-id-xr'), ['str'])),
                            ('mapping_tlv_count', (YLeaf(YType.uint32, 'mapping-tlv-count'), ['int'])),
                            ('notification_tlv_count', (YLeaf(YType.uint32, 'notification-tlv-count'), ['int'])),
                        ])
                        self.peer_id = None
                        self.fe_ctype = None
                        self.pw_id = None
                        self.agi_type = None
                        self.agi = None
                        self.saii_type = None
                        self.saii_local_id = None
                        self.saii_global_id = None
                        self.saii_prefix = None
                        self.saii_ac_id = None
                        self.taii_type = None
                        self.taii_local_id = None
                        self.taii_global_id = None
                        self.taii_prefix = None
                        self.taii_ac_id = None
                        self.peer_id_xr = None
                        self.mapping_tlv_count = None
                        self.notification_tlv_count = None

                        self.fec_info = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._segment_path = lambda: "ato-mdb-table-entry"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry, ['peer_id', 'fe_ctype', 'pw_id', 'agi_type', 'agi', 'saii_type', 'saii_local_id', 'saii_global_id', 'saii_prefix', 'saii_ac_id', 'taii_type', 'taii_local_id', 'taii_global_id', 'taii_prefix', 'taii_ac_id', 'peer_id_xr', 'mapping_tlv_count', 'notification_tlv_count'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:  :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:  :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:  :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:  :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fec128", ("fec128", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128)), ("fec129", ("fec129", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129)), ("fec130", ("fec130", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130))])
                            self._leafs = OrderedDict([
                                ('fe_ctype', (YLeaf(YType.enumeration, 'fe-ctype'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwFec', '')])),
                            ])
                            self.fe_ctype = None

                            self.fec128 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"

                            self.fec129 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"

                            self.fec130 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._segment_path = lambda: "fec-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pseudowire_id', (YLeaf(YType.uint32, 'pseudowire-id'), ['int'])),
                                ])
                                self.pseudowire_id = None
                                self._segment_path = lambda: "fec128"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:  :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi)), ("saii", ("saii", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii)), ("taii", ("taii", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"

                                self.taii = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._segment_path = lambda: "fec129"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/agi/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "taii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi)), ("saii", ("saii", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._segment_path = lambda: "fec130"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/agi/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.NsrSummaryAll.Vrf>`
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.NsrSummaryAll.Sessions>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.NsrSummaryAll.Vrf)), ("sessions", ("sessions", MplsLdp.Global.Active.NsrSummaryAll.Sessions))])
                    self._leafs = OrderedDict()

                    self.vrf = MplsLdp.Global.Active.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.sessions = MplsLdp.Global.Active.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._segment_path = lambda: "nsr-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.NsrSummaryAll, [], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/nsr-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.NsrSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                            ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                            ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                            ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                            ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                            ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                            ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                            ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                            ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                            ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                        ])
                        self.total = None
                        self.nsr_eligible = None
                        self.nsr_state_none = None
                        self.nsr_state_wait = None
                        self.nsr_state_ready = None
                        self.nsr_state_prepare = None
                        self.nsr_state_app_wait = None
                        self.nsr_state_operational = None
                        self.nsr_state_tcp_phase1 = None
                        self.nsr_state_tcp_phase2 = None
                        self._segment_path = lambda: "sessions"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/nsr-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.NsrSummaryAll.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Summary.Common>`
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\: bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\: bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\: bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\: bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\: bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\: bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\: bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\: bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\: bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\: bool
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("common", ("common", MplsLdp.Global.Active.Summary.Common))])
                    self._leafs = OrderedDict([
                        ('number_of_vrf', (YLeaf(YType.uint32, 'number-of-vrf'), ['int'])),
                        ('number_of_vrf_oper', (YLeaf(YType.uint32, 'number-of-vrf-oper'), ['int'])),
                        ('number_of_interfaces', (YLeaf(YType.uint32, 'number-of-interfaces'), ['int'])),
                        ('number_of_fwd_ref_interfaces', (YLeaf(YType.uint32, 'number-of-fwd-ref-interfaces'), ['int'])),
                        ('number_of_autocfg_interfaces', (YLeaf(YType.uint32, 'number-of-autocfg-interfaces'), ['int'])),
                        ('is_bound_with_sysdb', (YLeaf(YType.boolean, 'is-bound-with-sysdb'), ['bool'])),
                        ('is_registered_with_sysdb', (YLeaf(YType.boolean, 'is-registered-with-sysdb'), ['bool'])),
                        ('is_bound_with_rsi', (YLeaf(YType.boolean, 'is-bound-with-rsi'), ['bool'])),
                        ('is_bound_with_interface_manager', (YLeaf(YType.boolean, 'is-bound-with-interface-manager'), ['bool'])),
                        ('is_registered_with_interface_manager', (YLeaf(YType.boolean, 'is-registered-with-interface-manager'), ['bool'])),
                        ('is_bound_with_ip_arm', (YLeaf(YType.boolean, 'is-bound-with-ip-arm'), ['bool'])),
                        ('is_bound_with_lsd', (YLeaf(YType.boolean, 'is-bound-with-lsd'), ['bool'])),
                        ('is_registered_with_lsd', (YLeaf(YType.boolean, 'is-registered-with-lsd'), ['bool'])),
                        ('is_bound_with_ipv4_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv4-rib'), ['bool'])),
                        ('is_registered_with_ipv4_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv4-rib'), ['bool'])),
                        ('number_of_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-ipv4rib-tables'), ['int'])),
                        ('number_of_registered_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv4rib-tables'), ['int'])),
                        ('is_bound_with_ipv6_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv6-rib'), ['bool'])),
                        ('is_registered_with_ipv6_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv6-rib'), ['bool'])),
                        ('number_of_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-ipv6rib-tables'), ['int'])),
                        ('number_of_registered_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv6rib-tables'), ['int'])),
                        ('is_bound_with_atom', (YLeaf(YType.boolean, 'is-bound-with-atom'), ['bool'])),
                        ('is_bound_with_nsr_mate', (YLeaf(YType.boolean, 'is-bound-with-nsr-mate'), ['bool'])),
                        ('is_nsr_configured', (YLeaf(YType.boolean, 'is-nsr-configured'), ['bool'])),
                        ('is_mldp_registered', (YLeaf(YType.boolean, 'is-mldp-registered'), ['bool'])),
                    ])
                    self.number_of_vrf = None
                    self.number_of_vrf_oper = None
                    self.number_of_interfaces = None
                    self.number_of_fwd_ref_interfaces = None
                    self.number_of_autocfg_interfaces = None
                    self.is_bound_with_sysdb = None
                    self.is_registered_with_sysdb = None
                    self.is_bound_with_rsi = None
                    self.is_bound_with_interface_manager = None
                    self.is_registered_with_interface_manager = None
                    self.is_bound_with_ip_arm = None
                    self.is_bound_with_lsd = None
                    self.is_registered_with_lsd = None
                    self.is_bound_with_ipv4_rib = None
                    self.is_registered_with_ipv4_rib = None
                    self.number_of_ipv4rib_tables = None
                    self.number_of_registered_ipv4rib_tables = None
                    self.is_bound_with_ipv6_rib = None
                    self.is_registered_with_ipv6_rib = None
                    self.number_of_ipv6rib_tables = None
                    self.number_of_registered_ipv6rib_tables = None
                    self.is_bound_with_atom = None
                    self.is_bound_with_nsr_mate = None
                    self.is_nsr_configured = None
                    self.is_mldp_registered = None

                    self.common = MplsLdp.Global.Active.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.Summary, [u'number_of_vrf', u'number_of_vrf_oper', u'number_of_interfaces', u'number_of_fwd_ref_interfaces', u'number_of_autocfg_interfaces', u'is_bound_with_sysdb', u'is_registered_with_sysdb', u'is_bound_with_rsi', u'is_bound_with_interface_manager', u'is_registered_with_interface_manager', u'is_bound_with_ip_arm', u'is_bound_with_lsd', u'is_registered_with_lsd', u'is_bound_with_ipv4_rib', u'is_registered_with_ipv4_rib', u'number_of_ipv4rib_tables', u'number_of_registered_ipv4rib_tables', u'is_bound_with_ipv6_rib', u'is_registered_with_ipv6_rib', u'number_of_ipv6rib_tables', u'number_of_registered_ipv6rib_tables', u'is_bound_with_atom', u'is_bound_with_nsr_mate', u'is_nsr_configured', u'is_mldp_registered'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                            ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                            ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                            ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                            ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                            ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                            ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                            ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                            ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                            ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                            ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                            ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                            ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                            ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                            ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                            ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                            ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                            ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                            ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                            ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                            ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                        ])
                        self.address_families = None
                        self.number_of_ipv4af = None
                        self.number_of_ipv6af = None
                        self.number_of_neighbors = None
                        self.number_of_nsr_synced_neighbors = None
                        self.number_of_graceful_restart_neighbors = None
                        self.number_of_downstream_on_demand_neighbors = None
                        self.number_of_ipv4_hello_adj = None
                        self.number_of_ipv6_hello_adj = None
                        self.number_of_ipv4_routes = None
                        self.number_of_ipv6_routes = None
                        self.number_of_ipv4_local_addresses = None
                        self.number_of_ipv6_local_addresses = None
                        self.number_of_ldp_interfaces = None
                        self.number_of_ipv4ldp_interfaces = None
                        self.number_of_ipv6ldp_interfaces = None
                        self.number_of_bindings_ipv4 = None
                        self.number_of_bindings_ipv6 = None
                        self.number_of_local_bindings_ipv4 = None
                        self.number_of_local_bindings_ipv6 = None
                        self.number_of_remote_bindings_ipv4 = None
                        self.number_of_remote_bindings_ipv6 = None
                        self._segment_path = lambda: "common"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/summary/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  (key)
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Statistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['vrf_name']
                        self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Global.Active.Vrfs.Vrf.Capabilities)), ("summary", ("summary", MplsLdp.Global.Active.Vrfs.Vrf.Summary)), ("afs", ("afs", MplsLdp.Global.Active.Vrfs.Vrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Global.Active.Vrfs.Vrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Global.Active.Vrfs.Vrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Global.Active.Vrfs.Vrf.Nsr)), ("parameters", ("parameters", MplsLdp.Global.Active.Vrfs.Vrf.Parameters)), ("issu", ("issu", MplsLdp.Global.Active.Vrfs.Vrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Global.Active.Vrfs.Vrf.LdpId)), ("statistics", ("statistics", MplsLdp.Global.Active.Vrfs.Vrf.Statistics))])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.vrf_name = None

                        self.graceful_restart = MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"

                        self.capabilities = MplsLdp.Global.Active.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"

                        self.summary = MplsLdp.Global.Active.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"

                        self.afs = MplsLdp.Global.Active.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"

                        self.neighbor_briefs = MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                        self.backoff_parameters = MplsLdp.Global.Active.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"

                        self.backoffs = MplsLdp.Global.Active.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"

                        self.nsr = MplsLdp.Global.Active.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"

                        self.parameters = MplsLdp.Global.Active.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"

                        self.issu = MplsLdp.Global.Active.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"

                        self.neighbor_capabilities = MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                        self.neighbors = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.ldp_id = MplsLdp.Global.Active.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"

                        self.statistics = MplsLdp.Global.Active.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/vrfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.Vrf_>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\: bool
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.Vrf_)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor))])
                            self._leafs = OrderedDict([
                                ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                                ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                            ])
                            self.is_forwarding_state_hold_timer_running = None
                            self.forwarding_state_hold_timer_remaining_seconds = None

                            self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.Vrf_, [u'name', u'id'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\: bool
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\: bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\: bool
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                                self._leafs = OrderedDict([
                                    ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                    ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                    ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                    ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                    ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                    ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                    ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                    ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                    ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                                ])
                                self.connect_count = None
                                self.is_neighbor_up = None
                                self.is_liveness_timer_running = None
                                self.liveness_timer_remaining_seconds = None
                                self.is_recovery_timer_running = None
                                self.recovery_timer_remaining_seconds = None
                                self.down_nbr_flap_count = None
                                self.down_nbr_flags = None
                                self.down_nbr_down_reason = None

                                self.gr_peer = MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"

                                self.down_nbr_interface = YList(self)
                                self.down_nbr_address = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.ldp_id = None
                                    self._segment_path = lambda: "gr-peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                    ])
                                    self.address_family = None
                                    self.interface_handle = None
                                    self._segment_path = lambda: "down-nbr-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "down-nbr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability))])
                            self._leafs = OrderedDict()

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  (key)
                            
                            	The capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability.Capability_>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['capability_type']
                                self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability.Capability_))])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                    ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                                ])
                                self.capability_type = None
                                self.capability_owner = None

                                self.capability = MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability.Capability_()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                            class Capability_(Entity):
                                """
                                Capability information
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability.Capability_, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Summary.Vrf_>`
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Summary.Common>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Summary.Vrf_)), ("common", ("common", MplsLdp.Global.Active.Vrfs.Vrf.Summary.Common))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Summary.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.common = MplsLdp.Global.Active.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._segment_path = lambda: "summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Summary, [], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Summary.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Summary.Vrf_, [u'name', u'id'], name, value)


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                    ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                    ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                    ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                    ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                    ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                    ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                    ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                    ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                    ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                    ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                    ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                    ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                    ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                    ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                    ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                    ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                    ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                    ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                    ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                    ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                                ])
                                self.address_families = None
                                self.number_of_ipv4af = None
                                self.number_of_ipv6af = None
                                self.number_of_neighbors = None
                                self.number_of_nsr_synced_neighbors = None
                                self.number_of_graceful_restart_neighbors = None
                                self.number_of_downstream_on_demand_neighbors = None
                                self.number_of_ipv4_hello_adj = None
                                self.number_of_ipv6_hello_adj = None
                                self.number_of_ipv4_routes = None
                                self.number_of_ipv6_routes = None
                                self.number_of_ipv4_local_addresses = None
                                self.number_of_ipv6_local_addresses = None
                                self.number_of_ldp_interfaces = None
                                self.number_of_ipv4ldp_interfaces = None
                                self.number_of_ipv6ldp_interfaces = None
                                self.number_of_bindings_ipv4 = None
                                self.number_of_bindings_ipv6 = None
                                self.number_of_local_bindings_ipv4 = None
                                self.number_of_local_bindings_ipv6 = None
                                self.number_of_remote_bindings_ipv4 = None
                                self.number_of_remote_bindings_ipv6 = None
                                self._segment_path = lambda: "common"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("af", ("af", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af))])
                            self._leafs = OrderedDict()

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  (key)
                            
                            	Address Family name
                            	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['af_name']
                                self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary))])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                                ])
                                self.af_name = None

                                self.interface_summary = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"

                                self.bindings = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"

                                self.igp = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"

                                self.bindings_summary = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"

                                self.interfaces = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"

                                self.discovery = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"

                                self.forwardings = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"

                                self.bindings_advertise_spec = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                                self.forwarding_summary = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                        ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                        ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                        ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                        ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                        ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                        ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                        ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                    ])
                                    self.known_ip_interface_count = None
                                    self.known_ip_interface_ldp_enabled = None
                                    self.ldp_configured_attached_interface = None
                                    self.ldp_configured_te_interface = None
                                    self.forward_references = None
                                    self.auto_config_disabled = None
                                    self.auto_config = None
                                    self.auto_config_forward_reference_interfaces = None
                                    self._segment_path = lambda: "interface-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding))])
                                    self._leafs = OrderedDict()

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\: str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\: str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                            ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                            ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                            ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                            ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                            ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.local_label = None
                                        self.le_local_binding_revision = None
                                        self.le_local_label_state = None
                                        self.is_no_route = None
                                        self.label_oor = None
                                        self.advertise_prefix_acl = None
                                        self.advertise_tsr_acl = None
                                        self.config_enforced_local_label_value = None
                                        self.is_elc = None

                                        self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.remote_binding = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.peers_acked = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\: bool
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                            self._leafs = OrderedDict([
                                                ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                            ])
                                            self.remote_label = None
                                            self.is_stale = None
                                            self.is_elc = None

                                            self.assigning_peer_ldp_ident = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._segment_path = lambda: "remote-binding"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                ])
                                                self.lsr_id = None
                                                self.label_space_id = None
                                                self.ldp_id = None
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-acked"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart))])
                                    self._leafs = OrderedDict()

                                    self.syncs = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"

                                    self.sync_delay_restart = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._segment_path = lambda: "igp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp, [], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync))])
                                        self._leafs = OrderedDict()

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_)), ("peers", ("peers", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                                ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                                ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                                ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                                ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                            ])
                                            self.interface_name = None
                                            self.interface_name_xr = None
                                            self.igp_sync_state = None
                                            self.igp_sync_delay = None
                                            self.is_delay_timer_running = None
                                            self.delay_timer_remaining = None
                                            self.igp_sync_down_reason = None

                                            self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.peers = YList(self)
                                            self.gr_only_peer = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, [u'name', u'id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_gr_enabled = None
                                                self._segment_path = lambda: "peers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_chkpt_created = None
                                                self._segment_path = lambda: "gr-only-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                            ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                            ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                            ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                        ])
                                        self.configured = None
                                        self.delay_secs = None
                                        self.timer_running = None
                                        self.remaining_secs = None
                                        self._segment_path = lambda: "sync-delay-restart"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_>`
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_)), ("bind-af", ("bind_af", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf))])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.binding_no_route = None
                                    self.binding_local_no_route = None
                                    self.binding_local_null = None
                                    self.binding_local_implicit_null = None
                                    self.binding_local_explicit_null = None
                                    self.binding_local_non_null = None
                                    self.binding_local_oor = None
                                    self.lowest_allocated_label = None
                                    self.highest_allocated_label = None

                                    self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, [u'name', u'id'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                        ])
                                        self.address_family = None
                                        self.last_lib_update = None
                                        self.lib_minimum_revision_sent_all = None
                                        self.binding_total = None
                                        self.binding_local = None
                                        self.binding_remote = None
                                        self._segment_path = lambda: "bind-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface))])
                                    self._leafs = OrderedDict()

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                            ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                            ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                            ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.ldp_enabled = None
                                        self.is_im_stale = None
                                        self.ldp_config_mode = None
                                        self.ldp_autoconfig_disable = None

                                        self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.te_mesh_grp = YList(self)
                                        self.auto_config = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, [u'name', u'id'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\: bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                                ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                                ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                            ])
                                            self.ldp_te_mesh_group_all_cfgd = None
                                            self.ldp_mesh_group_enabled = None
                                            self.te_mesh_group_id = None
                                            self._segment_path = lambda: "te-mesh-grp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                            ])
                                            self.tuple = None
                                            self._segment_path = lambda: "auto-config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats))])
                                    self._leafs = OrderedDict()

                                    self.link_hellos = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"

                                    self.summary = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"

                                    self.targeted_hellos = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                    self.brief = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"

                                    self.stats = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._segment_path = lambda: "discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery, [], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                        self._leafs = OrderedDict()

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_>`
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hello = None
                                            self.interface = None
                                            self.interface_name_xr = None
                                            self.quick_start_disabled = None

                                            self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self.discovery_link_af = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\: bool
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\: bool
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                    ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                    ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                    ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                    ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                    ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.is_no_route = None
                                                self.hold_time = None
                                                self.local_hold_time = None
                                                self.neighbor_hold_time = None
                                                self.disc_expiry = None
                                                self.is_targeted = None
                                                self.session_up = None
                                                self.established_time = None
                                                self.established_age = None
                                                self.session_bringup_failure_reason = None

                                                self.neighbor_src_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                                self.neighbor_transport_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                                self.target = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "target"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\: str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                        ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                        ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                    ])
                                                    self.last_session_down_reason = None
                                                    self.last_session_down_time = None
                                                    self.last_session_up_time = None
                                                    self._segment_path = lambda: "last-session-down-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ])
                                                self.interval = None

                                                self.local_src_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"

                                                self.local_transport_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._segment_path = lambda: "discovery-link-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_>`
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\: str
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_))])
                                        self._leafs = OrderedDict([
                                            ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                            ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                            ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                            ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                            ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                            ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                            ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                            ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                            ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                            ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                            ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                            ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                        ])
                                        self.local_ldp_id = None
                                        self.num_of_ldp_interfaces = None
                                        self.num_of_active_ldp_interfaces = None
                                        self.num_of_lnk_disc_xmit = None
                                        self.num_of_tgt_disc_xmit = None
                                        self.num_of_lnk_disc_recv = None
                                        self.num_of_tgt_disc_recv = None
                                        self.num_of_disc_with_bad_addr_recv = None
                                        self.num_of_disc_with_bad_hello_pdu = None
                                        self.num_of_disc_with_bad_xport_addr = None
                                        self.num_of_disc_with_same_router_id = None
                                        self.num_of_disc_with_wrong_router_id = None

                                        self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, [u'name', u'id'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                                ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.state = None
                                            self.adjacency_ldp_identifier = None
                                            self.interval = None
                                            self.next_hello = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.quick_start_disabled = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_up = None
                                            self.session_bringup_failure_reason = None

                                            self.dhcb_local_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                            self.dhcb_target_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_briefs = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                        self.targeted_hello_briefs = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._segment_path = lambda: "brief"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief, [], name, value)


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	The Interface Name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.address_family = None
                                                self.address_family_set = None
                                                self.interface = None
                                                self.interface_name_xr = None

                                                self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                    ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ])
                                                self.local_address = None
                                                self.target_address = None
                                                self.address_family = None

                                                self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.dhcb_target_address = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "dhcb-target-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat))])
                                        self._leafs = OrderedDict()

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                                ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                                ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                                ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                                ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.adjacency_group_up_time = None
                                            self.tcp_open_count = None
                                            self.tcp_arb_chg_count = None
                                            self.tcp_role = None
                                            self._segment_path = lambda: "stat"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding))])
                                    self._leafs = OrderedDict()

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.table_id = None
                                        self.prefix_length = None

                                        self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.route = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\: bool
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                    ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                    ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                    ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                    ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                                ])
                                                self.version = None
                                                self.priority = None
                                                self.source = None
                                                self.type = None
                                                self.flags = None
                                                self.metric = None
                                                self.is_local_vrf_leaked = None
                                                self.routing_update_count = None
                                                self.routing_update_timestamp = None
                                                self.routing_update_age = None
                                                self.sr_local_label = None
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                    ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                    ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                                ])
                                                self.local_label = None
                                                self.forwarding_update_count = None
                                                self.forwarding_update_timestamp = None
                                                self.forwarding_update_age = None
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\: str
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                    ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                    ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                    ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                                ])
                                                self.interface = None
                                                self.interface_name = None
                                                self.nh_is_overriden = None
                                                self.nexthop_id = None
                                                self.next_hop_table_id = None
                                                self.flags = None
                                                self.load_metric = None
                                                self.path_id = None
                                                self.bkup_path_id = None
                                                self.path_flags = None

                                                self.next_hop = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.remote_lfa = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\: bool
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                        ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                        ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None
                                                    self.needs_tldp = None
                                                    self.has_q_node = None

                                                    self.remote_p_node_id = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                    self.remote_q_node_id = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-p-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-q-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                                self._leafs = OrderedDict()

                                                self.mpls_outgoing_info = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                                self.remote_lfa = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\: bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                    self._leafs = OrderedDict([
                                                        ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                        ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                        ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                        ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                        ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                        ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                    ])
                                                    self.out_label = None
                                                    self.out_label_rsn = None
                                                    self.out_label_type = None
                                                    self.out_label_owner = None
                                                    self.is_from_graceful_restartable_neighbor = None
                                                    self.is_stale = None

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                        ])
                                                        self.lsr_id = None
                                                        self.label_space_id = None
                                                        self.ldp_id = None
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None

                                                    self.mpls_outgoing_info = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                        self._leafs = OrderedDict()

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\: bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                            self._leafs = OrderedDict([
                                                                ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                                ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                                ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                                ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                                ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                            ])
                                                            self.out_label = None
                                                            self.out_label_rsn = None
                                                            self.out_label_type = None
                                                            self.out_label_owner = None
                                                            self.is_from_graceful_restartable_neighbor = None
                                                            self.is_stale = None

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._segment_path = lambda: "stack"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                                ])
                                                                self.lsr_id = None
                                                                self.label_space_id = None
                                                                self.ldp_id = None
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                    self._leafs = OrderedDict()

                                    self.allocation_acl = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                        ])
                                        self.has_acl = None
                                        self.prefix_acl = None
                                        self.is_host_route_only = None
                                        self._segment_path = lambda: "allocation-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                        ])
                                        self.prefix_acl = None
                                        self.peer_acl = None
                                        self._segment_path = lambda: "advt-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_>`
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\: bool
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_)), ("rws", ("rws", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws))])
                                    self._leafs = OrderedDict([
                                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                    ])
                                    self.is_lsd_bound = None
                                    self.fsht = None
                                    self.intfs = None
                                    self.lbls = None

                                    self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.rws = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._segment_path = lambda: "forwarding-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, [u'name', u'id'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                        self._leafs = OrderedDict()

                                        self.pfxs = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"

                                        self.nhs = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._segment_path = lambda: "rws"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                            self._leafs = OrderedDict([
                                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                            ])
                                            self.total_pfxs = None
                                            self.ecmp_pfxs = None
                                            self.protected_pfxs = None

                                            self.labeled_pfxs_aggr = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                            self.labeled_pfxs_primary = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                            self.labeled_pfxs_backup = MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._segment_path = lambda: "pfxs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-primary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                            ])
                                            self.total_paths = None
                                            self.protected_paths = None
                                            self.backup_paths = None
                                            self.remote_backup_paths = None
                                            self.labeled_paths = None
                                            self.labeled_backup_paths = None
                                            self._segment_path = lambda: "nhs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief))])
                            self._leafs = OrderedDict()

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_>`
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\: bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                    ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.is_graceful_restartable = None
                                self.nsr_state = None
                                self.up_time_seconds = None

                                self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, [u'name', u'id'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                        ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                        ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.num_of_nbr_discovery = None
                                    self.num_of_nbr_addresses = None
                                    self.num_of_nbr_lbl = None
                                    self._segment_path = lambda: "nbr-br-af-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                                ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                            ])
                            self.initial_seconds = None
                            self.maximum_seconds = None
                            self._segment_path = lambda: "backoff-parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Global.Active.Vrfs.Vrf.Backoffs.Backoff))])
                            self._leafs = OrderedDict()

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                    ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.backoff_seconds = None
                                self.waiting_seconds = None
                                self._segment_path = lambda: "backoff"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.nsr_pending = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"

                            self.ha_summary = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "nsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr, [], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_neighbors = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "nsr-pending"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending, [], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\: bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\: bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\: bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\: bool
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\: bool
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\: bool
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Global.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter))])
                            self._leafs = OrderedDict([
                                ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                                ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                                ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                                ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                                ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                                ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                                ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                                ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                                ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                                ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                                ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                                ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                                ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                                ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                                ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                                ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                                ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                            ])
                            self.role_is_active = None
                            self.global_md5_password_enabled = None
                            self.protocol_version = None
                            self.router_id = None
                            self.keepalive_interval = None
                            self.hello_hold_time = None
                            self.hello_interval = None
                            self.targeted_hello_hold_time = None
                            self.targeted_hello_interval = None
                            self.session_hold_time = None
                            self.housekeeping_timer_interval = None
                            self.le_no_route_timeout = None
                            self.ldp_recovery_timeout = None
                            self.af_binding_withdraw_delay = None
                            self.max_intf_attached = None
                            self.max_intf_te = None
                            self.max_peer = None
                            self.ldp_out_of_mem_state = None
                            self.nsr_enabled = None
                            self.nsr_synced = None
                            self.igp_sync_delay_time_for_interface = None
                            self.igp_sync_delay_time_on_restart = None
                            self.global_discovery_quick_start_disabled = None
                            self.discovery_quick_start_disabled_on_interfaces = None

                            self.graceful_restart_information = MplsLdp.Global.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                    ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                    ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                                ])
                                self.is_graceful_restart_configured = None
                                self.graceful_restart_reconnect_timeout = None
                                self.graceful_restart_forwarding_state_hold_time = None
                                self._segment_path = lambda: "graceful-restart-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\: str
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\: str
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\: bool
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                    ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                    ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                    ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                                ])
                                self.address_family = None
                                self.null_label = None
                                self.label_imp_null_override_acl = None
                                self.is_accepting_targeted_hellos = None
                                self.targeted_hello_acl = None

                                self.discovery_transport_address = MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._segment_path = lambda: "address-family-parameter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "discovery-transport-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.ha_summary = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "issu"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu, [], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability))])
                            self._leafs = OrderedDict()

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.sent = YList(self)
                                self.received = YList(self)
                                self._segment_path = lambda: "neighbor-capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "sent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "received"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.protocol_information = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"

                                self.tcp_information = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"

                                self.detailed_information = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\: str
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                    self._leafs = OrderedDict([
                                        ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                        ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                        ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                        ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                        ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                        ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                    ])
                                    self.ta_holdtime = None
                                    self.ta_state = None
                                    self.ta_pies_sent = None
                                    self.ta_pies_rcvd = None
                                    self.ta_up_time_seconds = None
                                    self.downstream_on_demand = None

                                    self.ta_graceful_restart_adjacency = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._segment_path = lambda: "protocol-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\: bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                            ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                            ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                        ])
                                        self.is_graceful_restartable = None
                                        self.reconnect_timeout = None
                                        self.recovery_time = None
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                    self._leafs = OrderedDict([
                                        ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                        ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                        ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                    ])
                                    self.foreign_port = None
                                    self.local_port = None
                                    self.is_md5_on = None

                                    self.foreign_host = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"

                                    self.local_host = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._segment_path = lambda: "tcp-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "foreign-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "local-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\: bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\: bool
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\: bool
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\: bool
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\: bool
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                    self._leafs = OrderedDict([
                                        ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                        ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                        ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                        ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                        ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                        ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                        ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                        ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                        ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                        ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                        ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                        ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                        ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                        ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                        ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                        ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                        ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                        ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                        ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                        ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                        ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                    ])
                                    self.peer_holdtime = None
                                    self.keep_alive_interval = None
                                    self.peer_state = None
                                    self.has_ipv4_inbound = None
                                    self.inbound_ipv4acl = None
                                    self.has_ipv6_inbound = None
                                    self.inbound_ipv6acl = None
                                    self.has_ipv4_outbound = None
                                    self.outbound_ipv4acl = None
                                    self.has_ipv6_outbound = None
                                    self.outbound_ipv6acl = None
                                    self.has_sp = None
                                    self.sp_state = None
                                    self.sp_has_acl = None
                                    self.spacl = None
                                    self.sp_has_duration = None
                                    self.sp_duration = None
                                    self.spht_running = None
                                    self.spht_remaining = None
                                    self.nsr_sync_state = None
                                    self.nsr_last_sync_error = None
                                    self.nsr_last_sync_nack_reason = None
                                    self.bgp_advertisement_state = None
                                    self.advertise_bgp_prefixes = None

                                    self.capabilities = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                        self._leafs = OrderedDict()

                                        self.sent = YList(self)
                                        self.received = YList(self)
                                        self._segment_path = lambda: "capabilities"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "sent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "received"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "client"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv4-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv6-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.ldp_id = None
                            self._segment_path = lambda: "ldp-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Global.Active.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic))])
                            self._leafs = OrderedDict()

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.iccp_enabled = None

                                self.message_out = MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"

                                self.message_in = MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._segment_path = lambda: "statistic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-out"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global.Active.DiscoverySummaryAll.Vrf>`
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\: str
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Global.Active.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Global.Active.DiscoverySummaryAll.Vrf))])
                    self._leafs = OrderedDict([
                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                    ])
                    self.local_ldp_id = None
                    self.num_of_ldp_interfaces = None
                    self.num_of_active_ldp_interfaces = None
                    self.num_of_lnk_disc_xmit = None
                    self.num_of_tgt_disc_xmit = None
                    self.num_of_lnk_disc_recv = None
                    self.num_of_tgt_disc_recv = None
                    self.num_of_disc_with_bad_addr_recv = None
                    self.num_of_disc_with_bad_hello_pdu = None
                    self.num_of_disc_with_bad_xport_addr = None
                    self.num_of_disc_with_same_router_id = None
                    self.num_of_disc_with_wrong_router_id = None

                    self.vrf = MplsLdp.Global.Active.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "discovery-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global.Active.DiscoverySummaryAll, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Global.Active.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/discovery-summary-all/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global.Active.DiscoverySummaryAll.Vrf, [u'name', u'id'], name, value)


    class Nodes(Entity):
        """
        Location MPLS LDP operational data
        
        .. attribute:: node
        
        	The MPLD LDP operational data for a particular node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node>`
        
        

        """

        _prefix = 'mpls-ldp-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(MplsLdp.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "mpls-ldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", MplsLdp.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(MplsLdp.Nodes, [], name, value)


        class Node(Entity):
            """
            The MPLD LDP operational data for a particular
            node
            
            .. attribute:: node_name  (key)
            
            	The identifier for the node
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:  :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:  :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll>`
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:  :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:  :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:  :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DiscoverySummaryAll>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(MplsLdp.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_name']
                self._child_classes = OrderedDict([("default-vrf", ("default_vrf", MplsLdp.Nodes.Node.DefaultVrf)), ("forwarding-summary-all", ("forwarding_summary_all", MplsLdp.Nodes.Node.ForwardingSummaryAll)), ("bindings-summary-all", ("bindings_summary_all", MplsLdp.Nodes.Node.BindingsSummaryAll)), ("ato-mdb-table-entries", ("ato_mdb_table_entries", MplsLdp.Nodes.Node.AtoMdbTableEntries)), ("nsr-summary-all", ("nsr_summary_all", MplsLdp.Nodes.Node.NsrSummaryAll)), ("summary", ("summary", MplsLdp.Nodes.Node.Summary)), ("vrfs", ("vrfs", MplsLdp.Nodes.Node.Vrfs)), ("discovery-summary-all", ("discovery_summary_all", MplsLdp.Nodes.Node.DiscoverySummaryAll))])
                self._leafs = OrderedDict([
                    ('node_name', (YLeaf(YType.str, 'node-name'), ['str'])),
                ])
                self.node_name = None

                self.default_vrf = MplsLdp.Nodes.Node.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"

                self.forwarding_summary_all = MplsLdp.Nodes.Node.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"

                self.bindings_summary_all = MplsLdp.Nodes.Node.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"

                self.ato_mdb_table_entries = MplsLdp.Nodes.Node.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"

                self.nsr_summary_all = MplsLdp.Nodes.Node.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"

                self.summary = MplsLdp.Nodes.Node.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.vrfs = MplsLdp.Nodes.Node.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"

                self.discovery_summary_all = MplsLdp.Nodes.Node.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._segment_path = lambda: "node" + "[node-name='" + str(self.node_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/nodes/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(MplsLdp.Nodes.Node, ['node_name'], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary>`
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Backoffs>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.LdpId>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Nodes.Node.DefaultVrf.Capabilities)), ("summary", ("summary", MplsLdp.Nodes.Node.DefaultVrf.Summary)), ("afs", ("afs", MplsLdp.Nodes.Node.DefaultVrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Nodes.Node.DefaultVrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Nodes.Node.DefaultVrf.Nsr)), ("parameters", ("parameters", MplsLdp.Nodes.Node.DefaultVrf.Parameters)), ("issu", ("issu", MplsLdp.Nodes.Node.DefaultVrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Nodes.Node.DefaultVrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Nodes.Node.DefaultVrf.LdpId)), ("statistics", ("statistics", MplsLdp.Nodes.Node.DefaultVrf.Statistics))])
                    self._leafs = OrderedDict()

                    self.graceful_restart = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"

                    self.capabilities = MplsLdp.Nodes.Node.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"

                    self.summary = MplsLdp.Nodes.Node.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.afs = MplsLdp.Nodes.Node.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"

                    self.neighbor_briefs = MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                    self.backoff_parameters = MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"

                    self.backoffs = MplsLdp.Nodes.Node.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"

                    self.nsr = MplsLdp.Nodes.Node.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"

                    self.parameters = MplsLdp.Nodes.Node.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"

                    self.issu = MplsLdp.Nodes.Node.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"

                    self.neighbor_capabilities = MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                    self.neighbors = MplsLdp.Nodes.Node.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"

                    self.ldp_id = MplsLdp.Nodes.Node.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"

                    self.statistics = MplsLdp.Nodes.Node.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._segment_path = lambda: "default-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf, [], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\: bool
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor))])
                        self._leafs = OrderedDict([
                            ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                            ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                        ])
                        self.is_forwarding_state_hold_timer_running = None
                        self.forwarding_state_hold_timer_remaining_seconds = None

                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf, [u'name', u'id'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\: bool
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\: bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\: bool
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                            self._leafs = OrderedDict([
                                ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                            ])
                            self.connect_count = None
                            self.is_neighbor_up = None
                            self.is_liveness_timer_running = None
                            self.liveness_timer_remaining_seconds = None
                            self.is_recovery_timer_running = None
                            self.recovery_timer_remaining_seconds = None
                            self.down_nbr_flap_count = None
                            self.down_nbr_flags = None
                            self.down_nbr_down_reason = None

                            self.gr_peer = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"

                            self.down_nbr_interface = YList(self)
                            self.down_nbr_address = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.ldp_id = None
                                self._segment_path = lambda: "gr-peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                ])
                                self.address_family = None
                                self.interface_handle = None
                                self._segment_path = lambda: "down-nbr-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "down-nbr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability))])
                        self._leafs = OrderedDict()

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  (key)
                        
                        	The capability type (IANA assigned)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability_>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['capability_type']
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability_))])
                            self._leafs = OrderedDict([
                                ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                            ])
                            self.capability_type = None
                            self.capability_owner = None

                            self.capability = MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability_()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                        class Capability_(Entity):
                            """
                            Capability information
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability_, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf>`
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary.Common>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf)), ("common", ("common", MplsLdp.Nodes.Node.DefaultVrf.Summary.Common))])
                        self._leafs = OrderedDict()

                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"

                        self.common = MplsLdp.Nodes.Node.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Summary, [], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.name = None
                            self.id = None
                            self._segment_path = lambda: "vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf, [u'name', u'id'], name, value)


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                            ])
                            self.address_families = None
                            self.number_of_ipv4af = None
                            self.number_of_ipv6af = None
                            self.number_of_neighbors = None
                            self.number_of_nsr_synced_neighbors = None
                            self.number_of_graceful_restart_neighbors = None
                            self.number_of_downstream_on_demand_neighbors = None
                            self.number_of_ipv4_hello_adj = None
                            self.number_of_ipv6_hello_adj = None
                            self.number_of_ipv4_routes = None
                            self.number_of_ipv6_routes = None
                            self.number_of_ipv4_local_addresses = None
                            self.number_of_ipv6_local_addresses = None
                            self.number_of_ldp_interfaces = None
                            self.number_of_ipv4ldp_interfaces = None
                            self.number_of_ipv6ldp_interfaces = None
                            self.number_of_bindings_ipv4 = None
                            self.number_of_bindings_ipv6 = None
                            self.number_of_local_bindings_ipv4 = None
                            self.number_of_local_bindings_ipv6 = None
                            self.number_of_remote_bindings_ipv4 = None
                            self.number_of_remote_bindings_ipv6 = None
                            self._segment_path = lambda: "common"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("af", ("af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af))])
                        self._leafs = OrderedDict()

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  (key)
                        
                        	Address Family name
                        	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['af_name']
                            self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                            ])
                            self.af_name = None

                            self.interface_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"

                            self.bindings = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"

                            self.igp = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"

                            self.bindings_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"

                            self.interfaces = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"

                            self.discovery = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"

                            self.forwardings = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"

                            self.bindings_advertise_spec = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                            self.forwarding_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                    ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                    ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                    ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                    ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                    ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                    ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                    ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                ])
                                self.known_ip_interface_count = None
                                self.known_ip_interface_ldp_enabled = None
                                self.ldp_configured_attached_interface = None
                                self.ldp_configured_te_interface = None
                                self.forward_references = None
                                self.auto_config_disabled = None
                                self.auto_config = None
                                self.auto_config_forward_reference_interfaces = None
                                self._segment_path = lambda: "interface-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding))])
                                self._leafs = OrderedDict()

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\: bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\: bool
                                
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\: str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\: str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\: bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\: bool
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                        ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                        ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                        ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                        ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                        ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                        ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                        ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                        ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None
                                    self.local_label = None
                                    self.le_local_binding_revision = None
                                    self.le_local_label_state = None
                                    self.is_no_route = None
                                    self.label_oor = None
                                    self.advertise_prefix_acl = None
                                    self.advertise_tsr_acl = None
                                    self.config_enforced_local_label_value = None
                                    self.is_elc = None

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.remote_binding = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.peers_acked = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                        self._leafs = OrderedDict([
                                            ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.remote_label = None
                                        self.is_stale = None
                                        self.is_elc = None

                                        self.assigning_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._segment_path = lambda: "remote-binding"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-advertised-to"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.ldp_id = None
                                        self._segment_path = lambda: "peers-acked"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart))])
                                self._leafs = OrderedDict()

                                self.syncs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"

                                self.sync_delay_restart = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._segment_path = lambda: "igp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp, [], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync))])
                                    self._leafs = OrderedDict()

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)), ("peers", ("peers", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                            ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                            ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                            ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                            ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                        ])
                                        self.interface_name = None
                                        self.interface_name_xr = None
                                        self.igp_sync_state = None
                                        self.igp_sync_delay = None
                                        self.is_delay_timer_running = None
                                        self.delay_timer_remaining = None
                                        self.igp_sync_down_reason = None

                                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.peers = YList(self)
                                        self.gr_only_peer = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, [u'name', u'id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_gr_enabled = None
                                            self._segment_path = lambda: "peers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                            ])
                                            self.peer_id = None
                                            self.is_chkpt_created = None
                                            self._segment_path = lambda: "gr-only-peer"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\: bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\: bool
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                        ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                        ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                        ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                    ])
                                    self.configured = None
                                    self.delay_secs = None
                                    self.timer_running = None
                                    self.remaining_secs = None
                                    self._segment_path = lambda: "sync-delay-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf)), ("bind-af", ("bind_af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                    ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                    ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                    ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                    ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                    ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                    ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                    ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                    ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                ])
                                self.address_family = None
                                self.binding_no_route = None
                                self.binding_local_no_route = None
                                self.binding_local_null = None
                                self.binding_local_implicit_null = None
                                self.binding_local_explicit_null = None
                                self.binding_local_non_null = None
                                self.binding_local_oor = None
                                self.lowest_allocated_label = None
                                self.highest_allocated_label = None

                                self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf, [u'name', u'id'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                        ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                        ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                        ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                        ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.last_lib_update = None
                                    self.lib_minimum_revision_sent_all = None
                                    self.binding_total = None
                                    self.binding_local = None
                                    self.binding_remote = None
                                    self._segment_path = lambda: "bind-af"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  (key)
                                
                                	The Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\: str
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\: bool
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\: bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\: bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\: bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                        ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                        ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                        ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                        ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.interface = None
                                    self.interface_name_xr = None
                                    self.ldp_enabled = None
                                    self.is_im_stale = None
                                    self.ldp_config_mode = None
                                    self.ldp_autoconfig_disable = None

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.te_mesh_grp = YList(self)
                                    self.auto_config = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, [u'name', u'id'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                            ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                            ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                        ])
                                        self.ldp_te_mesh_group_all_cfgd = None
                                        self.ldp_mesh_group_enabled = None
                                        self.te_mesh_group_id = None
                                        self._segment_path = lambda: "te-mesh-grp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                        ])
                                        self.tuple = None
                                        self._segment_path = lambda: "auto-config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats))])
                                self._leafs = OrderedDict()

                                self.link_hellos = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"

                                self.summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"

                                self.targeted_hellos = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                self.brief = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"

                                self.stats = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._segment_path = lambda: "discovery"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery, [], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                    self._leafs = OrderedDict()

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.next_hello = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.quick_start_disabled = None

                                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.hello_information = YList(self)
                                        self.discovery_link_af = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, [u'name', u'id'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\: bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\: bool
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.neighbor_ldp_identifier = None
                                            self.is_no_route = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.is_targeted = None
                                            self.session_up = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_bringup_failure_reason = None

                                            self.neighbor_src_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                            self.neighbor_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                            self.target = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "neighbor-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                            self._leafs = OrderedDict([
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ])
                                            self.interval = None

                                            self.local_src_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"

                                            self.local_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._segment_path = lambda: "discovery-link-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-src-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-transport-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\: str
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                    ])
                                    self.local_ldp_id = None
                                    self.num_of_ldp_interfaces = None
                                    self.num_of_active_ldp_interfaces = None
                                    self.num_of_lnk_disc_xmit = None
                                    self.num_of_tgt_disc_xmit = None
                                    self.num_of_lnk_disc_recv = None
                                    self.num_of_tgt_disc_recv = None
                                    self.num_of_disc_with_bad_addr_recv = None
                                    self.num_of_disc_with_bad_hello_pdu = None
                                    self.num_of_disc_with_bad_xport_addr = None
                                    self.num_of_disc_with_same_router_id = None
                                    self.num_of_disc_with_wrong_router_id = None

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, [u'name', u'id'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                    self._leafs = OrderedDict()

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\: str
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\: bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\: str
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                        self._leafs = OrderedDict([
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                            ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                            ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                            ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                            ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                            ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                            ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                            ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                            ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                            ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                            ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                            ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                        ])
                                        self.local_address = None
                                        self.target_address = None
                                        self.state = None
                                        self.adjacency_ldp_identifier = None
                                        self.interval = None
                                        self.next_hello = None
                                        self.hold_time = None
                                        self.local_hold_time = None
                                        self.neighbor_hold_time = None
                                        self.disc_expiry = None
                                        self.quick_start_disabled = None
                                        self.established_time = None
                                        self.established_age = None
                                        self.session_up = None
                                        self.session_bringup_failure_reason = None

                                        self.dhcb_local_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                        self.dhcb_target_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "dhcb-target-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                            ])
                                            self.last_session_down_reason = None
                                            self.last_session_down_time = None
                                            self.last_session_up_time = None
                                            self._segment_path = lambda: "last-session-down-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                    self._leafs = OrderedDict()

                                    self.link_hello_briefs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                    self.targeted_hello_briefs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._segment_path = lambda: "brief"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief, [], name, value)


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ])
                                            self.interface_name = None
                                            self.address_family = None
                                            self.address_family_set = None
                                            self.interface = None
                                            self.interface_name_xr = None

                                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.address_family = None

                                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.dhcb_target_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, [u'name', u'id'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.hold_time = None
                                                self.session_up = None
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat))])
                                    self._leafs = OrderedDict()

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                            ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                            ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                            ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.adjacency_group_up_time = None
                                        self.tcp_open_count = None
                                        self.tcp_arb_chg_count = None
                                        self.tcp_role = None
                                        self._segment_path = lambda: "stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding))])
                                self._leafs = OrderedDict()

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  (key)
                                
                                	The IP Prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)), ("prefix-xr", ("prefix_xr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.table_id = None
                                    self.prefix_length = None

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.prefix_xr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"

                                    self.route = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, [u'name', u'id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "prefix-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "route"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\: bool
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                            ])
                                            self.version = None
                                            self.priority = None
                                            self.source = None
                                            self.type = None
                                            self.flags = None
                                            self.metric = None
                                            self.is_local_vrf_leaked = None
                                            self.routing_update_count = None
                                            self.routing_update_timestamp = None
                                            self.routing_update_age = None
                                            self.sr_local_label = None
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                            ])
                                            self.local_label = None
                                            self.forwarding_update_count = None
                                            self.forwarding_update_timestamp = None
                                            self.forwarding_update_age = None
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                        self._leafs = OrderedDict()

                                        self.routing = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"

                                        self.mpls = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._segment_path = lambda: "paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\: bool
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self.nh_is_overriden = None
                                            self.nexthop_id = None
                                            self.next_hop_table_id = None
                                            self.flags = None
                                            self.load_metric = None
                                            self.path_id = None
                                            self.bkup_path_id = None
                                            self.path_flags = None

                                            self.next_hop = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.remote_lfa = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "routing"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\: bool
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                    ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None
                                                self.needs_tldp = None
                                                self.has_q_node = None

                                                self.remote_p_node_id = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                self.remote_q_node_id = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-p-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "remote-q-node-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                            self._leafs = OrderedDict()

                                            self.mpls_outgoing_info = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                            self.remote_lfa = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._segment_path = lambda: "mpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                self._leafs = OrderedDict([
                                                    ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                    ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                    ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                    ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                    ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                    ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ])
                                                self.out_label = None
                                                self.out_label_rsn = None
                                                self.out_label_type = None
                                                self.out_label_owner = None
                                                self.is_from_graceful_restartable_neighbor = None
                                                self.is_stale = None

                                                self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._segment_path = lambda: "mpls-outgoing-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                    ])
                                                    self.lsr_id = None
                                                    self.label_space_id = None
                                                    self.ldp_id = None
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                self._leafs = OrderedDict([
                                                    ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                ])
                                                self.has_remote_lfa_bkup = None

                                                self.mpls_outgoing_info = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._segment_path = lambda: "remote-lfa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                    self._leafs = OrderedDict()

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                        self._leafs = OrderedDict([
                                                            ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                            ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                            ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                            ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                            ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                            ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                        ])
                                                        self.out_label = None
                                                        self.out_label_rsn = None
                                                        self.out_label_type = None
                                                        self.out_label_owner = None
                                                        self.is_from_graceful_restartable_neighbor = None
                                                        self.is_stale = None

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._segment_path = lambda: "stack"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                            ])
                                                            self.lsr_id = None
                                                            self.label_space_id = None
                                                            self.ldp_id = None
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                self._leafs = OrderedDict()

                                self.allocation_acl = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\: bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                    ])
                                    self.has_acl = None
                                    self.prefix_acl = None
                                    self.is_host_route_only = None
                                    self._segment_path = lambda: "allocation-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\: str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                        ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                    ])
                                    self.prefix_acl = None
                                    self.peer_acl = None
                                    self._segment_path = lambda: "advt-acl"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\: bool
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)), ("rws", ("rws", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws))])
                                self._leafs = OrderedDict([
                                    ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                    ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                    ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                    ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                ])
                                self.is_lsd_bound = None
                                self.fsht = None
                                self.intfs = None
                                self.lbls = None

                                self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.rws = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._segment_path = lambda: "forwarding-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, [u'name', u'id'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                    self._leafs = OrderedDict()

                                    self.pfxs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"

                                    self.nhs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._segment_path = lambda: "rws"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                        self._leafs = OrderedDict([
                                            ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                            ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                            ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                        ])
                                        self.total_pfxs = None
                                        self.ecmp_pfxs = None
                                        self.protected_pfxs = None

                                        self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                        self.labeled_pfxs_primary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                        self.labeled_pfxs_backup = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._segment_path = lambda: "pfxs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-aggr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                            ])
                                            self.labeled_pfxs = None
                                            self.labeled_pfxs_partial = None
                                            self.unlabeled_pfxs = None
                                            self._segment_path = lambda: "labeled-pfxs-backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                            ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                            ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                            ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                            ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                            ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                        ])
                                        self.total_paths = None
                                        self.protected_paths = None
                                        self.backup_paths = None
                                        self.remote_backup_paths = None
                                        self.labeled_paths = None
                                        self.labeled_backup_paths = None
                                        self._segment_path = lambda: "nhs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief))])
                        self._leafs = OrderedDict()

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\: bool
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.is_graceful_restartable = None
                            self.nsr_state = None
                            self.up_time_seconds = None

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, [u'name', u'id'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                    ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                    ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                ])
                                self.address_family = None
                                self.num_of_nbr_discovery = None
                                self.num_of_nbr_addresses = None
                                self.num_of_nbr_lbl = None
                                self._segment_path = lambda: "nbr-br-af-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                            ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                        ])
                        self.initial_seconds = None
                        self.maximum_seconds = None
                        self._segment_path = lambda: "backoff-parameters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff))])
                        self._leafs = OrderedDict()

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.backoff_seconds = None
                            self.waiting_seconds = None
                            self._segment_path = lambda: "backoff"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.nsr_pending = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"

                        self.ha_summary = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "nsr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr, [], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "nsr-pending"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending, [], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\: bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\: bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\: bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\: bool
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\: bool
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\: bool
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter))])
                        self._leafs = OrderedDict([
                            ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                            ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                            ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                            ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                            ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                            ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                            ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                            ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                            ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                            ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                            ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                            ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                            ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                            ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                            ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                            ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                            ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                            ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                            ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                            ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                            ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                        ])
                        self.role_is_active = None
                        self.global_md5_password_enabled = None
                        self.protocol_version = None
                        self.router_id = None
                        self.keepalive_interval = None
                        self.hello_hold_time = None
                        self.hello_interval = None
                        self.targeted_hello_hold_time = None
                        self.targeted_hello_interval = None
                        self.session_hold_time = None
                        self.housekeeping_timer_interval = None
                        self.le_no_route_timeout = None
                        self.ldp_recovery_timeout = None
                        self.af_binding_withdraw_delay = None
                        self.max_intf_attached = None
                        self.max_intf_te = None
                        self.max_peer = None
                        self.ldp_out_of_mem_state = None
                        self.nsr_enabled = None
                        self.nsr_synced = None
                        self.igp_sync_delay_time_for_interface = None
                        self.igp_sync_delay_time_on_restart = None
                        self.global_discovery_quick_start_disabled = None
                        self.discovery_quick_start_disabled_on_interfaces = None

                        self.graceful_restart_information = MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\: bool
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                            ])
                            self.is_graceful_restart_configured = None
                            self.graceful_restart_reconnect_timeout = None
                            self.graceful_restart_forwarding_state_hold_time = None
                            self._segment_path = lambda: "graceful-restart-information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\: str
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\: str
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\: bool
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                            self._leafs = OrderedDict([
                                ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                            ])
                            self.address_family = None
                            self.null_label = None
                            self.label_imp_null_override_acl = None
                            self.is_accepting_targeted_hellos = None
                            self.targeted_hello_acl = None

                            self.discovery_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._segment_path = lambda: "address-family-parameter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ])
                                self.afi = None
                                self.dummy = None
                                self.ipv4 = None
                                self.ipv6 = None
                                self._segment_path = lambda: "discovery-transport-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary>`
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics))])
                        self._leafs = OrderedDict()

                        self.ha_summary = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"

                        self.ha_statistics = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._segment_path = lambda: "issu"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu, [], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf)), ("sessions", ("sessions", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.sessions = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._segment_path = lambda: "ha-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf, [u'name', u'id'], name, value)


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                    ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                    ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                    ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                    ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                    ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                    ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                    ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                    ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                    ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                ])
                                self.total = None
                                self.nsr_eligible = None
                                self.nsr_state_none = None
                                self.nsr_state_wait = None
                                self.nsr_state_ready = None
                                self.nsr_state_prepare = None
                                self.nsr_state_app_wait = None
                                self.nsr_state_operational = None
                                self.nsr_state_tcp_phase1 = None
                                self.nsr_state_tcp_phase2 = None
                                self._segment_path = lambda: "sessions"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors))])
                            self._leafs = OrderedDict()

                            self.ha_global = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._segment_path = lambda: "ha-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics, [], name, value)


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                self._leafs = OrderedDict()

                                self.init_sync = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._segment_path = lambda: "ha-global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal, [], name, value)


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\: bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\: bool
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                        ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                        ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                        ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                        ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                        ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                        ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                        ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                        ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                        ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                        ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                        ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                        ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                        ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                        ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                        ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                        ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                        ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                        ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                        ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                        ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                        ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                    ])
                                    self.nsr_cfged = None
                                    self.nsr_synced = None
                                    self.init_sync_start = None
                                    self.init_sync_end = None
                                    self.num_peers = None
                                    self.num_cap_sent = None
                                    self.num_cap_rcvd = None
                                    self.num_pfx = None
                                    self.num_lbl = None
                                    self.num_lcl_addr_wd = None
                                    self.num_lbl_adv = None
                                    self.ipc_msg_tx_cnt = None
                                    self.ipc_msg_tx_bytes = None
                                    self.ipc_msg_rx_cnt = None
                                    self.ipc_msg_rx_bytes = None
                                    self.ipc_max_tx_batch_bytes = None
                                    self.ipc_max_rx_batch_bytes = None
                                    self.ipc_tx_fail_cnt = None
                                    self.total_ipc_tx_fail_cnt = None
                                    self.ipc_restart_cnt = None
                                    self.ipc_default_mtu = None
                                    self.ipc_exceeded_mtu_msg_cnt = None
                                    self._segment_path = lambda: "init-sync"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                self._leafs = OrderedDict()

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                        ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                        ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                        ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.lsr_id_xr = None
                                    self.lbl_spc_id = None
                                    self.nsr_sync_state = None
                                    self.num_msg = None

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                            ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                            ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                        ])
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_addr = None
                                        self.num_duplicate_addr = None
                                        self.num_rx_bytes = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_lbl = None
                                        self.num_app_bytes = None
                                        self._segment_path = lambda: "init-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                            ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                            ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                            ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                        ])
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.rem_lbl_wd = None
                                        self.rem_lbl_rq = None
                                        self.num_stdby_adj_join = None
                                        self.num_stdby_adj_leave = None
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability))])
                        self._leafs = OrderedDict()

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.sent = YList(self)
                            self.received = YList(self)
                            self._segment_path = lambda: "neighbor-capability"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "sent"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                    ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                ])
                                self.type = None
                                self.description = None
                                self.capability_data_length = None
                                self.capability_data = None
                                self._segment_path = lambda: "received"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None

                            self.protocol_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"

                            self.tcp_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"

                            self.detailed_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\: str
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                self._leafs = OrderedDict([
                                    ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                    ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                    ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                    ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                    ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                    ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                ])
                                self.ta_holdtime = None
                                self.ta_state = None
                                self.ta_pies_sent = None
                                self.ta_pies_rcvd = None
                                self.ta_up_time_seconds = None
                                self.downstream_on_demand = None

                                self.ta_graceful_restart_adjacency = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._segment_path = lambda: "protocol-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\: bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                        ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                        ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                    ])
                                    self.is_graceful_restartable = None
                                    self.reconnect_timeout = None
                                    self.recovery_time = None
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                self._leafs = OrderedDict([
                                    ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                    ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                    ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                ])
                                self.foreign_port = None
                                self.local_port = None
                                self.is_md5_on = None

                                self.foreign_host = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"

                                self.local_host = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._segment_path = lambda: "tcp-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "foreign-host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "local-host"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\: bool
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\: bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\: bool
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\: str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\: bool
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\: bool
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\: bool
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                self._leafs = OrderedDict([
                                    ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                    ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                    ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                    ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                    ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                    ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                    ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                    ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                    ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                    ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                    ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                    ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                    ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                    ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                    ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                    ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                    ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                    ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                    ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                    ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                    ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                    ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                    ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                ])
                                self.peer_holdtime = None
                                self.keep_alive_interval = None
                                self.peer_state = None
                                self.has_ipv4_inbound = None
                                self.inbound_ipv4acl = None
                                self.has_ipv6_inbound = None
                                self.inbound_ipv6acl = None
                                self.has_ipv4_outbound = None
                                self.outbound_ipv4acl = None
                                self.has_ipv6_outbound = None
                                self.outbound_ipv6acl = None
                                self.has_sp = None
                                self.sp_state = None
                                self.sp_has_acl = None
                                self.spacl = None
                                self.sp_has_duration = None
                                self.sp_duration = None
                                self.spht_running = None
                                self.spht_remaining = None
                                self.nsr_sync_state = None
                                self.nsr_last_sync_error = None
                                self.nsr_last_sync_nack_reason = None
                                self.bgp_advertisement_state = None
                                self.advertise_bgp_prefixes = None

                                self.capabilities = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                    self._leafs = OrderedDict()

                                    self.sent = YList(self)
                                    self.received = YList(self)
                                    self._segment_path = lambda: "capabilities"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "sent"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\: str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                            ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                        ])
                                        self.type = None
                                        self.description = None
                                        self.capability_data_length = None
                                        self.capability_data = None
                                        self._segment_path = lambda: "received"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "client"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv4-duplicate-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ipv6-duplicate-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                self._leafs = OrderedDict()

                                self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                self._leafs = OrderedDict()

                                self.adjacency_group = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                    self._leafs = OrderedDict([
                                        ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                    ])
                                    self.hello_type = None

                                    self.link_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"

                                    self.target_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._segment_path = lambda: "adjacency-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.interface = None
                                        self.interface_name = None
                                        self._segment_path = lambda: "link-hello-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                        self._leafs = OrderedDict([
                                            ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                        ])
                                        self.state = None

                                        self.local_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"

                                        self.target_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._segment_path = lambda: "target-hello-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "target-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                        ])
                        self.lsr_id = None
                        self.label_space_id = None
                        self.ldp_id = None
                        self._segment_path = lambda: "ldp-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic))])
                        self._leafs = OrderedDict()

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn))])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.iccp_enabled = None

                            self.message_out = MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"

                            self.message_in = MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._segment_path = lambda: "statistic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-out"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                    ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                    ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                    ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                    ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                    ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                    ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                    ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                    ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                    ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                    ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                    ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                    ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                    ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                ])
                                self.total_count = None
                                self.init_count = None
                                self.address_count = None
                                self.address_withdraw_count = None
                                self.label_map_count = None
                                self.label_withdraw_count = None
                                self.label_release_count = None
                                self.label_request_count = None
                                self.label_abort_request_count = None
                                self.notification_count = None
                                self.keep_alive_count = None
                                self.iccp_rg_conn_count = None
                                self.iccp_rg_disconn_count = None
                                self.iccp_rg_notif_count = None
                                self.iccp_rg_app_data_count = None
                                self._segment_path = lambda: "message-in"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf>`
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws>`
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\: bool
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf)), ("rws", ("rws", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws))])
                    self._leafs = OrderedDict([
                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                    ])
                    self.is_lsd_bound = None
                    self.fsht = None
                    self.intfs = None
                    self.lbls = None

                    self.vrf = MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.rws = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._segment_path = lambda: "forwarding-summary-all"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs))])
                        self._leafs = OrderedDict()

                        self.pfxs = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"

                        self.nhs = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._segment_path = lambda: "rws"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws, [], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup))])
                            self._leafs = OrderedDict([
                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                            ])
                            self.total_pfxs = None
                            self.ecmp_pfxs = None
                            self.protected_pfxs = None

                            self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                            self.labeled_pfxs_primary = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                            self.labeled_pfxs_backup = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._segment_path = lambda: "pfxs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-primary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                ])
                                self.labeled_pfxs = None
                                self.labeled_pfxs_partial = None
                                self.unlabeled_pfxs = None
                                self._segment_path = lambda: "labeled-pfxs-backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                            ])
                            self.total_paths = None
                            self.protected_paths = None
                            self.backup_paths = None
                            self.remote_backup_paths = None
                            self.labeled_paths = None
                            self.labeled_backup_paths = None
                            self._segment_path = lambda: "nhs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf>`
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf)), ("bind-af", ("bind_af", MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf))])
                    self._leafs = OrderedDict([
                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                    ])
                    self.address_family = None
                    self.binding_no_route = None
                    self.binding_local_no_route = None
                    self.binding_local_null = None
                    self.binding_local_implicit_null = None
                    self.binding_local_explicit_null = None
                    self.binding_local_non_null = None
                    self.binding_local_oor = None
                    self.lowest_allocated_label = None
                    self.highest_allocated_label = None

                    self.vrf = MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf, [u'name', u'id'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                        ])
                        self.address_family = None
                        self.last_lib_update = None
                        self.lib_minimum_revision_sent_all = None
                        self.binding_total = None
                        self.binding_local = None
                        self.binding_remote = None
                        self._segment_path = lambda: "bind-af"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of  		 :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ato-mdb-table-entry", ("ato_mdb_table_entry", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry))])
                    self._leafs = OrderedDict()

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:  :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fec-info", ("fec_info", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo))])
                        self._leafs = OrderedDict([
                            ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str','str'])),
                            ('fe_ctype', (YLeaf(YType.uint32, 'fe-ctype'), ['int'])),
                            ('pw_id', (YLeaf(YType.uint32, 'pw-id'), ['int'])),
                            ('agi_type', (YLeaf(YType.uint32, 'agi-type'), ['int'])),
                            ('agi', (YLeaf(YType.uint32, 'agi'), ['int'])),
                            ('saii_type', (YLeaf(YType.uint32, 'saii-type'), ['int'])),
                            ('saii_local_id', (YLeaf(YType.str, 'saii-local-id'), ['str','str'])),
                            ('saii_global_id', (YLeaf(YType.uint32, 'saii-global-id'), ['int'])),
                            ('saii_prefix', (YLeaf(YType.str, 'saii-prefix'), ['str'])),
                            ('saii_ac_id', (YLeaf(YType.uint32, 'saii-ac-id'), ['int'])),
                            ('taii_type', (YLeaf(YType.uint32, 'taii-type'), ['int'])),
                            ('taii_local_id', (YLeaf(YType.str, 'taii-local-id'), ['str','str'])),
                            ('taii_global_id', (YLeaf(YType.uint32, 'taii-global-id'), ['int'])),
                            ('taii_prefix', (YLeaf(YType.str, 'taii-prefix'), ['str'])),
                            ('taii_ac_id', (YLeaf(YType.uint32, 'taii-ac-id'), ['int'])),
                            ('peer_id_xr', (YLeaf(YType.str, 'peer-id-xr'), ['str'])),
                            ('mapping_tlv_count', (YLeaf(YType.uint32, 'mapping-tlv-count'), ['int'])),
                            ('notification_tlv_count', (YLeaf(YType.uint32, 'notification-tlv-count'), ['int'])),
                        ])
                        self.peer_id = None
                        self.fe_ctype = None
                        self.pw_id = None
                        self.agi_type = None
                        self.agi = None
                        self.saii_type = None
                        self.saii_local_id = None
                        self.saii_global_id = None
                        self.saii_prefix = None
                        self.saii_ac_id = None
                        self.taii_type = None
                        self.taii_local_id = None
                        self.taii_global_id = None
                        self.taii_prefix = None
                        self.taii_ac_id = None
                        self.peer_id_xr = None
                        self.mapping_tlv_count = None
                        self.notification_tlv_count = None

                        self.fec_info = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._segment_path = lambda: "ato-mdb-table-entry"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry, ['peer_id', 'fe_ctype', 'pw_id', 'agi_type', 'agi', 'saii_type', 'saii_local_id', 'saii_global_id', 'saii_prefix', 'saii_ac_id', 'taii_type', 'taii_local_id', 'taii_global_id', 'taii_prefix', 'taii_ac_id', 'peer_id_xr', 'mapping_tlv_count', 'notification_tlv_count'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:  :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:  :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:  :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:  :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fec128", ("fec128", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128)), ("fec129", ("fec129", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129)), ("fec130", ("fec130", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130))])
                            self._leafs = OrderedDict([
                                ('fe_ctype', (YLeaf(YType.enumeration, 'fe-ctype'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwFec', '')])),
                            ])
                            self.fe_ctype = None

                            self.fec128 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"

                            self.fec129 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"

                            self.fec130 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._segment_path = lambda: "fec-info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pseudowire_id', (YLeaf(YType.uint32, 'pseudowire-id'), ['int'])),
                                ])
                                self.pseudowire_id = None
                                self._segment_path = lambda: "fec128"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:  :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi)), ("saii", ("saii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii)), ("taii", ("taii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"

                                self.taii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._segment_path = lambda: "fec129"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1)), ("aii2", ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "taii"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:  :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:  :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("agi", ("agi", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi)), ("saii", ("saii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii))])
                                self._leafs = OrderedDict()

                                self.agi = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"

                                self.saii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._segment_path = lambda: "fec130"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, [], name, value)


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:  :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:  :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("agi1", ("agi1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1))])
                                    self._leafs = OrderedDict([
                                        ('agi_type', (YLeaf(YType.enumeration, 'agi-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAgi', '')])),
                                    ])
                                    self.agi_type = None

                                    self.agi1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._segment_path = lambda: "agi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.uint64, 'rd'), ['int'])),
                                        ])
                                        self.rd = None
                                        self._segment_path = lambda: "agi1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:  :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:  :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:  :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("aii1", ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1)), ("aii2", ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2))])
                                    self._leafs = OrderedDict([
                                        ('aii_type', (YLeaf(YType.enumeration, 'aii-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'L2vpnLdpPwAii', '')])),
                                    ])
                                    self.aii_type = None

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._segment_path = lambda: "saii"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                        ])
                                        self.local_id = None
                                        self._segment_path = lambda: "aii1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gobal_id', (YLeaf(YType.uint32, 'gobal-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.uint32, 'prefix'), ['int'])),
                                            ('ac_id', (YLeaf(YType.uint32, 'ac-id'), ['int'])),
                                        ])
                                        self.gobal_id = None
                                        self.prefix = None
                                        self.ac_id = None
                                        self._segment_path = lambda: "aii2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['gobal_id', 'prefix', 'ac_id'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll.Vrf>`
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll.Sessions>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.NsrSummaryAll.Vrf)), ("sessions", ("sessions", MplsLdp.Nodes.Node.NsrSummaryAll.Sessions))])
                    self._leafs = OrderedDict()

                    self.vrf = MplsLdp.Nodes.Node.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"

                    self.sessions = MplsLdp.Nodes.Node.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._segment_path = lambda: "nsr-summary-all"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.NsrSummaryAll, [], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.NsrSummaryAll.Vrf, [u'name', u'id'], name, value)


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                            ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                            ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                            ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                            ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                            ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                            ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                            ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                            ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                            ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                        ])
                        self.total = None
                        self.nsr_eligible = None
                        self.nsr_state_none = None
                        self.nsr_state_wait = None
                        self.nsr_state_ready = None
                        self.nsr_state_prepare = None
                        self.nsr_state_app_wait = None
                        self.nsr_state_operational = None
                        self.nsr_state_tcp_phase1 = None
                        self.nsr_state_tcp_phase2 = None
                        self._segment_path = lambda: "sessions"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.NsrSummaryAll.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Summary.Common>`
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\: bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\: bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\: bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\: bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\: bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\: bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\: bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\: bool
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\: bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\: bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\: bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\: bool
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("common", ("common", MplsLdp.Nodes.Node.Summary.Common))])
                    self._leafs = OrderedDict([
                        ('number_of_vrf', (YLeaf(YType.uint32, 'number-of-vrf'), ['int'])),
                        ('number_of_vrf_oper', (YLeaf(YType.uint32, 'number-of-vrf-oper'), ['int'])),
                        ('number_of_interfaces', (YLeaf(YType.uint32, 'number-of-interfaces'), ['int'])),
                        ('number_of_fwd_ref_interfaces', (YLeaf(YType.uint32, 'number-of-fwd-ref-interfaces'), ['int'])),
                        ('number_of_autocfg_interfaces', (YLeaf(YType.uint32, 'number-of-autocfg-interfaces'), ['int'])),
                        ('is_bound_with_sysdb', (YLeaf(YType.boolean, 'is-bound-with-sysdb'), ['bool'])),
                        ('is_registered_with_sysdb', (YLeaf(YType.boolean, 'is-registered-with-sysdb'), ['bool'])),
                        ('is_bound_with_rsi', (YLeaf(YType.boolean, 'is-bound-with-rsi'), ['bool'])),
                        ('is_bound_with_interface_manager', (YLeaf(YType.boolean, 'is-bound-with-interface-manager'), ['bool'])),
                        ('is_registered_with_interface_manager', (YLeaf(YType.boolean, 'is-registered-with-interface-manager'), ['bool'])),
                        ('is_bound_with_ip_arm', (YLeaf(YType.boolean, 'is-bound-with-ip-arm'), ['bool'])),
                        ('is_bound_with_lsd', (YLeaf(YType.boolean, 'is-bound-with-lsd'), ['bool'])),
                        ('is_registered_with_lsd', (YLeaf(YType.boolean, 'is-registered-with-lsd'), ['bool'])),
                        ('is_bound_with_ipv4_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv4-rib'), ['bool'])),
                        ('is_registered_with_ipv4_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv4-rib'), ['bool'])),
                        ('number_of_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-ipv4rib-tables'), ['int'])),
                        ('number_of_registered_ipv4rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv4rib-tables'), ['int'])),
                        ('is_bound_with_ipv6_rib', (YLeaf(YType.boolean, 'is-bound-with-ipv6-rib'), ['bool'])),
                        ('is_registered_with_ipv6_rib', (YLeaf(YType.boolean, 'is-registered-with-ipv6-rib'), ['bool'])),
                        ('number_of_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-ipv6rib-tables'), ['int'])),
                        ('number_of_registered_ipv6rib_tables', (YLeaf(YType.uint32, 'number-of-registered-ipv6rib-tables'), ['int'])),
                        ('is_bound_with_atom', (YLeaf(YType.boolean, 'is-bound-with-atom'), ['bool'])),
                        ('is_bound_with_nsr_mate', (YLeaf(YType.boolean, 'is-bound-with-nsr-mate'), ['bool'])),
                        ('is_nsr_configured', (YLeaf(YType.boolean, 'is-nsr-configured'), ['bool'])),
                        ('is_mldp_registered', (YLeaf(YType.boolean, 'is-mldp-registered'), ['bool'])),
                    ])
                    self.number_of_vrf = None
                    self.number_of_vrf_oper = None
                    self.number_of_interfaces = None
                    self.number_of_fwd_ref_interfaces = None
                    self.number_of_autocfg_interfaces = None
                    self.is_bound_with_sysdb = None
                    self.is_registered_with_sysdb = None
                    self.is_bound_with_rsi = None
                    self.is_bound_with_interface_manager = None
                    self.is_registered_with_interface_manager = None
                    self.is_bound_with_ip_arm = None
                    self.is_bound_with_lsd = None
                    self.is_registered_with_lsd = None
                    self.is_bound_with_ipv4_rib = None
                    self.is_registered_with_ipv4_rib = None
                    self.number_of_ipv4rib_tables = None
                    self.number_of_registered_ipv4rib_tables = None
                    self.is_bound_with_ipv6_rib = None
                    self.is_registered_with_ipv6_rib = None
                    self.number_of_ipv6rib_tables = None
                    self.number_of_registered_ipv6rib_tables = None
                    self.is_bound_with_atom = None
                    self.is_bound_with_nsr_mate = None
                    self.is_nsr_configured = None
                    self.is_mldp_registered = None

                    self.common = MplsLdp.Nodes.Node.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._segment_path = lambda: "summary"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.Summary, [u'number_of_vrf', u'number_of_vrf_oper', u'number_of_interfaces', u'number_of_fwd_ref_interfaces', u'number_of_autocfg_interfaces', u'is_bound_with_sysdb', u'is_registered_with_sysdb', u'is_bound_with_rsi', u'is_bound_with_interface_manager', u'is_registered_with_interface_manager', u'is_bound_with_ip_arm', u'is_bound_with_lsd', u'is_registered_with_lsd', u'is_bound_with_ipv4_rib', u'is_registered_with_ipv4_rib', u'number_of_ipv4rib_tables', u'number_of_registered_ipv4rib_tables', u'is_bound_with_ipv6_rib', u'is_registered_with_ipv6_rib', u'number_of_ipv6rib_tables', u'number_of_registered_ipv6rib_tables', u'is_bound_with_atom', u'is_bound_with_nsr_mate', u'is_nsr_configured', u'is_mldp_registered'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                            ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                            ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                            ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                            ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                            ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                            ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                            ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                            ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                            ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                            ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                            ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                            ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                            ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                            ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                            ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                            ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                            ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                            ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                            ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                            ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                            ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                        ])
                        self.address_families = None
                        self.number_of_ipv4af = None
                        self.number_of_ipv6af = None
                        self.number_of_neighbors = None
                        self.number_of_nsr_synced_neighbors = None
                        self.number_of_graceful_restart_neighbors = None
                        self.number_of_downstream_on_demand_neighbors = None
                        self.number_of_ipv4_hello_adj = None
                        self.number_of_ipv6_hello_adj = None
                        self.number_of_ipv4_routes = None
                        self.number_of_ipv6_routes = None
                        self.number_of_ipv4_local_addresses = None
                        self.number_of_ipv6_local_addresses = None
                        self.number_of_ldp_interfaces = None
                        self.number_of_ipv4ldp_interfaces = None
                        self.number_of_ipv6ldp_interfaces = None
                        self.number_of_bindings_ipv4 = None
                        self.number_of_bindings_ipv6 = None
                        self.number_of_local_bindings_ipv4 = None
                        self.number_of_local_bindings_ipv6 = None
                        self.number_of_remote_bindings_ipv4 = None
                        self.number_of_remote_bindings_ipv6 = None
                        self._segment_path = lambda: "common"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  (key)
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:  :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:  :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:  :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:  :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:  :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vrf_name']
                        self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart)), ("capabilities", ("capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities)), ("summary", ("summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary)), ("afs", ("afs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs)), ("neighbor-briefs", ("neighbor_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs)), ("backoff-parameters", ("backoff_parameters", MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters)), ("backoffs", ("backoffs", MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs)), ("nsr", ("nsr", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr)), ("parameters", ("parameters", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters)), ("issu", ("issu", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu)), ("neighbor-capabilities", ("neighbor_capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities)), ("neighbors", ("neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors)), ("ldp-id", ("ldp_id", MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId)), ("statistics", ("statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics))])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.vrf_name = None

                        self.graceful_restart = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"

                        self.capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"

                        self.summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"

                        self.afs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"

                        self.neighbor_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"

                        self.backoff_parameters = MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"

                        self.backoffs = MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"

                        self.nsr = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"

                        self.parameters = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"

                        self.issu = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"

                        self.neighbor_capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"

                        self.neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.ldp_id = MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"

                        self.statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf, ['vrf_name'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf_>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\: bool
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of  		 :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf_)), ("graceful-restartable-neighbor", ("graceful_restartable_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor))])
                            self._leafs = OrderedDict([
                                ('is_forwarding_state_hold_timer_running', (YLeaf(YType.boolean, 'is-forwarding-state-hold-timer-running'), ['bool'])),
                                ('forwarding_state_hold_timer_remaining_seconds', (YLeaf(YType.uint32, 'forwarding-state-hold-timer-remaining-seconds'), ['int'])),
                            ])
                            self.is_forwarding_state_hold_timer_running = None
                            self.forwarding_state_hold_timer_remaining_seconds = None

                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart, [u'is_forwarding_state_hold_timer_running', u'forwarding_state_hold_timer_remaining_seconds'], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf_, [u'name', u'id'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:  :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\: bool
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\: bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\: bool
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of  		 :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gr-peer", ("gr_peer", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)), ("down-nbr-interface", ("down_nbr_interface", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)), ("down-nbr-address", ("down_nbr_address", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress))])
                                self._leafs = OrderedDict([
                                    ('connect_count', (YLeaf(YType.uint32, 'connect-count'), ['int'])),
                                    ('is_neighbor_up', (YLeaf(YType.boolean, 'is-neighbor-up'), ['bool'])),
                                    ('is_liveness_timer_running', (YLeaf(YType.boolean, 'is-liveness-timer-running'), ['bool'])),
                                    ('liveness_timer_remaining_seconds', (YLeaf(YType.uint32, 'liveness-timer-remaining-seconds'), ['int'])),
                                    ('is_recovery_timer_running', (YLeaf(YType.boolean, 'is-recovery-timer-running'), ['bool'])),
                                    ('recovery_timer_remaining_seconds', (YLeaf(YType.uint32, 'recovery-timer-remaining-seconds'), ['int'])),
                                    ('down_nbr_flap_count', (YLeaf(YType.uint8, 'down-nbr-flap-count'), ['int'])),
                                    ('down_nbr_flags', (YLeaf(YType.uint32, 'down-nbr-flags'), ['int'])),
                                    ('down_nbr_down_reason', (YLeaf(YType.uint32, 'down-nbr-down-reason'), ['int'])),
                                ])
                                self.connect_count = None
                                self.is_neighbor_up = None
                                self.is_liveness_timer_running = None
                                self.liveness_timer_remaining_seconds = None
                                self.is_recovery_timer_running = None
                                self.recovery_timer_remaining_seconds = None
                                self.down_nbr_flap_count = None
                                self.down_nbr_flags = None
                                self.down_nbr_down_reason = None

                                self.gr_peer = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"

                                self.down_nbr_interface = YList(self)
                                self.down_nbr_address = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, [u'connect_count', u'is_neighbor_up', u'is_liveness_timer_running', u'liveness_timer_remaining_seconds', u'is_recovery_timer_running', u'recovery_timer_remaining_seconds', u'down_nbr_flap_count', u'down_nbr_flags', u'down_nbr_down_reason'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                        ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                        ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                    ])
                                    self.lsr_id = None
                                    self.label_space_id = None
                                    self.ldp_id = None
                                    self._segment_path = lambda: "gr-peer"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('interface_handle', (YLeaf(YType.str, 'interface-handle'), ['str'])),
                                    ])
                                    self.address_family = None
                                    self.interface_handle = None
                                    self._segment_path = lambda: "down-nbr-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, [u'address_family', u'interface_handle'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "down-nbr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of  		 :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability))])
                            self._leafs = OrderedDict()

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  (key)
                            
                            	The capability type (IANA assigned)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:  :py:class:`Capability_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability_>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['capability_type']
                                self._child_classes = OrderedDict([("capability", ("capability", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability_))])
                                self._leafs = OrderedDict([
                                    ('capability_type', (YLeaf(YType.uint32, 'capability-type'), ['int'])),
                                    ('capability_owner', (YLeaf(YType.str, 'capability-owner'), ['str'])),
                                ])
                                self.capability_type = None
                                self.capability_owner = None

                                self.capability = MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability_()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._segment_path = lambda: "capability" + "[capability-type='" + str(self.capability_type) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability, ['capability_type', u'capability_owner'], name, value)


                            class Capability_(Entity):
                                """
                                Capability information
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability_, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "capability"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability_, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf_>`
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:  :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf_)), ("common", ("common", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common))])
                            self._leafs = OrderedDict()

                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf_()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.common = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._segment_path = lambda: "summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary, [], name, value)


                        class Vrf_(Entity):
                            """
                            VRF information
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf_, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                ])
                                self.name = None
                                self.id = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf_, [u'name', u'id'], name, value)


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address_families', (YLeaf(YType.enumeration, 'address-families'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('number_of_ipv4af', (YLeaf(YType.uint32, 'number-of-ipv4af'), ['int'])),
                                    ('number_of_ipv6af', (YLeaf(YType.uint32, 'number-of-ipv6af'), ['int'])),
                                    ('number_of_neighbors', (YLeaf(YType.uint32, 'number-of-neighbors'), ['int'])),
                                    ('number_of_nsr_synced_neighbors', (YLeaf(YType.uint32, 'number-of-nsr-synced-neighbors'), ['int'])),
                                    ('number_of_graceful_restart_neighbors', (YLeaf(YType.uint32, 'number-of-graceful-restart-neighbors'), ['int'])),
                                    ('number_of_downstream_on_demand_neighbors', (YLeaf(YType.uint32, 'number-of-downstream-on-demand-neighbors'), ['int'])),
                                    ('number_of_ipv4_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv4-hello-adj'), ['int'])),
                                    ('number_of_ipv6_hello_adj', (YLeaf(YType.uint32, 'number-of-ipv6-hello-adj'), ['int'])),
                                    ('number_of_ipv4_routes', (YLeaf(YType.uint32, 'number-of-ipv4-routes'), ['int'])),
                                    ('number_of_ipv6_routes', (YLeaf(YType.uint32, 'number-of-ipv6-routes'), ['int'])),
                                    ('number_of_ipv4_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv4-local-addresses'), ['int'])),
                                    ('number_of_ipv6_local_addresses', (YLeaf(YType.uint32, 'number-of-ipv6-local-addresses'), ['int'])),
                                    ('number_of_ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ldp-interfaces'), ['int'])),
                                    ('number_of_ipv4ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv4ldp-interfaces'), ['int'])),
                                    ('number_of_ipv6ldp_interfaces', (YLeaf(YType.uint32, 'number-of-ipv6ldp-interfaces'), ['int'])),
                                    ('number_of_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-bindings-ipv4'), ['int'])),
                                    ('number_of_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-bindings-ipv6'), ['int'])),
                                    ('number_of_local_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv4'), ['int'])),
                                    ('number_of_local_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-local-bindings-ipv6'), ['int'])),
                                    ('number_of_remote_bindings_ipv4', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv4'), ['int'])),
                                    ('number_of_remote_bindings_ipv6', (YLeaf(YType.uint32, 'number-of-remote-bindings-ipv6'), ['int'])),
                                ])
                                self.address_families = None
                                self.number_of_ipv4af = None
                                self.number_of_ipv6af = None
                                self.number_of_neighbors = None
                                self.number_of_nsr_synced_neighbors = None
                                self.number_of_graceful_restart_neighbors = None
                                self.number_of_downstream_on_demand_neighbors = None
                                self.number_of_ipv4_hello_adj = None
                                self.number_of_ipv6_hello_adj = None
                                self.number_of_ipv4_routes = None
                                self.number_of_ipv6_routes = None
                                self.number_of_ipv4_local_addresses = None
                                self.number_of_ipv6_local_addresses = None
                                self.number_of_ldp_interfaces = None
                                self.number_of_ipv4ldp_interfaces = None
                                self.number_of_ipv6ldp_interfaces = None
                                self.number_of_bindings_ipv4 = None
                                self.number_of_bindings_ipv6 = None
                                self.number_of_local_bindings_ipv4 = None
                                self.number_of_local_bindings_ipv6 = None
                                self.number_of_remote_bindings_ipv4 = None
                                self.number_of_remote_bindings_ipv6 = None
                                self._segment_path = lambda: "common"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common, [u'address_families', u'number_of_ipv4af', u'number_of_ipv6af', u'number_of_neighbors', u'number_of_nsr_synced_neighbors', u'number_of_graceful_restart_neighbors', u'number_of_downstream_on_demand_neighbors', u'number_of_ipv4_hello_adj', u'number_of_ipv6_hello_adj', u'number_of_ipv4_routes', u'number_of_ipv6_routes', u'number_of_ipv4_local_addresses', u'number_of_ipv6_local_addresses', u'number_of_ldp_interfaces', u'number_of_ipv4ldp_interfaces', u'number_of_ipv6ldp_interfaces', u'number_of_bindings_ipv4', u'number_of_bindings_ipv6', u'number_of_local_bindings_ipv4', u'number_of_local_bindings_ipv6', u'number_of_remote_bindings_ipv4', u'number_of_remote_bindings_ipv6'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("af", ("af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af))])
                            self._leafs = OrderedDict()

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  (key)
                            
                            	Address Family name
                            	**type**\:  :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:  :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:  :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:  :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:  :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:  :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['af_name']
                                self._child_classes = OrderedDict([("interface-summary", ("interface_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary)), ("bindings", ("bindings", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings)), ("igp", ("igp", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp)), ("bindings-summary", ("bindings_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary)), ("interfaces", ("interfaces", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces)), ("discovery", ("discovery", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery)), ("forwardings", ("forwardings", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings)), ("bindings-advertise-spec", ("bindings_advertise_spec", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec)), ("forwarding-summary", ("forwarding_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary))])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MplsLdpOperAfName', '')])),
                                ])
                                self.af_name = None

                                self.interface_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"

                                self.bindings = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"

                                self.igp = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"

                                self.bindings_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"

                                self.interfaces = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"

                                self.discovery = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"

                                self.forwardings = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"

                                self.bindings_advertise_spec = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"

                                self.forwarding_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('known_ip_interface_count', (YLeaf(YType.uint32, 'known-ip-interface-count'), ['int'])),
                                        ('known_ip_interface_ldp_enabled', (YLeaf(YType.uint32, 'known-ip-interface-ldp-enabled'), ['int'])),
                                        ('ldp_configured_attached_interface', (YLeaf(YType.uint32, 'ldp-configured-attached-interface'), ['int'])),
                                        ('ldp_configured_te_interface', (YLeaf(YType.uint32, 'ldp-configured-te-interface'), ['int'])),
                                        ('forward_references', (YLeaf(YType.uint32, 'forward-references'), ['int'])),
                                        ('auto_config_disabled', (YLeaf(YType.uint32, 'auto-config-disabled'), ['int'])),
                                        ('auto_config', (YLeaf(YType.uint32, 'auto-config'), ['int'])),
                                        ('auto_config_forward_reference_interfaces', (YLeaf(YType.uint32, 'auto-config-forward-reference-interfaces'), ['int'])),
                                    ])
                                    self.known_ip_interface_count = None
                                    self.known_ip_interface_ldp_enabled = None
                                    self.ldp_configured_attached_interface = None
                                    self.ldp_configured_te_interface = None
                                    self.forward_references = None
                                    self.auto_config_disabled = None
                                    self.auto_config = None
                                    self.auto_config_forward_reference_interfaces = None
                                    self._segment_path = lambda: "interface-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary, [u'known_ip_interface_count', u'known_ip_interface_ldp_enabled', u'ldp_configured_attached_interface', u'ldp_configured_te_interface', u'forward_references', u'auto_config_disabled', u'auto_config', u'auto_config_forward_reference_interfaces'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of  		 :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("binding", ("binding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding))])
                                    self._leafs = OrderedDict()

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:  :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\: str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\: str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\: bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of  		 :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of  		 :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of  		 :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr)), ("remote-binding", ("remote_binding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)), ("peers-advertised-to", ("peers_advertised_to", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo)), ("peers-acked", ("peers_acked", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                            ('le_local_binding_revision', (YLeaf(YType.uint32, 'le-local-binding-revision'), ['int'])),
                                            ('le_local_label_state', (YLeaf(YType.enumeration, 'le-local-label-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LocalLabelState', '')])),
                                            ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('advertise_prefix_acl', (YLeaf(YType.str, 'advertise-prefix-acl'), ['str'])),
                                            ('advertise_tsr_acl', (YLeaf(YType.str, 'advertise-tsr-acl'), ['str'])),
                                            ('config_enforced_local_label_value', (YLeaf(YType.boolean, 'config-enforced-local-label-value'), ['bool'])),
                                            ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.local_label = None
                                        self.le_local_binding_revision = None
                                        self.le_local_label_state = None
                                        self.is_no_route = None
                                        self.label_oor = None
                                        self.advertise_prefix_acl = None
                                        self.advertise_tsr_acl = None
                                        self.config_enforced_local_label_value = None
                                        self.is_elc = None

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.remote_binding = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.peers_acked = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', u'prefix_length', u'local_label', u'le_local_binding_revision', u'le_local_label_state', u'is_no_route', u'label_oor', u'advertise_prefix_acl', u'advertise_tsr_acl', u'config_enforced_local_label_value', u'is_elc'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:  :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\: bool
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("assigning-peer-ldp-ident", ("assigning_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent))])
                                            self._leafs = OrderedDict([
                                                ('remote_label', (YLeaf(YType.uint32, 'remote-label'), ['int'])),
                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                ('is_elc', (YLeaf(YType.boolean, 'is-elc'), ['bool'])),
                                            ])
                                            self.remote_label = None
                                            self.is_stale = None
                                            self.is_elc = None

                                            self.assigning_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._segment_path = lambda: "remote-binding"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, [u'remote_label', u'is_stale', u'is_elc'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                ])
                                                self.lsr_id = None
                                                self.label_space_id = None
                                                self.ldp_id = None
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.ldp_id = None
                                            self._segment_path = lambda: "peers-acked"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:  :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:  :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("syncs", ("syncs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs)), ("sync-delay-restart", ("sync_delay_restart", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart))])
                                    self._leafs = OrderedDict()

                                    self.syncs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"

                                    self.sync_delay_restart = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._segment_path = lambda: "igp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp, [], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of  		 :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sync", ("sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync))])
                                        self._leafs = OrderedDict()

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:  :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:  :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of  		 :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of  		 :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_)), ("peers", ("peers", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)), ("gr-only-peer", ("gr_only_peer", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('igp_sync_state', (YLeaf(YType.enumeration, 'igp-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncState', '')])),
                                                ('igp_sync_delay', (YLeaf(YType.uint32, 'igp-sync-delay'), ['int'])),
                                                ('is_delay_timer_running', (YLeaf(YType.boolean, 'is-delay-timer-running'), ['bool'])),
                                                ('delay_timer_remaining', (YLeaf(YType.uint32, 'delay-timer-remaining'), ['int'])),
                                                ('igp_sync_down_reason', (YLeaf(YType.enumeration, 'igp-sync-down-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpIgpSyncDownReason', '')])),
                                            ])
                                            self.interface_name = None
                                            self.interface_name_xr = None
                                            self.igp_sync_state = None
                                            self.igp_sync_delay = None
                                            self.is_delay_timer_running = None
                                            self.delay_timer_remaining = None
                                            self.igp_sync_down_reason = None

                                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.peers = YList(self)
                                            self.gr_only_peer = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', u'interface_name_xr', u'igp_sync_state', u'igp_sync_delay', u'is_delay_timer_running', u'delay_timer_remaining', u'igp_sync_down_reason'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf_, [u'name', u'id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_gr_enabled', (YLeaf(YType.boolean, 'is-gr-enabled'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_gr_enabled = None
                                                self._segment_path = lambda: "peers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, [u'peer_id', u'is_gr_enabled'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('peer_id', (YLeaf(YType.str, 'peer-id'), ['str'])),
                                                    ('is_chkpt_created', (YLeaf(YType.boolean, 'is-chkpt-created'), ['bool'])),
                                                ])
                                                self.peer_id = None
                                                self.is_chkpt_created = None
                                                self._segment_path = lambda: "gr-only-peer"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, [u'peer_id', u'is_chkpt_created'], name, value)


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\: bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                            ('delay_secs', (YLeaf(YType.uint32, 'delay-secs'), ['int'])),
                                            ('timer_running', (YLeaf(YType.boolean, 'timer-running'), ['bool'])),
                                            ('remaining_secs', (YLeaf(YType.uint32, 'remaining-secs'), ['int'])),
                                        ])
                                        self.configured = None
                                        self.delay_secs = None
                                        self.timer_running = None
                                        self.remaining_secs = None
                                        self._segment_path = lambda: "sync-delay-restart"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, [u'configured', u'delay_secs', u'timer_running', u'remaining_secs'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_>`
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of  		 :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_)), ("bind-af", ("bind_af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf))])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('binding_no_route', (YLeaf(YType.uint32, 'binding-no-route'), ['int'])),
                                        ('binding_local_no_route', (YLeaf(YType.uint32, 'binding-local-no-route'), ['int'])),
                                        ('binding_local_null', (YLeaf(YType.uint32, 'binding-local-null'), ['int'])),
                                        ('binding_local_implicit_null', (YLeaf(YType.uint32, 'binding-local-implicit-null'), ['int'])),
                                        ('binding_local_explicit_null', (YLeaf(YType.uint32, 'binding-local-explicit-null'), ['int'])),
                                        ('binding_local_non_null', (YLeaf(YType.uint32, 'binding-local-non-null'), ['int'])),
                                        ('binding_local_oor', (YLeaf(YType.uint32, 'binding-local-oor'), ['int'])),
                                        ('lowest_allocated_label', (YLeaf(YType.uint32, 'lowest-allocated-label'), ['int'])),
                                        ('highest_allocated_label', (YLeaf(YType.uint32, 'highest-allocated-label'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.binding_no_route = None
                                    self.binding_local_no_route = None
                                    self.binding_local_null = None
                                    self.binding_local_implicit_null = None
                                    self.binding_local_explicit_null = None
                                    self.binding_local_non_null = None
                                    self.binding_local_oor = None
                                    self.lowest_allocated_label = None
                                    self.highest_allocated_label = None

                                    self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary, [u'address_family', u'binding_no_route', u'binding_local_no_route', u'binding_local_null', u'binding_local_implicit_null', u'binding_local_explicit_null', u'binding_local_non_null', u'binding_local_oor', u'lowest_allocated_label', u'highest_allocated_label'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf_, [u'name', u'id'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                            ('last_lib_update', (YLeaf(YType.uint32, 'last-lib-update'), ['int'])),
                                            ('lib_minimum_revision_sent_all', (YLeaf(YType.uint32, 'lib-minimum-revision-sent-all'), ['int'])),
                                            ('binding_total', (YLeaf(YType.uint32, 'binding-total'), ['int'])),
                                            ('binding_local', (YLeaf(YType.uint32, 'binding-local'), ['int'])),
                                            ('binding_remote', (YLeaf(YType.uint32, 'binding-remote'), ['int'])),
                                        ])
                                        self.address_family = None
                                        self.last_lib_update = None
                                        self.lib_minimum_revision_sent_all = None
                                        self.binding_total = None
                                        self.binding_local = None
                                        self.binding_remote = None
                                        self._segment_path = lambda: "bind-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, [u'address_family', u'last_lib_update', u'lib_minimum_revision_sent_all', u'binding_total', u'binding_local', u'binding_remote'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface))])
                                    self._leafs = OrderedDict()

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	The Interface Name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\: bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of  		 :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of  		 :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_)), ("te-mesh-grp", ("te_mesh_grp", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)), ("auto-config", ("auto_config", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                            ('ldp_enabled', (YLeaf(YType.boolean, 'ldp-enabled'), ['bool'])),
                                            ('is_im_stale', (YLeaf(YType.boolean, 'is-im-stale'), ['bool'])),
                                            ('ldp_config_mode', (YLeaf(YType.boolean, 'ldp-config-mode'), ['bool'])),
                                            ('ldp_autoconfig_disable', (YLeaf(YType.boolean, 'ldp-autoconfig-disable'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.interface = None
                                        self.interface_name_xr = None
                                        self.ldp_enabled = None
                                        self.is_im_stale = None
                                        self.ldp_config_mode = None
                                        self.ldp_autoconfig_disable = None

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.te_mesh_grp = YList(self)
                                        self.auto_config = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', u'interface', u'interface_name_xr', u'ldp_enabled', u'is_im_stale', u'ldp_config_mode', u'ldp_autoconfig_disable'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf_, [u'name', u'id'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\: bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ldp_te_mesh_group_all_cfgd', (YLeaf(YType.boolean, 'ldp-te-mesh-group-all-cfgd'), ['bool'])),
                                                ('ldp_mesh_group_enabled', (YLeaf(YType.boolean, 'ldp-mesh-group-enabled'), ['bool'])),
                                                ('te_mesh_group_id', (YLeaf(YType.uint32, 'te-mesh-group-id'), ['int'])),
                                            ])
                                            self.ldp_te_mesh_group_all_cfgd = None
                                            self.ldp_mesh_group_enabled = None
                                            self.te_mesh_group_id = None
                                            self._segment_path = lambda: "te-mesh-grp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, [u'ldp_te_mesh_group_all_cfgd', u'ldp_mesh_group_enabled', u'te_mesh_group_id'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('tuple', (YLeaf(YType.str, 'tuple'), ['str'])),
                                            ])
                                            self.tuple = None
                                            self._segment_path = lambda: "auto-config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, [u'tuple'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:  :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:  :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:  :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("link-hellos", ("link_hellos", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos)), ("summary", ("summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary)), ("targeted-hellos", ("targeted_hellos", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)), ("brief", ("brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief)), ("stats", ("stats", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats))])
                                    self._leafs = OrderedDict()

                                    self.link_hellos = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"

                                    self.summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"

                                    self.targeted_hellos = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"

                                    self.brief = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"

                                    self.stats = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._segment_path = lambda: "discovery"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery, [], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of  		 :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello", ("link_hello", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello))])
                                        self._leafs = OrderedDict()

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  (key)
                                        
                                        	The Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_>`
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of  		 :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['interface_name']
                                            self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)), ("discovery-link-af", ("discovery_link_af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                            ])
                                            self.interface_name = None
                                            self.next_hello = None
                                            self.interface = None
                                            self.interface_name_xr = None
                                            self.quick_start_disabled = None

                                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"

                                            self.hello_information = YList(self)
                                            self.discovery_link_af = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + str(self.interface_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', u'next_hello', u'interface', u'interface_name_xr', u'quick_start_disabled'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                ])
                                                self.name = None
                                                self.id = None
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf_, [u'name', u'id'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:  :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:  :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:  :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\: str
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\: bool
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\: bool
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\: bool
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-src-address", ("neighbor_src_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress)), ("neighbor-transport-address", ("neighbor_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress)), ("target", ("target", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                    ('is_no_route', (YLeaf(YType.boolean, 'is-no-route'), ['bool'])),
                                                    ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                    ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                    ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                    ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                    ('is_targeted', (YLeaf(YType.boolean, 'is-targeted'), ['bool'])),
                                                    ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                    ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                    ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                                ])
                                                self.neighbor_ldp_identifier = None
                                                self.is_no_route = None
                                                self.hold_time = None
                                                self.local_hold_time = None
                                                self.neighbor_hold_time = None
                                                self.disc_expiry = None
                                                self.is_targeted = None
                                                self.session_up = None
                                                self.established_time = None
                                                self.established_age = None
                                                self.session_bringup_failure_reason = None

                                                self.neighbor_src_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"

                                                self.neighbor_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"

                                                self.target = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, [u'neighbor_ldp_identifier', u'is_no_route', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'is_targeted', u'session_up', u'established_time', u'established_age', u'session_bringup_failure_reason'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "neighbor-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "target"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\: str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                        ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                        ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                    ])
                                                    self.last_session_down_reason = None
                                                    self.last_session_down_time = None
                                                    self.last_session_up_time = None
                                                    self._segment_path = lambda: "last-session-down-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:  :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:  :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-src-address", ("local_src_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress)), ("local-transport-address", ("local_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress))])
                                                self._leafs = OrderedDict([
                                                    ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ])
                                                self.interval = None

                                                self.local_src_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"

                                                self.local_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._segment_path = lambda: "discovery-link-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, [u'interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-src-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "local-transport-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_>`
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\: str
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_))])
                                        self._leafs = OrderedDict([
                                            ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                                            ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                                            ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                                            ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                                            ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                                            ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                                            ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                                            ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                                            ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                                            ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                                            ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                                            ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                                        ])
                                        self.local_ldp_id = None
                                        self.num_of_ldp_interfaces = None
                                        self.num_of_active_ldp_interfaces = None
                                        self.num_of_lnk_disc_xmit = None
                                        self.num_of_tgt_disc_xmit = None
                                        self.num_of_lnk_disc_recv = None
                                        self.num_of_tgt_disc_recv = None
                                        self.num_of_disc_with_bad_addr_recv = None
                                        self.num_of_disc_with_bad_hello_pdu = None
                                        self.num_of_disc_with_bad_xport_addr = None
                                        self.num_of_disc_with_same_router_id = None
                                        self.num_of_disc_with_wrong_router_id = None

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf_, [u'name', u'id'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of  		 :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("targeted-hello", ("targeted_hello", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello))])
                                        self._leafs = OrderedDict()

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:  :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\: str
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\: bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\: str
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of  		 :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcb-local-address", ("dhcb_local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)), ("last-session-down-info", ("last_session_down_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo))])
                                            self._leafs = OrderedDict([
                                                ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                                ('adjacency_ldp_identifier', (YLeaf(YType.str, 'adjacency-ldp-identifier'), ['str'])),
                                                ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                                ('next_hello', (YLeaf(YType.uint32, 'next-hello'), ['int'])),
                                                ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                ('local_hold_time', (YLeaf(YType.uint32, 'local-hold-time'), ['int'])),
                                                ('neighbor_hold_time', (YLeaf(YType.uint32, 'neighbor-hold-time'), ['int'])),
                                                ('disc_expiry', (YLeaf(YType.uint32, 'disc-expiry'), ['int'])),
                                                ('quick_start_disabled', (YLeaf(YType.boolean, 'quick-start-disabled'), ['bool'])),
                                                ('established_time', (YLeaf(YType.uint64, 'established-time'), ['int'])),
                                                ('established_age', (YLeaf(YType.uint64, 'established-age'), ['int'])),
                                                ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                ('session_bringup_failure_reason', (YLeaf(YType.str, 'session-bringup-failure-reason'), ['str'])),
                                            ])
                                            self.local_address = None
                                            self.target_address = None
                                            self.state = None
                                            self.adjacency_ldp_identifier = None
                                            self.interval = None
                                            self.next_hello = None
                                            self.hold_time = None
                                            self.local_hold_time = None
                                            self.neighbor_hold_time = None
                                            self.disc_expiry = None
                                            self.quick_start_disabled = None
                                            self.established_time = None
                                            self.established_age = None
                                            self.session_up = None
                                            self.session_bringup_failure_reason = None

                                            self.dhcb_local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"

                                            self.dhcb_target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['local_address', 'target_address', u'state', u'adjacency_ldp_identifier', u'interval', u'next_hello', u'hold_time', u'local_hold_time', u'neighbor_hold_time', u'disc_expiry', u'quick_start_disabled', u'established_time', u'established_age', u'session_up', u'session_bringup_failure_reason'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "dhcb-target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\: str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('last_session_down_reason', (YLeaf(YType.str, 'last-session-down-reason'), ['str'])),
                                                    ('last_session_down_time', (YLeaf(YType.uint64, 'last-session-down-time'), ['int'])),
                                                    ('last_session_up_time', (YLeaf(YType.uint32, 'last-session-up-time'), ['int'])),
                                                ])
                                                self.last_session_down_reason = None
                                                self.last_session_down_time = None
                                                self.last_session_up_time = None
                                                self._segment_path = lambda: "last-session-down-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, [u'last_session_down_reason', u'last_session_down_time', u'last_session_up_time'], name, value)


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:  :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:  :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-briefs", ("link_hello_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs)), ("targeted-hello-briefs", ("targeted_hello_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs))])
                                        self._leafs = OrderedDict()

                                        self.link_hello_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"

                                        self.targeted_hello_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._segment_path = lambda: "brief"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief, [], name, value)


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of  		 :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("link-hello-brief", ("link_hello_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	The Interface Name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('address_family_set', (YLeaf(YType.enumeration, 'address-family-set'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.address_family = None
                                                self.address_family_set = None
                                                self.interface = None
                                                self.interface_name_xr = None

                                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', u'address_family', u'address_family_set', u'interface', u'interface_name_xr'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of  		 :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("targeted-hello-brief", ("targeted_hello_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief))])
                                            self._leafs = OrderedDict()

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:  :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of  		 :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_)), ("dhcb-target-address", ("dhcb_target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress)), ("hello-information", ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation))])
                                                self._leafs = OrderedDict([
                                                    ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str'])),
                                                    ('target_address', (YLeaf(YType.str, 'target-address'), ['str','str'])),
                                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                                ])
                                                self.local_address = None
                                                self.target_address = None
                                                self.address_family = None

                                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"

                                                self.dhcb_target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['local_address', 'target_address', u'address_family'], name, value)


                                            class Vrf_(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\: str
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ])
                                                    self.name = None
                                                    self.id = None
                                                    self._segment_path = lambda: "vrf"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf_, [u'name', u'id'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "dhcb-target-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\: str
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_ldp_identifier', (YLeaf(YType.str, 'neighbor-ldp-identifier'), ['str'])),
                                                        ('hold_time', (YLeaf(YType.uint32, 'hold-time'), ['int'])),
                                                        ('session_up', (YLeaf(YType.boolean, 'session-up'), ['bool'])),
                                                    ])
                                                    self.neighbor_ldp_identifier = None
                                                    self.hold_time = None
                                                    self.session_up = None
                                                    self._segment_path = lambda: "hello-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, [u'neighbor_ldp_identifier', u'hold_time', u'session_up'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of  		 :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("stat", ("stat", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat))])
                                        self._leafs = OrderedDict()

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                                ('adjacency_group_up_time', (YLeaf(YType.uint32, 'adjacency-group-up-time'), ['int'])),
                                                ('tcp_open_count', (YLeaf(YType.uint32, 'tcp-open-count'), ['int'])),
                                                ('tcp_arb_chg_count', (YLeaf(YType.uint32, 'tcp-arb-chg-count'), ['int'])),
                                                ('tcp_role', (YLeaf(YType.uint32, 'tcp-role'), ['int'])),
                                            ])
                                            self.lsr_id = None
                                            self.label_space_id = None
                                            self.adjacency_group_up_time = None
                                            self.tcp_open_count = None
                                            self.tcp_arb_chg_count = None
                                            self.tcp_role = None
                                            self._segment_path = lambda: "stat"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['lsr_id', 'label_space_id', u'adjacency_group_up_time', u'tcp_open_count', u'tcp_arb_chg_count', u'tcp_role'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of  		 :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("forwarding", ("forwarding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding))])
                                    self._leafs = OrderedDict()

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  (key)
                                    
                                    	The IP Prefix
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_>`
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:  :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['prefix']
                                        self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_)), ("prefix-xr", ("prefix_xr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr)), ("route", ("route", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route)), ("paths", ("paths", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.table_id = None
                                        self.prefix_length = None

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.prefix_xr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"

                                        self.route = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + str(self.prefix) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', u'table_id', u'prefix_length'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.name = None
                                            self.id = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf_, [u'name', u'id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "prefix-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)), ("mpls", ("mpls", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "route"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\: bool
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('source', (YLeaf(YType.uint16, 'source'), ['int'])),
                                                    ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('is_local_vrf_leaked', (YLeaf(YType.boolean, 'is-local-vrf-leaked'), ['bool'])),
                                                    ('routing_update_count', (YLeaf(YType.uint32, 'routing-update-count'), ['int'])),
                                                    ('routing_update_timestamp', (YLeaf(YType.uint64, 'routing-update-timestamp'), ['int'])),
                                                    ('routing_update_age', (YLeaf(YType.uint64, 'routing-update-age'), ['int'])),
                                                    ('sr_local_label', (YLeaf(YType.uint32, 'sr-local-label'), ['int'])),
                                                ])
                                                self.version = None
                                                self.priority = None
                                                self.source = None
                                                self.type = None
                                                self.flags = None
                                                self.metric = None
                                                self.is_local_vrf_leaked = None
                                                self.routing_update_count = None
                                                self.routing_update_timestamp = None
                                                self.routing_update_age = None
                                                self.sr_local_label = None
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, [u'version', u'priority', u'source', u'type', u'flags', u'metric', u'is_local_vrf_leaked', u'routing_update_count', u'routing_update_timestamp', u'routing_update_age', u'sr_local_label'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('forwarding_update_count', (YLeaf(YType.uint32, 'forwarding-update-count'), ['int'])),
                                                    ('forwarding_update_timestamp', (YLeaf(YType.uint64, 'forwarding-update-timestamp'), ['int'])),
                                                    ('forwarding_update_age', (YLeaf(YType.uint64, 'forwarding-update-age'), ['int'])),
                                                ])
                                                self.local_label = None
                                                self.forwarding_update_count = None
                                                self.forwarding_update_timestamp = None
                                                self.forwarding_update_age = None
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, [u'local_label', u'forwarding_update_count', u'forwarding_update_timestamp', u'forwarding_update_age'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:  :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("routing", ("routing", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)), ("mpls", ("mpls", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls))])
                                            self._leafs = OrderedDict()

                                            self.routing = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"

                                            self.mpls = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._segment_path = lambda: "paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, [], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\: str
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:  :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop", ("next_hop", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop)), ("remote-lfa", ("remote_lfa", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa))])
                                                self._leafs = OrderedDict([
                                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('nh_is_overriden', (YLeaf(YType.boolean, 'nh-is-overriden'), ['bool'])),
                                                    ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                    ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                    ('path_id', (YLeaf(YType.uint8, 'path-id'), ['int'])),
                                                    ('bkup_path_id', (YLeaf(YType.uint8, 'bkup-path-id'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.enumeration, 'path-flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathFlags', '')])),
                                                ])
                                                self.interface = None
                                                self.interface_name = None
                                                self.nh_is_overriden = None
                                                self.nexthop_id = None
                                                self.next_hop_table_id = None
                                                self.flags = None
                                                self.load_metric = None
                                                self.path_id = None
                                                self.bkup_path_id = None
                                                self.path_flags = None

                                                self.next_hop = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.remote_lfa = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "routing"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, [u'interface', u'interface_name', u'nh_is_overriden', u'nexthop_id', u'next_hop_table_id', u'flags', u'load_metric', u'path_id', u'bkup_path_id', u'path_flags'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.dummy = None
                                                    self.ipv4 = None
                                                    self.ipv6 = None
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:  :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:  :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\: bool
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("remote-p-node-id", ("remote_p_node_id", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId)), ("remote-q-node-id", ("remote_q_node_id", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                        ('needs_tldp', (YLeaf(YType.boolean, 'needs-tldp'), ['bool'])),
                                                        ('has_q_node', (YLeaf(YType.boolean, 'has-q-node'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None
                                                    self.needs_tldp = None
                                                    self.has_q_node = None

                                                    self.remote_p_node_id = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"

                                                    self.remote_q_node_id = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, [u'has_remote_lfa_bkup', u'needs_tldp', u'has_q_node'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-p-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.dummy = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "remote-q-node-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:  :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo)), ("remote-lfa", ("remote_lfa", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa))])
                                                self._leafs = OrderedDict()

                                                self.mpls_outgoing_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"

                                                self.remote_lfa = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._segment_path = lambda: "mpls"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, [], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\: bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent))])
                                                    self._leafs = OrderedDict([
                                                        ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                        ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                        ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                        ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                        ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                        ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                    ])
                                                    self.out_label = None
                                                    self.out_label_rsn = None
                                                    self.out_label_type = None
                                                    self.out_label_owner = None
                                                    self.is_from_graceful_restartable_neighbor = None
                                                    self.is_stale = None

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._segment_path = lambda: "mpls-outgoing-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                            ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                            ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                        ])
                                                        self.lsr_id = None
                                                        self.label_space_id = None
                                                        self.ldp_id = None
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:  :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("mpls-outgoing-info", ("mpls_outgoing_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo))])
                                                    self._leafs = OrderedDict([
                                                        ('has_remote_lfa_bkup', (YLeaf(YType.boolean, 'has-remote-lfa-bkup'), ['bool'])),
                                                    ])
                                                    self.has_remote_lfa_bkup = None

                                                    self.mpls_outgoing_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._segment_path = lambda: "remote-lfa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, [u'has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of  		 :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("stack", ("stack", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack))])
                                                        self._leafs = OrderedDict()

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:  :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:  :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:  :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:  :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\: bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("nexthop-peer-ldp-ident", ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent))])
                                                            self._leafs = OrderedDict([
                                                                ('out_label', (YLeaf(YType.uint32, 'out-label'), ['int'])),
                                                                ('out_label_rsn', (YLeaf(YType.enumeration, 'out-label-rsn'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpFwdUnlblRsn', '')])),
                                                                ('out_label_type', (YLeaf(YType.enumeration, 'out-label-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LabelValue', '')])),
                                                                ('out_label_owner', (YLeaf(YType.enumeration, 'out-label-owner'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpRoutePathLblOwner', '')])),
                                                                ('is_from_graceful_restartable_neighbor', (YLeaf(YType.boolean, 'is-from-graceful-restartable-neighbor'), ['bool'])),
                                                                ('is_stale', (YLeaf(YType.boolean, 'is-stale'), ['bool'])),
                                                            ])
                                                            self.out_label = None
                                                            self.out_label_rsn = None
                                                            self.out_label_type = None
                                                            self.out_label_owner = None
                                                            self.is_from_graceful_restartable_neighbor = None
                                                            self.is_stale = None

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._segment_path = lambda: "stack"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, [u'out_label', u'out_label_rsn', u'out_label_type', u'out_label_owner', u'is_from_graceful_restartable_neighbor', u'is_stale'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                                                    ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                                                    ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                                                                ])
                                                                self.lsr_id = None
                                                                self.label_space_id = None
                                                                self.ldp_id = None
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:  :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of  		 :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("allocation-acl", ("allocation_acl", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)), ("advt-acl", ("advt_acl", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl))])
                                    self._leafs = OrderedDict()

                                    self.allocation_acl = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('has_acl', (YLeaf(YType.boolean, 'has-acl'), ['bool'])),
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('is_host_route_only', (YLeaf(YType.boolean, 'is-host-route-only'), ['bool'])),
                                        ])
                                        self.has_acl = None
                                        self.prefix_acl = None
                                        self.is_host_route_only = None
                                        self._segment_path = lambda: "allocation-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, [u'has_acl', u'prefix_acl', u'is_host_route_only'], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix_acl', (YLeaf(YType.str, 'prefix-acl'), ['str'])),
                                            ('peer_acl', (YLeaf(YType.str, 'peer-acl'), ['str'])),
                                        ])
                                        self.prefix_acl = None
                                        self.peer_acl = None
                                        self._segment_path = lambda: "advt-acl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, [u'prefix_acl', u'peer_acl'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_>`
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:  :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\: bool
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_)), ("rws", ("rws", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws))])
                                    self._leafs = OrderedDict([
                                        ('is_lsd_bound', (YLeaf(YType.boolean, 'is-lsd-bound'), ['bool'])),
                                        ('fsht', (YLeaf(YType.uint16, 'fsht'), ['int'])),
                                        ('intfs', (YLeaf(YType.uint16, 'intfs'), ['int'])),
                                        ('lbls', (YLeaf(YType.uint16, 'lbls'), ['int'])),
                                    ])
                                    self.is_lsd_bound = None
                                    self.fsht = None
                                    self.intfs = None
                                    self.lbls = None

                                    self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.rws = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._segment_path = lambda: "forwarding-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary, [u'is_lsd_bound', u'fsht', u'intfs', u'lbls'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                        ])
                                        self.name = None
                                        self.id = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf_, [u'name', u'id'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:  :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:  :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pfxs", ("pfxs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)), ("nhs", ("nhs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs))])
                                        self._leafs = OrderedDict()

                                        self.pfxs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"

                                        self.nhs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._segment_path = lambda: "rws"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, [], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:  :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:  :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:  :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("labeled-pfxs-aggr", ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr)), ("labeled-pfxs-primary", ("labeled_pfxs_primary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)), ("labeled-pfxs-backup", ("labeled_pfxs_backup", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup))])
                                            self._leafs = OrderedDict([
                                                ('total_pfxs', (YLeaf(YType.uint16, 'total-pfxs'), ['int'])),
                                                ('ecmp_pfxs', (YLeaf(YType.uint16, 'ecmp-pfxs'), ['int'])),
                                                ('protected_pfxs', (YLeaf(YType.uint16, 'protected-pfxs'), ['int'])),
                                            ])
                                            self.total_pfxs = None
                                            self.ecmp_pfxs = None
                                            self.protected_pfxs = None

                                            self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"

                                            self.labeled_pfxs_primary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"

                                            self.labeled_pfxs_backup = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._segment_path = lambda: "pfxs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, [u'total_pfxs', u'ecmp_pfxs', u'protected_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-primary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('labeled_pfxs', (YLeaf(YType.uint16, 'labeled-pfxs'), ['int'])),
                                                    ('labeled_pfxs_partial', (YLeaf(YType.uint16, 'labeled-pfxs-partial'), ['int'])),
                                                    ('unlabeled_pfxs', (YLeaf(YType.uint16, 'unlabeled-pfxs'), ['int'])),
                                                ])
                                                self.labeled_pfxs = None
                                                self.labeled_pfxs_partial = None
                                                self.unlabeled_pfxs = None
                                                self._segment_path = lambda: "labeled-pfxs-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, [u'labeled_pfxs', u'labeled_pfxs_partial', u'unlabeled_pfxs'], name, value)


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                                ('protected_paths', (YLeaf(YType.uint32, 'protected-paths'), ['int'])),
                                                ('backup_paths', (YLeaf(YType.uint32, 'backup-paths'), ['int'])),
                                                ('remote_backup_paths', (YLeaf(YType.uint32, 'remote-backup-paths'), ['int'])),
                                                ('labeled_paths', (YLeaf(YType.uint32, 'labeled-paths'), ['int'])),
                                                ('labeled_backup_paths', (YLeaf(YType.uint32, 'labeled-backup-paths'), ['int'])),
                                            ])
                                            self.total_paths = None
                                            self.protected_paths = None
                                            self.backup_paths = None
                                            self.remote_backup_paths = None
                                            self.labeled_paths = None
                                            self.labeled_backup_paths = None
                                            self._segment_path = lambda: "nhs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, [u'total_paths', u'protected_paths', u'backup_paths', u'remote_backup_paths', u'labeled_paths', u'labeled_backup_paths'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-brief", ("neighbor_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief))])
                            self._leafs = OrderedDict()

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_>`
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\: bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:  :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of  		 :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_)), ("nbr-br-af-info", ("nbr_br_af_info", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'ShowNsrState', '')])),
                                    ('up_time_seconds', (YLeaf(YType.uint32, 'up-time-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.is_graceful_restartable = None
                                self.nsr_state = None
                                self.up_time_seconds = None

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['lsr_id', 'label_space_id', u'is_graceful_restartable', u'nsr_state', u'up_time_seconds'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf_, [u'name', u'id'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                        ('num_of_nbr_discovery', (YLeaf(YType.uint32, 'num-of-nbr-discovery'), ['int'])),
                                        ('num_of_nbr_addresses', (YLeaf(YType.uint32, 'num-of-nbr-addresses'), ['int'])),
                                        ('num_of_nbr_lbl', (YLeaf(YType.uint32, 'num-of-nbr-lbl'), ['int'])),
                                    ])
                                    self.address_family = None
                                    self.num_of_nbr_discovery = None
                                    self.num_of_nbr_addresses = None
                                    self.num_of_nbr_lbl = None
                                    self._segment_path = lambda: "nbr-br-af-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, [u'address_family', u'num_of_nbr_discovery', u'num_of_nbr_addresses', u'num_of_nbr_lbl'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('initial_seconds', (YLeaf(YType.uint32, 'initial-seconds'), ['int'])),
                                ('maximum_seconds', (YLeaf(YType.uint32, 'maximum-seconds'), ['int'])),
                            ])
                            self.initial_seconds = None
                            self.maximum_seconds = None
                            self._segment_path = lambda: "backoff-parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters, [u'initial_seconds', u'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of  		 :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("backoff", ("backoff", MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff))])
                            self._leafs = OrderedDict()

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('backoff_seconds', (YLeaf(YType.uint32, 'backoff-seconds'), ['int'])),
                                    ('waiting_seconds', (YLeaf(YType.uint32, 'waiting-seconds'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.backoff_seconds = None
                                self.waiting_seconds = None
                                self._segment_path = lambda: "backoff"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff, ['lsr_id', 'label_space_id', u'backoff_seconds', u'waiting_seconds'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:  :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pending", ("nsr_pending", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending)), ("ha-summary", ("ha_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.nsr_pending = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"

                            self.ha_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "nsr"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr, [], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "nsr-pending"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending, [], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:  :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\: bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\: bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\: bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\: bool
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\: bool
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\: bool
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of  		 :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart-information", ("graceful_restart_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation)), ("address-family-parameter", ("address_family_parameter", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter))])
                            self._leafs = OrderedDict([
                                ('role_is_active', (YLeaf(YType.boolean, 'role-is-active'), ['bool'])),
                                ('global_md5_password_enabled', (YLeaf(YType.boolean, 'global-md5-password-enabled'), ['bool'])),
                                ('protocol_version', (YLeaf(YType.uint32, 'protocol-version'), ['int'])),
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                                ('hello_hold_time', (YLeaf(YType.uint32, 'hello-hold-time'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('targeted_hello_hold_time', (YLeaf(YType.uint32, 'targeted-hello-hold-time'), ['int'])),
                                ('targeted_hello_interval', (YLeaf(YType.uint32, 'targeted-hello-interval'), ['int'])),
                                ('session_hold_time', (YLeaf(YType.uint32, 'session-hold-time'), ['int'])),
                                ('housekeeping_timer_interval', (YLeaf(YType.uint32, 'housekeeping-timer-interval'), ['int'])),
                                ('le_no_route_timeout', (YLeaf(YType.uint32, 'le-no-route-timeout'), ['int'])),
                                ('ldp_recovery_timeout', (YLeaf(YType.uint32, 'ldp-recovery-timeout'), ['int'])),
                                ('af_binding_withdraw_delay', (YLeaf(YType.uint32, 'af-binding-withdraw-delay'), ['int'])),
                                ('max_intf_attached', (YLeaf(YType.uint32, 'max-intf-attached'), ['int'])),
                                ('max_intf_te', (YLeaf(YType.uint32, 'max-intf-te'), ['int'])),
                                ('max_peer', (YLeaf(YType.uint32, 'max-peer'), ['int'])),
                                ('ldp_out_of_mem_state', (YLeaf(YType.uint32, 'ldp-out-of-mem-state'), ['int'])),
                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                ('igp_sync_delay_time_for_interface', (YLeaf(YType.uint32, 'igp-sync-delay-time-for-interface'), ['int'])),
                                ('igp_sync_delay_time_on_restart', (YLeaf(YType.uint32, 'igp-sync-delay-time-on-restart'), ['int'])),
                                ('global_discovery_quick_start_disabled', (YLeaf(YType.boolean, 'global-discovery-quick-start-disabled'), ['bool'])),
                                ('discovery_quick_start_disabled_on_interfaces', (YLeaf(YType.boolean, 'discovery-quick-start-disabled-on-interfaces'), ['bool'])),
                            ])
                            self.role_is_active = None
                            self.global_md5_password_enabled = None
                            self.protocol_version = None
                            self.router_id = None
                            self.keepalive_interval = None
                            self.hello_hold_time = None
                            self.hello_interval = None
                            self.targeted_hello_hold_time = None
                            self.targeted_hello_interval = None
                            self.session_hold_time = None
                            self.housekeeping_timer_interval = None
                            self.le_no_route_timeout = None
                            self.ldp_recovery_timeout = None
                            self.af_binding_withdraw_delay = None
                            self.max_intf_attached = None
                            self.max_intf_te = None
                            self.max_peer = None
                            self.ldp_out_of_mem_state = None
                            self.nsr_enabled = None
                            self.nsr_synced = None
                            self.igp_sync_delay_time_for_interface = None
                            self.igp_sync_delay_time_on_restart = None
                            self.global_discovery_quick_start_disabled = None
                            self.discovery_quick_start_disabled_on_interfaces = None

                            self.graceful_restart_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters, [u'role_is_active', u'global_md5_password_enabled', u'protocol_version', u'router_id', u'keepalive_interval', u'hello_hold_time', u'hello_interval', u'targeted_hello_hold_time', u'targeted_hello_interval', u'session_hold_time', u'housekeeping_timer_interval', u'le_no_route_timeout', u'ldp_recovery_timeout', u'af_binding_withdraw_delay', u'max_intf_attached', u'max_intf_te', u'max_peer', u'ldp_out_of_mem_state', u'nsr_enabled', u'nsr_synced', u'igp_sync_delay_time_for_interface', u'igp_sync_delay_time_on_restart', u'global_discovery_quick_start_disabled', u'discovery_quick_start_disabled_on_interfaces'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('is_graceful_restart_configured', (YLeaf(YType.boolean, 'is-graceful-restart-configured'), ['bool'])),
                                    ('graceful_restart_reconnect_timeout', (YLeaf(YType.uint32, 'graceful-restart-reconnect-timeout'), ['int'])),
                                    ('graceful_restart_forwarding_state_hold_time', (YLeaf(YType.uint32, 'graceful-restart-forwarding-state-hold-time'), ['int'])),
                                ])
                                self.is_graceful_restart_configured = None
                                self.graceful_restart_reconnect_timeout = None
                                self.graceful_restart_forwarding_state_hold_time = None
                                self._segment_path = lambda: "graceful-restart-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation, [u'is_graceful_restart_configured', u'graceful_restart_reconnect_timeout', u'graceful_restart_forwarding_state_hold_time'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:  :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:  :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\: str
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\: str
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\: bool
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discovery-transport-address", ("discovery_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress))])
                                self._leafs = OrderedDict([
                                    ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAf', '')])),
                                    ('null_label', (YLeaf(YType.str, 'null-label'), ['str'])),
                                    ('label_imp_null_override_acl', (YLeaf(YType.str, 'label-imp-null-override-acl'), ['str'])),
                                    ('is_accepting_targeted_hellos', (YLeaf(YType.boolean, 'is-accepting-targeted-hellos'), ['bool'])),
                                    ('targeted_hello_acl', (YLeaf(YType.str, 'targeted-hello-acl'), ['str'])),
                                ])
                                self.address_family = None
                                self.null_label = None
                                self.label_imp_null_override_acl = None
                                self.is_accepting_targeted_hellos = None
                                self.targeted_hello_acl = None

                                self.discovery_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._segment_path = lambda: "address-family-parameter"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter, [u'address_family', u'null_label', u'label_imp_null_override_acl', u'is_accepting_targeted_hellos', u'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                        ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                        ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.dummy = None
                                    self.ipv4 = None
                                    self.ipv6 = None
                                    self._segment_path = lambda: "discovery-transport-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:  :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary>`
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:  :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ha-summary", ("ha_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary)), ("ha-statistics", ("ha_statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics))])
                            self._leafs = OrderedDict()

                            self.ha_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"

                            self.ha_statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._segment_path = lambda: "issu"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu, [], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf_>`
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf_)), ("sessions", ("sessions", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions))])
                                self._leafs = OrderedDict()

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.sessions = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._segment_path = lambda: "ha-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary, [], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ])
                                    self.name = None
                                    self.id = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf_, [u'name', u'id'], name, value)


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total', (YLeaf(YType.uint32, 'total'), ['int'])),
                                        ('nsr_eligible', (YLeaf(YType.uint32, 'nsr-eligible'), ['int'])),
                                        ('nsr_state_none', (YLeaf(YType.uint32, 'nsr-state-none'), ['int'])),
                                        ('nsr_state_wait', (YLeaf(YType.uint32, 'nsr-state-wait'), ['int'])),
                                        ('nsr_state_ready', (YLeaf(YType.uint32, 'nsr-state-ready'), ['int'])),
                                        ('nsr_state_prepare', (YLeaf(YType.uint32, 'nsr-state-prepare'), ['int'])),
                                        ('nsr_state_app_wait', (YLeaf(YType.uint32, 'nsr-state-app-wait'), ['int'])),
                                        ('nsr_state_operational', (YLeaf(YType.uint32, 'nsr-state-operational'), ['int'])),
                                        ('nsr_state_tcp_phase1', (YLeaf(YType.uint32, 'nsr-state-tcp-phase1'), ['int'])),
                                        ('nsr_state_tcp_phase2', (YLeaf(YType.uint32, 'nsr-state-tcp-phase2'), ['int'])),
                                    ])
                                    self.total = None
                                    self.nsr_eligible = None
                                    self.nsr_state_none = None
                                    self.nsr_state_wait = None
                                    self.nsr_state_ready = None
                                    self.nsr_state_prepare = None
                                    self.nsr_state_app_wait = None
                                    self.nsr_state_operational = None
                                    self.nsr_state_tcp_phase1 = None
                                    self.nsr_state_tcp_phase2 = None
                                    self._segment_path = lambda: "sessions"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions, [u'total', u'nsr_eligible', u'nsr_state_none', u'nsr_state_wait', u'nsr_state_ready', u'nsr_state_prepare', u'nsr_state_app_wait', u'nsr_state_operational', u'nsr_state_tcp_phase1', u'nsr_state_tcp_phase2'], name, value)


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:  :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:  :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ha-global", ("ha_global", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal)), ("ha-neighbors", ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors))])
                                self._leafs = OrderedDict()

                                self.ha_global = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._segment_path = lambda: "ha-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics, [], name, value)


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:  :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("init-sync", ("init_sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync))])
                                    self._leafs = OrderedDict()

                                    self.init_sync = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._segment_path = lambda: "ha-global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, [], name, value)


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\: bool
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('nsr_cfged', (YLeaf(YType.boolean, 'nsr-cfged'), ['bool'])),
                                            ('nsr_synced', (YLeaf(YType.boolean, 'nsr-synced'), ['bool'])),
                                            ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                            ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                            ('num_peers', (YLeaf(YType.uint32, 'num-peers'), ['int'])),
                                            ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                            ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                            ('num_pfx', (YLeaf(YType.uint32, 'num-pfx'), ['int'])),
                                            ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                            ('num_lcl_addr_wd', (YLeaf(YType.uint32, 'num-lcl-addr-wd'), ['int'])),
                                            ('num_lbl_adv', (YLeaf(YType.uint32, 'num-lbl-adv'), ['int'])),
                                            ('ipc_msg_tx_cnt', (YLeaf(YType.uint32, 'ipc-msg-tx-cnt'), ['int'])),
                                            ('ipc_msg_tx_bytes', (YLeaf(YType.uint32, 'ipc-msg-tx-bytes'), ['int'])),
                                            ('ipc_msg_rx_cnt', (YLeaf(YType.uint32, 'ipc-msg-rx-cnt'), ['int'])),
                                            ('ipc_msg_rx_bytes', (YLeaf(YType.uint32, 'ipc-msg-rx-bytes'), ['int'])),
                                            ('ipc_max_tx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-tx-batch-bytes'), ['int'])),
                                            ('ipc_max_rx_batch_bytes', (YLeaf(YType.uint32, 'ipc-max-rx-batch-bytes'), ['int'])),
                                            ('ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'ipc-tx-fail-cnt'), ['int'])),
                                            ('total_ipc_tx_fail_cnt', (YLeaf(YType.uint32, 'total-ipc-tx-fail-cnt'), ['int'])),
                                            ('ipc_restart_cnt', (YLeaf(YType.uint32, 'ipc-restart-cnt'), ['int'])),
                                            ('ipc_default_mtu', (YLeaf(YType.uint32, 'ipc-default-mtu'), ['int'])),
                                            ('ipc_exceeded_mtu_msg_cnt', (YLeaf(YType.uint32, 'ipc-exceeded-mtu-msg-cnt'), ['int'])),
                                        ])
                                        self.nsr_cfged = None
                                        self.nsr_synced = None
                                        self.init_sync_start = None
                                        self.init_sync_end = None
                                        self.num_peers = None
                                        self.num_cap_sent = None
                                        self.num_cap_rcvd = None
                                        self.num_pfx = None
                                        self.num_lbl = None
                                        self.num_lcl_addr_wd = None
                                        self.num_lbl_adv = None
                                        self.ipc_msg_tx_cnt = None
                                        self.ipc_msg_tx_bytes = None
                                        self.ipc_msg_rx_cnt = None
                                        self.ipc_msg_rx_bytes = None
                                        self.ipc_max_tx_batch_bytes = None
                                        self.ipc_max_rx_batch_bytes = None
                                        self.ipc_tx_fail_cnt = None
                                        self.total_ipc_tx_fail_cnt = None
                                        self.ipc_restart_cnt = None
                                        self.ipc_default_mtu = None
                                        self.ipc_exceeded_mtu_msg_cnt = None
                                        self._segment_path = lambda: "init-sync"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['nsr_cfged', 'nsr_synced', 'init_sync_start', 'init_sync_end', 'num_peers', 'num_cap_sent', 'num_cap_rcvd', 'num_pfx', 'num_lbl', 'num_lcl_addr_wd', 'num_lbl_adv', 'ipc_msg_tx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_rx_bytes', 'ipc_max_tx_batch_bytes', 'ipc_max_rx_batch_bytes', 'ipc_tx_fail_cnt', 'total_ipc_tx_fail_cnt', 'ipc_restart_cnt', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of  		 :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ha-neighbor", ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:  :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:  :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("init-sync-info", ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo)), ("steady-state-sync-info", ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo))])
                                        self._leafs = OrderedDict([
                                            ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                            ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                            ('lsr_id_xr', (YLeaf(YType.uint32, 'lsr-id-xr'), ['int'])),
                                            ('lbl_spc_id', (YLeaf(YType.uint16, 'lbl-spc-id'), ['int'])),
                                            ('nsr_sync_state', (YLeaf(YType.int32, 'nsr-sync-state'), ['int'])),
                                            ('num_msg', (YLeaf(YType.uint32, 'num-msg'), ['int'])),
                                        ])
                                        self.lsr_id = None
                                        self.label_space_id = None
                                        self.lsr_id_xr = None
                                        self.lbl_spc_id = None
                                        self.nsr_sync_state = None
                                        self.num_msg = None

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._segment_path = lambda: "ha-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['lsr_id', 'label_space_id', 'lsr_id_xr', 'lbl_spc_id', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('init_sync_start', (YLeaf(YType.uint32, 'init-sync-start'), ['int'])),
                                                ('init_sync_end', (YLeaf(YType.uint32, 'init-sync-end'), ['int'])),
                                                ('num_addr', (YLeaf(YType.uint32, 'num-addr'), ['int'])),
                                                ('num_duplicate_addr', (YLeaf(YType.uint32, 'num-duplicate-addr'), ['int'])),
                                                ('num_rx_bytes', (YLeaf(YType.uint32, 'num-rx-bytes'), ['int'])),
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('num_lbl', (YLeaf(YType.uint32, 'num-lbl'), ['int'])),
                                                ('num_app_bytes', (YLeaf(YType.uint32, 'num-app-bytes'), ['int'])),
                                            ])
                                            self.init_sync_start = None
                                            self.init_sync_end = None
                                            self.num_addr = None
                                            self.num_duplicate_addr = None
                                            self.num_rx_bytes = None
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.num_lbl = None
                                            self.num_app_bytes = None
                                            self._segment_path = lambda: "init-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_start', 'init_sync_end', 'num_addr', 'num_duplicate_addr', 'num_rx_bytes', 'num_cap_sent', 'num_cap_rcvd', 'num_lbl', 'num_app_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('num_cap_sent', (YLeaf(YType.uint32, 'num-cap-sent'), ['int'])),
                                                ('num_cap_rcvd', (YLeaf(YType.uint32, 'num-cap-rcvd'), ['int'])),
                                                ('rem_lbl_wd', (YLeaf(YType.uint32, 'rem-lbl-wd'), ['int'])),
                                                ('rem_lbl_rq', (YLeaf(YType.uint32, 'rem-lbl-rq'), ['int'])),
                                                ('num_stdby_adj_join', (YLeaf(YType.uint32, 'num-stdby-adj-join'), ['int'])),
                                                ('num_stdby_adj_leave', (YLeaf(YType.uint32, 'num-stdby-adj-leave'), ['int'])),
                                            ])
                                            self.num_cap_sent = None
                                            self.num_cap_rcvd = None
                                            self.rem_lbl_wd = None
                                            self.rem_lbl_rq = None
                                            self.num_stdby_adj_join = None
                                            self.num_stdby_adj_leave = None
                                            self._segment_path = lambda: "steady-state-sync-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_sent', 'num_cap_rcvd', 'rem_lbl_wd', 'rem_lbl_rq', 'num_stdby_adj_join', 'num_stdby_adj_leave'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-capability", ("neighbor_capability", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability))])
                            self._leafs = OrderedDict()

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)), ("received", ("received", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.sent = YList(self)
                                self.received = YList(self)
                                self._segment_path = lambda: "neighbor-capability"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['lsr_id', 'label_space_id'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "sent"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                        ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                    ])
                                    self.type = None
                                    self.description = None
                                    self.capability_data_length = None
                                    self.capability_data = None
                                    self._segment_path = lambda: "received"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:  :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:  :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:  :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of  		 :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of  		 :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocol-information", ("protocol_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation)), ("tcp-information", ("tcp_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)), ("detailed-information", ("detailed_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation)), ("ldp-nbr-bound-ipv4-address-info", ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo)), ("ldp-nbr-bound-ipv6-address-info", ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo)), ("ldp-nbr-ipv4-adj-info", ("ldp_nbr_ipv4_adj_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo)), ("ldp-nbr-ipv6-adj-info", ("ldp_nbr_ipv6_adj_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None

                                self.protocol_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"

                                self.tcp_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"

                                self.detailed_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor, ['lsr_id', 'label_space_id'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:  :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\: str
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ta-graceful-restart-adjacency", ("ta_graceful_restart_adjacency", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency))])
                                    self._leafs = OrderedDict([
                                        ('ta_holdtime', (YLeaf(YType.uint32, 'ta-holdtime'), ['int'])),
                                        ('ta_state', (YLeaf(YType.str, 'ta-state'), ['str'])),
                                        ('ta_pies_sent', (YLeaf(YType.uint32, 'ta-pies-sent'), ['int'])),
                                        ('ta_pies_rcvd', (YLeaf(YType.uint32, 'ta-pies-rcvd'), ['int'])),
                                        ('ta_up_time_seconds', (YLeaf(YType.uint32, 'ta-up-time-seconds'), ['int'])),
                                        ('downstream_on_demand', (YLeaf(YType.boolean, 'downstream-on-demand'), ['bool'])),
                                    ])
                                    self.ta_holdtime = None
                                    self.ta_state = None
                                    self.ta_pies_sent = None
                                    self.ta_pies_rcvd = None
                                    self.ta_up_time_seconds = None
                                    self.downstream_on_demand = None

                                    self.ta_graceful_restart_adjacency = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._segment_path = lambda: "protocol-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, [u'ta_holdtime', u'ta_state', u'ta_pies_sent', u'ta_pies_rcvd', u'ta_up_time_seconds', u'downstream_on_demand'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\: bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('is_graceful_restartable', (YLeaf(YType.boolean, 'is-graceful-restartable'), ['bool'])),
                                            ('reconnect_timeout', (YLeaf(YType.uint32, 'reconnect-timeout'), ['int'])),
                                            ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                        ])
                                        self.is_graceful_restartable = None
                                        self.reconnect_timeout = None
                                        self.recovery_time = None
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, [u'is_graceful_restartable', u'reconnect_timeout', u'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:  :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:  :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("foreign-host", ("foreign_host", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost)), ("local-host", ("local_host", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost))])
                                    self._leafs = OrderedDict([
                                        ('foreign_port', (YLeaf(YType.uint16, 'foreign-port'), ['int'])),
                                        ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                        ('is_md5_on', (YLeaf(YType.boolean, 'is-md5-on'), ['bool'])),
                                    ])
                                    self.foreign_port = None
                                    self.local_port = None
                                    self.is_md5_on = None

                                    self.foreign_host = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"

                                    self.local_host = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._segment_path = lambda: "tcp-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, [u'foreign_port', u'local_port', u'is_md5_on'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "foreign-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "local-host"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:  :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\: bool
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\: bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\: bool
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\: str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\: bool
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\: bool
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:  :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:  :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:  :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\: bool
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of  		 :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of  		 :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("capabilities", ("capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)), ("client", ("client", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client)), ("ipv4-duplicate-address", ("ipv4_duplicate_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress)), ("ipv6-duplicate-address", ("ipv6_duplicate_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress))])
                                    self._leafs = OrderedDict([
                                        ('peer_holdtime', (YLeaf(YType.uint32, 'peer-holdtime'), ['int'])),
                                        ('keep_alive_interval', (YLeaf(YType.uint32, 'keep-alive-interval'), ['int'])),
                                        ('peer_state', (YLeaf(YType.str, 'peer-state'), ['str'])),
                                        ('has_ipv4_inbound', (YLeaf(YType.boolean, 'has-ipv4-inbound'), ['bool'])),
                                        ('inbound_ipv4acl', (YLeaf(YType.str, 'inbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_inbound', (YLeaf(YType.boolean, 'has-ipv6-inbound'), ['bool'])),
                                        ('inbound_ipv6acl', (YLeaf(YType.str, 'inbound-ipv6acl'), ['str'])),
                                        ('has_ipv4_outbound', (YLeaf(YType.boolean, 'has-ipv4-outbound'), ['bool'])),
                                        ('outbound_ipv4acl', (YLeaf(YType.str, 'outbound-ipv4acl'), ['str'])),
                                        ('has_ipv6_outbound', (YLeaf(YType.boolean, 'has-ipv6-outbound'), ['bool'])),
                                        ('outbound_ipv6acl', (YLeaf(YType.str, 'outbound-ipv6acl'), ['str'])),
                                        ('has_sp', (YLeaf(YType.boolean, 'has-sp'), ['bool'])),
                                        ('sp_state', (YLeaf(YType.str, 'sp-state'), ['str'])),
                                        ('sp_has_acl', (YLeaf(YType.boolean, 'sp-has-acl'), ['bool'])),
                                        ('spacl', (YLeaf(YType.str, 'spacl'), ['str'])),
                                        ('sp_has_duration', (YLeaf(YType.boolean, 'sp-has-duration'), ['bool'])),
                                        ('sp_duration', (YLeaf(YType.uint32, 'sp-duration'), ['int'])),
                                        ('spht_running', (YLeaf(YType.boolean, 'spht-running'), ['bool'])),
                                        ('spht_remaining', (YLeaf(YType.uint32, 'spht-remaining'), ['int'])),
                                        ('nsr_sync_state', (YLeaf(YType.enumeration, 'nsr-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncState', '')])),
                                        ('nsr_last_sync_error', (YLeaf(YType.enumeration, 'nsr-last-sync-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerSyncErr', '')])),
                                        ('nsr_last_sync_nack_reason', (YLeaf(YType.enumeration, 'nsr-last-sync-nack-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNsrPeerLdpSyncNackRsn', '')])),
                                        ('bgp_advertisement_state', (YLeaf(YType.enumeration, 'bgp-advertisement-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'MgmtLdpNbrBgpAdvtState', '')])),
                                        ('advertise_bgp_prefixes', (YLeaf(YType.boolean, 'advertise-bgp-prefixes'), ['bool'])),
                                    ])
                                    self.peer_holdtime = None
                                    self.keep_alive_interval = None
                                    self.peer_state = None
                                    self.has_ipv4_inbound = None
                                    self.inbound_ipv4acl = None
                                    self.has_ipv6_inbound = None
                                    self.inbound_ipv6acl = None
                                    self.has_ipv4_outbound = None
                                    self.outbound_ipv4acl = None
                                    self.has_ipv6_outbound = None
                                    self.outbound_ipv6acl = None
                                    self.has_sp = None
                                    self.sp_state = None
                                    self.sp_has_acl = None
                                    self.spacl = None
                                    self.sp_has_duration = None
                                    self.sp_duration = None
                                    self.spht_running = None
                                    self.spht_remaining = None
                                    self.nsr_sync_state = None
                                    self.nsr_last_sync_error = None
                                    self.nsr_last_sync_nack_reason = None
                                    self.bgp_advertisement_state = None
                                    self.advertise_bgp_prefixes = None

                                    self.capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, [u'peer_holdtime', u'keep_alive_interval', u'peer_state', u'has_ipv4_inbound', u'inbound_ipv4acl', u'has_ipv6_inbound', u'inbound_ipv6acl', u'has_ipv4_outbound', u'outbound_ipv4acl', u'has_ipv6_outbound', u'outbound_ipv6acl', u'has_sp', u'sp_state', u'sp_has_acl', u'spacl', u'sp_has_duration', u'sp_duration', u'spht_running', u'spht_remaining', u'nsr_sync_state', u'nsr_last_sync_error', u'nsr_last_sync_nack_reason', u'bgp_advertisement_state', u'advertise_bgp_prefixes'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of  		 :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of  		 :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sent", ("sent", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)), ("received", ("received", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received))])
                                        self._leafs = OrderedDict()

                                        self.sent = YList(self)
                                        self.received = YList(self)
                                        self._segment_path = lambda: "capabilities"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "sent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\: str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.uint16, 'type'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('capability_data_length', (YLeaf(YType.uint16, 'capability-data-length'), ['int'])),
                                                ('capability_data', (YLeaf(YType.str, 'capability-data'), ['str'])),
                                            ])
                                            self.type = None
                                            self.description = None
                                            self.capability_data_length = None
                                            self.capability_data = None
                                            self._segment_path = lambda: "received"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, [u'type', u'description', u'capability_data_length', u'capability_data'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "client"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, [u'name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv4-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address))])
                                        self._leafs = OrderedDict()

                                        self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._segment_path = lambda: "ipv6-duplicate-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, [], name, value)


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.dummy = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self._segment_path = lambda: "address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("address", ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address))])
                                    self._leafs = OrderedDict()

                                    self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, [], name, value)


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                            ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.dummy = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:  :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-group", ("adjacency_group", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup))])
                                    self._leafs = OrderedDict()

                                    self.adjacency_group = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, [], name, value)


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:  :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:  :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:  :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-hello-data", ("link_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData)), ("target-hello-data", ("target_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData))])
                                        self._leafs = OrderedDict([
                                            ('hello_type', (YLeaf(YType.enumeration, 'hello-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAdjUnionDiscrim', '')])),
                                        ])
                                        self.hello_type = None

                                        self.link_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"

                                        self.target_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._segment_path = lambda: "adjacency-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, [u'hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "link-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, [u'interface', u'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:  :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:  :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:  :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-address", ("local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress)), ("target-address", ("target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress))])
                                            self._leafs = OrderedDict([
                                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'DhcbState', '')])),
                                            ])
                                            self.state = None

                                            self.local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"

                                            self.target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._segment_path = lambda: "target-hello-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, [u'state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper', 'LdpAfId', '')])),
                                                    ('dummy', (YLeaf(YType.uint8, 'dummy'), ['int'])),
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                    ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.dummy = None
                                                self.ipv4 = None
                                                self.ipv6 = None
                                                self._segment_path = lambda: "target-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, [u'afi', u'dummy', u'ipv4', u'ipv6'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                ('label_space_id', (YLeaf(YType.uint16, 'label-space-id'), ['int'])),
                                ('ldp_id', (YLeaf(YType.str, 'ldp-id'), ['str'])),
                            ])
                            self.lsr_id = None
                            self.label_space_id = None
                            self.ldp_id = None
                            self._segment_path = lambda: "ldp-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId, [u'lsr_id', u'label_space_id', u'ldp_id'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("statistic", ("statistic", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic))])
                            self._leafs = OrderedDict()

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:  :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:  :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("message-out", ("message_out", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut)), ("message-in", ("message_in", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn))])
                                self._leafs = OrderedDict([
                                    ('lsr_id', (YLeaf(YType.str, 'lsr-id'), ['str'])),
                                    ('label_space_id', (YLeaf(YType.uint32, 'label-space-id'), ['int'])),
                                    ('iccp_enabled', (YLeaf(YType.boolean, 'iccp-enabled'), ['bool'])),
                                ])
                                self.lsr_id = None
                                self.label_space_id = None
                                self.iccp_enabled = None

                                self.message_out = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"

                                self.message_in = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._segment_path = lambda: "statistic"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic, ['lsr_id', 'label_space_id', u'iccp_enabled'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-out"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_count', (YLeaf(YType.uint32, 'total-count'), ['int'])),
                                        ('init_count', (YLeaf(YType.uint32, 'init-count'), ['int'])),
                                        ('address_count', (YLeaf(YType.uint32, 'address-count'), ['int'])),
                                        ('address_withdraw_count', (YLeaf(YType.uint32, 'address-withdraw-count'), ['int'])),
                                        ('label_map_count', (YLeaf(YType.uint32, 'label-map-count'), ['int'])),
                                        ('label_withdraw_count', (YLeaf(YType.uint32, 'label-withdraw-count'), ['int'])),
                                        ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                        ('label_request_count', (YLeaf(YType.uint32, 'label-request-count'), ['int'])),
                                        ('label_abort_request_count', (YLeaf(YType.uint32, 'label-abort-request-count'), ['int'])),
                                        ('notification_count', (YLeaf(YType.uint32, 'notification-count'), ['int'])),
                                        ('keep_alive_count', (YLeaf(YType.uint32, 'keep-alive-count'), ['int'])),
                                        ('iccp_rg_conn_count', (YLeaf(YType.uint32, 'iccp-rg-conn-count'), ['int'])),
                                        ('iccp_rg_disconn_count', (YLeaf(YType.uint32, 'iccp-rg-disconn-count'), ['int'])),
                                        ('iccp_rg_notif_count', (YLeaf(YType.uint32, 'iccp-rg-notif-count'), ['int'])),
                                        ('iccp_rg_app_data_count', (YLeaf(YType.uint32, 'iccp-rg-app-data-count'), ['int'])),
                                    ])
                                    self.total_count = None
                                    self.init_count = None
                                    self.address_count = None
                                    self.address_withdraw_count = None
                                    self.label_map_count = None
                                    self.label_withdraw_count = None
                                    self.label_release_count = None
                                    self.label_request_count = None
                                    self.label_abort_request_count = None
                                    self.notification_count = None
                                    self.keep_alive_count = None
                                    self.iccp_rg_conn_count = None
                                    self.iccp_rg_disconn_count = None
                                    self.iccp_rg_notif_count = None
                                    self.iccp_rg_app_data_count = None
                                    self._segment_path = lambda: "message-in"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn, [u'total_count', u'init_count', u'address_count', u'address_withdraw_count', u'label_map_count', u'label_withdraw_count', u'label_release_count', u'label_request_count', u'label_abort_request_count', u'notification_count', u'keep_alive_count', u'iccp_rg_conn_count', u'iccp_rg_disconn_count', u'iccp_rg_notif_count', u'iccp_rg_app_data_count'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf>`
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\: str
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf))])
                    self._leafs = OrderedDict([
                        ('local_ldp_id', (YLeaf(YType.str, 'local-ldp-id'), ['str'])),
                        ('num_of_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-ldp-interfaces'), ['int'])),
                        ('num_of_active_ldp_interfaces', (YLeaf(YType.uint32, 'num-of-active-ldp-interfaces'), ['int'])),
                        ('num_of_lnk_disc_xmit', (YLeaf(YType.uint32, 'num-of-lnk-disc-xmit'), ['int'])),
                        ('num_of_tgt_disc_xmit', (YLeaf(YType.uint32, 'num-of-tgt-disc-xmit'), ['int'])),
                        ('num_of_lnk_disc_recv', (YLeaf(YType.uint32, 'num-of-lnk-disc-recv'), ['int'])),
                        ('num_of_tgt_disc_recv', (YLeaf(YType.uint32, 'num-of-tgt-disc-recv'), ['int'])),
                        ('num_of_disc_with_bad_addr_recv', (YLeaf(YType.uint32, 'num-of-disc-with-bad-addr-recv'), ['int'])),
                        ('num_of_disc_with_bad_hello_pdu', (YLeaf(YType.uint32, 'num-of-disc-with-bad-hello-pdu'), ['int'])),
                        ('num_of_disc_with_bad_xport_addr', (YLeaf(YType.uint32, 'num-of-disc-with-bad-xport-addr'), ['int'])),
                        ('num_of_disc_with_same_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-same-router-id'), ['int'])),
                        ('num_of_disc_with_wrong_router_id', (YLeaf(YType.uint32, 'num-of-disc-with-wrong-router-id'), ['int'])),
                    ])
                    self.local_ldp_id = None
                    self.num_of_ldp_interfaces = None
                    self.num_of_active_ldp_interfaces = None
                    self.num_of_lnk_disc_xmit = None
                    self.num_of_tgt_disc_xmit = None
                    self.num_of_lnk_disc_recv = None
                    self.num_of_tgt_disc_recv = None
                    self.num_of_disc_with_bad_addr_recv = None
                    self.num_of_disc_with_bad_hello_pdu = None
                    self.num_of_disc_with_bad_xport_addr = None
                    self.num_of_disc_with_same_router_id = None
                    self.num_of_disc_with_wrong_router_id = None

                    self.vrf = MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._segment_path = lambda: "discovery-summary-all"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.DiscoverySummaryAll, [u'local_ldp_id', u'num_of_ldp_interfaces', u'num_of_active_ldp_interfaces', u'num_of_lnk_disc_xmit', u'num_of_tgt_disc_xmit', u'num_of_lnk_disc_recv', u'num_of_tgt_disc_recv', u'num_of_disc_with_bad_addr_recv', u'num_of_disc_with_bad_hello_pdu', u'num_of_disc_with_bad_xport_addr', u'num_of_disc_with_same_router_id', u'num_of_disc_with_wrong_router_id'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                        ])
                        self.name = None
                        self.id = None
                        self._segment_path = lambda: "vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf, [u'name', u'id'], name, value)

    def clone_ptr(self):
        self._top_entity = MplsLdp()
        return self._top_entity

